<?php

/*
#----------------------------------------------------------------------------------------------
#
#  Reference:  	E-ARK  -  Census Management Page
#
#  File:     	~/census_page.php 
#  Project:    	E-ARK
#  Version:     $Id: census_page.php,v 1.20 2004/04/15 14:44:39 vboctor Exp $	
#  State:       Beta
#  Author:      Ian Atherton, Victor Boctor
#  Creation:    17/03/2004
#
#
#  Comments:    Main Census page, used for managing the census infomation into the system. 
#		The tasks supported are : 
#
#		1) Adding of families, 
#		2) Editing of families, 
#		3) Adding a parishioner to an already existing family, 
#		4) Removing a parishioner from an already existing family, 
#
#		N.B. The presumption is that the "register_globals" variable is set in the 
#		php.ini file.  If this is not the case, you must make the change and restart
#		apache or IIS (if required) before proceeding. 
#
#
#
#  Routines:
#       Routine                     Date            Description
#       -----------------------------------------------------------------------
#	Main_Menu()		   17/03/2004	    Dislay Main Menu for Family Admin 
#	Family_Details()	   17/03/2004	    Collect Family Details for new family
#       Family_Members()	   17/03/2004       Collect Information for each family member
#       Family_Find_And_edit()	   17/03/2004       Find a Family to edit
#       Family_Find_And_Delete()   17/03/2004       Find a Family to delete 
#	Family_add_data		   17/03/2004	    Add Family and Member data to database
#       family_list_for_delete()   17/03/2004 	    List family ID's for deletion
#       family_list_for_edit()     17/03/2004 	    List family ID's for editing  
#       family_delete_all_data()   17/03/2004 	    
#       family_find_add()   	   17/03/2004 	    
#       family_find_move()   	   17/03/2004 	    
#       family_edit_page()   	   17/03/2004 	    
#
#  Update History:
#       -----------------------------------------------------------------------
#       $Log: census_page.php,v $
#       Revision 1.20  2004/04/15 14:44:39  vboctor
#       Added occupation field to parishioner (in database, in view page, in add, in edit)
#
#       Revision 1.19  2004/04/13 10:52:20  iatherton
#       Modified to remove the Famil Admin options
#
#       Revision 1.18  2004/04/05 11:07:59  vboctor
#       - Fixed some html issues with family results for editing and made the layout more readable.
#       - Fixed some issues with the family edit, but found out that the editing of the family member information is not yet implemented.
#
#       Revision 1.17  2004/04/04 10:06:17  vboctor
#       M src/family_inc.php
#       - Implemented family_delete() to delete a family, all associated family members/parishioners, address, and the suburb (if the suburb is not used by other families).  It internally uses parishioner_delete() and address_delete().
#
#       M src/address_inc.php
#       - suburb_get_id() to get the id given the name.
#       - suburb_is_used() to check if the suburb is used by any addresses.
#       - suburb_get_all_ids() to return an array of all ids in the db.
#       - suburb_delete() deletes a suburb irrespective of whether it is used or not.
#       - address_delete() deletes an address and deletes its suburb if not used by other addresses.
#
#       M src/parishioner_inc.php
#       - Implemented parishioner_delete().
#
#       M census_page.php
#       - Call family_delete() rather than implement it here.
#
#       M templates/family_deleted.tpl
#       - Adjusted the output message.
#
#       Revision 1.16  2004/04/03 15:33:15  vboctor
#       Generate passphrase for family_view_page only when in standalone mode.
#
#       Revision 1.15  2004/04/03 15:21:55  vboctor
#       Added support for partial dates in census form (for example, someone specifying month/year of date of birth, but not the day, ...etc)
#
#       Revision 1.14  2004/04/03 15:10:38  vboctor
#       - Changed the family add flow to use the family_view_page.php for displaying details about the added family.
#       - Added a passphrase mechanism to make the family_view_page.php work in standalone mode only to display the info about the added family (without allowing the user to view other families).
#
#       Revision 1.13  2004/04/03 14:29:38  vboctor
#       - Added support for "approved" state in families/parishioners based on whether the form is in standalone / normal mode.
#       - "Delete Family" wasn't deleting the parishioners. (fixed)
#       - "Delete Family" was deleting the suburb even if used by other addresses (fixed)
#
#       Revision 1.12  2004/04/03 14:09:42  iatherton
#       1)  Merged Victor's changes in with my own, fixed up furthed issues with
#           my own.
#       2)  Bug fixed further issues with the family edit code.
#       3)  Modifications to the family delete code
#
#       Revision 1.11  2004/04/03 13:39:01  vboctor
#       - Fixed notices in the family search results for deleting.
#       - Fixed the query for filtering families when editing/deleting (it wasn't included the parish in the criteria).
#       - Added the parish for the family delete search to be consistent with the family edit search.
#
#       Revision 1.10  2004/04/03 13:28:10  vboctor
#       Removed all hard-coded table names (used table( 'table_name' ) instead)
#
#       Revision 1.9  2004/04/03 13:10:39  vboctor
#       M src/parishioner_inc.php
#       M census_page.php
#       - Added the parishes list in the family search for editing
#       - Fixed some notices in the result list of the family search for edit.
#       - Use standard functions to retrieve genders and titles.
#       - Started using table( 'tablename' ) rather than hard-coding the name in the query.
#
#       Revision 1.8  2004/04/03 12:32:33  iatherton
#       1. Bug fixes to add new family menu
#       2. Bug fixes to delete family
#       3. Bug fixes to edit family (not completed)
#       4. Functional work on Delete/add paritioner in family
#
#       Revision 1.7  2004/04/03 07:51:47  iatherton
#       General debugging
#
#       Revision 1.6  2004/04/02 16:15:35  iatherton
#       1.  Created a standard Smarty variable for called standalone, that is set to the value
#           of $cfg_standalone.   This is used by smarty templated called by the census page, to
#           decied if menu.tpl should be displayed.
#       2.  Included 'access_ensure_not_standalone()' from 'access_api_inc.php' to allow validation
#           of functionality that is not allowed during standalone mode.  If such functionality is
#           attempted, and error message will be triggered.
#
#       Revision 1.5  2004/04/02 14:52:41  iatherton
#       1. Turned PHP Notices ON ( Line to turn all noticed OFF included and commented out)
#          error_reporting (E_ALL ^ E_NOTICE);  //error_reporting (E_NONE);
#       2. Included 'family_member_inc.php'
#       3. Modified $role_ids and $role_names to use 'family_member_get_role_id_name_map()'
#          included in 'family_member_inc.php'
#
#       Revision 1.4  2004/04/02 14:42:54  iatherton
#       1. Created e-ark/HELP directory
#       2. Updated e-ark/readme.txt to include new directory details
#       3. Added exampleX.jpg helpIcon.gif images to e-ark/images (images of census forms)
#       4. created  e-ark/census_family.tpl and e-ark/census_member.tpl templates in e-eark/templates
#          depricated e-ark/census_page.tpl.
#       5. Modified e-ark/templates/menu.tpl, changed "Family Add" to "Family Admin"
#       6. Added e-ark/doc/code directory, to contain code specific information.
#       7. Created e-ark/templates/family_admin_menu.tpl
#       8. Created census_page_member.tpl, census_page_family.tpl, census_page_success.tpl,
#          family_admin_menu.tpl, family_find_delete.tpl, family_find_edit.tpl, family_list_for_delete.tpl
#       9. Added hlp_family_01.html, hlp_family_02.html to e-ark/HELP/  
#
#
#
#  Documentation Details:
#       -----------------------------------------------------------------------
#       Code Documenton:        ~/doc/code/census_page.txt
#       Author:                 Ian Atherton
#       Contact Number:         0409656609
#       Email:                  Iatherton@users.sourceforge.net 
#
#
#  Terms of Use:
#       -----------------------------------------------------------------------
#  	Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
#  	This program is distributed under the terms and conditions of the GPL
#  	See the README and LICENSE files for details
#
#----------------------------------------------------------------------------------------------
*/

//#----------------------------------------------------------------------------------------------
//# PHP NOTICES 
//#----------------------------------------------------------------------------------------------
      error_reporting (E_ALL ^ E_NOTICE);				// ALL ON
      //error_reporting (E_ALL);					// EVERYTHING 
      //error_reporting (E_NOTICE);					// JUST NOTICES 
      //error_reporting (E_NONE);					// ALL OFF


//#----------------------------------------------------------------------------------------------
//# REQUIRED INCLUDE FILES 
//#----------------------------------------------------------------------------------------------
    $t_src_path = dirname( __FILE__ ).DIRECTORY_SEPARATOR.'src'.DIRECTORY_SEPARATOR; // Path to 'src'

    $t_arguments=$option;						// Get current option argument
    $t_error=$error;							// Get current error argument
    require_once( $t_src_path . 'common_inc.php' );			// Perform check and instantiate standard classes
    require_once( $t_src_path . 'parish_inc.php' );			// Parish related class and methods
    require_once( $t_src_path . 'address_inc.php' );			// Address related class and methods
    require_once( $t_src_path . 'utils_api_inc.php' );			// Validation and other utilities
    require_once( $t_src_path . 'access_api_inc.php' );			// Access permissions
    require_once( $t_src_path . 'database_inc.php' );			// Database Access functionality
    require_once( $t_src_path . 'family_member_inc.php' );		// Family Member functionality
    $option=$t_arguments;						// Map previous option arguement to option 
    $error=$t_error;							// Map previous error arguement to error 

    




//#----------------------------------------------------------------------------------------------
//# DECLARATIONS 
//#----------------------------------------------------------------------------------------------
    $template->assign( 'option',        '' );				// Define smarty option variable
    $template->assign( 'error',        $error );			// Define smarty error  variable
    $template->assign( 'standalone',   $cfg_standalone );		// Define smarty standalone variable




//#----------------------------------------------------------------------------------------------
//# FLOW CONTROLL
//#----------------------------------------------------------------------------------------------
//# Option values
//#  		< 1 	Main menu
//#		  1	Enter Family Details
//#		  2	Enter Family Members information
//#		  3	Add Family and Member data to database
//#               4
//#		  8	Family find and edit
//#		  9     List Family Id's for deletion
//#		  10    Family Edit page
//#               11    Family Members Edit page (not yet implemented)
//#		  16	Family find and delete
//#	 	  17    List Family Id's for deletion
//#		  18	Family Delete all Data
//#		  25    Family Find Add
//#
//#----------------------------------------------------------------------------------------------

	switch ($option)
	{

		case 1:
			$name='census_page_family';			// Family details page
			family_details($template,$diocese_db,$name);	// Add Family Function
		break;
	
		case 2:

			 //#--------------------------------------------------------------------
			 //# Form validation
			 //#--------------------------------------------------------------------
			 	if(is_blank($last_name))
                         	{ 
                                	header_redirect( $_SERVER['PHP_SELF'] . '?option=1&error=No_Family_Name' ); 
                         	}

			 	if(is_blank($street))
				{
                                	header_redirect( $_SERVER['PHP_SELF'] . '?option=1&error=No_Address' ); 
				}

				if(is_blank($suburb_name))
                                {
                                        header_redirect( $_SERVER['PHP_SELF'] . '?option=1&error=No_Suburb' );    
                                }

			 	if( ! (is_valid_phone($home_phone))  )
			 	{
                                	header_redirect( $_SERVER['PHP_SELF'] . '?option=1&error=Bad_Phone_Number' ); 
			 	}

			 	if( ! (is_valid_phone($home_phone2))  )
			 	{
                               	 	header_redirect( $_SERVER['PHP_SELF'] . '?option=1&error=Bad_Second_Phone_Number' ); 
				}

			 	if( ! (is_valid_phone($home_fax))  )
			 	{
                                	header_redirect( $_SERVER['PHP_SELF'] . '?option=1&error=Bad_Fax_Number' ); 
			 	}

			 //#--------------------------------------------------------------------

			 $name='census_page_member';					// Family members page

		 	family_members($template,$diocese_db,$name,$family_members,$state_id,$last_name,$home_phone,$home_phone2,$home_fax,$street,$suburb_name,$post_code,$home_fax,$parish);		   // Get Family members data

		break;

		case 3:
				$name="census_page_success";				// Add Data to Database, and show results
				family_add_data(&$template,&$diocese_db,$name,$last_name,$home_phone,$home_phone2,$home_fax,$street,$suburb_name,$post_code,$state_id,$parish,$title,$first_name,$middle_name,$last_name,$email,$occupation,$mobile_phone,$gender,$dob,$mob,$yob,$primary_parish_id,$secondary_parish_id,$role,$family_members);
		break;

		case 4:									// Not in use 
			 access_ensure_not_standalone();                                // Check not in Standalone mode
		break;

		
		case 8:
			 access_ensure_not_standalone();                                // Check not in Standalone mode
			 $name='family_find_edit';                      		// Family Find and Edit  
                         family_find_and_edit($template,$diocese_db,$name);             // Family_Finad_And_edit Function
		break;
		
                case 9:
                         access_ensure_not_standalone();                                // Check not in Standalone mode
                         $name='family_list_for_edit';                                  // Family Find and Delete
                         family_list_for_edit($template,$diocese_db,$name,$parish,$last_name); // Family_Find_And_delete Function
                break;

	        case 10:
                         access_ensure_not_standalone();                                // Check not in Standalone mode
                         $name='family_edit';                                		// Family Find and Delete
                         family_edit_page($template,$diocese_db,$name,$family_id,$family_members); // Family_Find_And_delete Function
                break;

		case 11:
                         trigger_error( "Editing Family Members Information not yet implemented", E_USER_ERROR );
                         exit;
                break;
		
                case 16:
			 access_ensure_not_standalone();                                // Check not in Standalone mode
                         $name='family_find_delete';                      		// Family Find and Delete 
                         family_find_and_delete($template,$diocese_db,$name);  		// Family_Find_And_delete Function
                break;
		case 17:
			 access_ensure_not_standalone();				// Check not in Standalone mode
                         $name='family_list_for_delete';                      		// Family Find and Delete 
                         family_list_for_delete($template,$diocese_db,$name,$parish,$last_name); // Family_Find_And_delete Function
                break;

		case 18:
                         access_ensure_not_standalone();                                // Check not in Standalone mode
                         $name='family_deleted';                                	// Family Find and Delete
                         family_delete_all_data($template,$diocese_db,$name,$family_id); // Family_Find_And_delete Function
                break;

		case 25:
                         access_ensure_not_standalone();                                // Check not in Standalone mode
                         $name='family_find_add';                                    // Family Find and Delete
                         family_find_add($template,$diocese_db,$name);           // Family_Find_And_delete Function
                break;



		case 35:
                         access_ensure_not_standalone();                                // Check not in Standalone mode
                         $name='family_find_move';                                    // Family Find and Delete
                         family_find_move($template,$diocese_db,$name);           // Family_Find_And_delete Function
                break;

		default:
			    $name='census_page_family';			            // Family details page
			    family_details($template,$diocese_db,$name);	// Add Family Function
		break;
	}
//#----------------------------------------------------------------------------------------------





//#----------------------------------------------------------------------------------------------
//# Routine:		Main Menu
//# Creation:     	18/04/2004
//# Description:	Displays the Main Family Admin Menu
//# Reference:
//# History:
//#----------------------------------------------------------------------------------------------
function main_menu(&$template,$name)
{

	$template->assign( 'action_page', $_SERVER['PHP_SELF'] );	// Define Actioning PHP page
  	$template->run($name);						// Execute template
}



//#----------------------------------------------------------------------------------------------
//# Routine:		Family Details
//# Creation:     	18/04/2004
//# Description:	
//#			From this point you will be asked to enter the Generic family details info.
//#			This includes selecting how many family members there are in your family (Max 10).
//#			The $family_members field will be used to create the appropriate number of 
//# 			family member information boxes.  The template page that is run on completion 
//#			of this script will set the $option value to '2' (value must have been '1' to 
//#			have reached this function).  If data is deemed to be invalid then the $error
//#			value will be set to '1'.  Values other than NULL will result in an error message
//#			and a request to re-enter the page details again. 
//# Reference:
//# History:
//#----------------------------------------------------------------------------------------------
function family_details(&$template,&$diocese_db,$name)
{


	//#----------------------------------------------------------------------------------------------
	//# CONNECT TO DB 
	//#----------------------------------------------------------------------------------------------
	  $diocese_db->connect();                                               // Establish connection to DB


	//#----------------------------------------------------------------------------------------------
	//# DEFINE OR RETRIEVE DATA FOR PAGE 
	//#----------------------------------------------------------------------------------------------
	  $t_states   = states_get_id_name_map();                               // Get state mappings (address_inc.php)
	  $t_state_ids = array_keys( $t_states );                               // Get Internal Values for States
	  $t_state_names = array_values( $t_states );                           // Get State Name Values for page
	  $t_family_values = array( '1','2','3','4','5','6','7','8','9','10');  // Define 'family_members' values
          $t_parishes = parish_get_id_name_map();                               // Get parish mapping (parish_inc.php)
          $t_parish_ids = array_keys( $t_parishes );                            // Get Internal parish values
	  $t_parish_names = array_values( $t_parishes );                        // Get Parish Names for page


	//#----------------------------------------------------------------------------------------------
	//# Prepare and Execute the template
	//#----------------------------------------------------------------------------------------------
	  $template->assign( 'action_page',        $_SERVER['PHP_SELF'] );      // Define Actioning PHP page
	  $template->assign( 'state_ids',          $t_state_ids );              // Assign values for 'state_ids'
	  $template->assign( 'state_initials',     $t_state_names );            // Assign values for 'state_names'
	  $template->assign( 'family_members',     'family_members' );        	// Assign Field name
	  $template->assign( 'family_values',      $t_family_values );          // Assign values for 'family_members'
	  $template->assign( 'state_id',           'state_id' );                // Assign Field Name
	  $template->assign( 'last_name',          'last_name' );               // Assign Field Name
	  $template->assign( 'home_phone',         'home_phone' );              // Assign Field Name
	  $template->assign( 'home_phone2',        'home_phone2' );             // Assign Field Name
	  $template->assign( 'home_fax',           'home_fax' );                // Assign Field Name
	  $template->assign( 'street',             'street' );                  // Assign Field Name
	  $template->assign( 'suburb_name',        'suburb_name' );             // Assign Field Name
	  $template->assign( 'post_code',          'post_code' );               // Assign Field Name
	  $template->assign( 'home_fax',           'home_fax' );                // Assign Field Name
	  $template->assign( 'parish',             'parish' );                  // Assign Field Name
          $template->assign( 'parish_ids',         $t_parish_ids );             // Assign values for 'parish_ids'
          $template->assign( 'parish_names',       $t_parish_names );           // Assign values for 'parish_names'

	  $template->run($name);                                		// Execute template

}


//#----------------------------------------------------------------------------------------------
//# Routine:		Family Members Page
//# Creation:     	18/03/2004
//# Description:	Add details for each of the members of te family
//# Reference:		Once the option field has been set to '2' and successfully passed form based
//# 			and code based field validation, it will then add the currently collected
//#			Family information to the html page as hidden fields.  It will then apply
//#			the "last_name','Parish' answers as default to all family member dialogs.
//#			These be changed as further detail is entered.   Please note that one dialog
//#			will be created for each family member ( as per the previous form $family_members).
//#			If you want to change this, use the Java 'Back' buttond, and change the drop down
//#			selection that refers to family members (Max is 10). 
//# History:
//#----------------------------------------------------------------------------------------------
function family_members(&$template,&$diocese_db,$name,$family_members,$state_id,$last_name,$home_phone,$home_phone2,$home_fax,$street,$suburb_name,$post_code,$home_fax,$parish)
{


	//#----------------------------------------------------------------------------------------------
	//# CONNECT TO DB 
	//#----------------------------------------------------------------------------------------------
	  $diocese_db->connect();                                               // Establish connection to DB


	//#----------------------------------------------------------------------------------------------
	//# DEFINE OR RETRIEVE DATA FOR PAGE
	//#----------------------------------------------------------------------------------------------
	  $t_parishes = parish_get_id_name_map();                               // Get parish mapping (parish_inc.php)
	  $t_parish_ids = array_keys( $t_parishes );                            // Get Internal parish values
	  $t_parish_names = array_values( $t_parishes );                        // Get Parish Names for page
	  $t_roles = family_member_get_role_id_name_map();			// Get Roler Mapping ( )
	  $t_role_ids = array_keys( $t_roles );					// Get Role Values
	  $t_role_names = array_values( $t_roles);				// Get Role Names
	  $t_genders = gender_get_id_name_map();				// Get Genders Mapping
	  $t_gender_ids = array_keys( $t_genders );				// Get Gender Values
	  $t_gender_names = array_values( $t_genders );				// Get Gender Names
	  $t_title_names = title_get_all();					// Get title values



	//#----------------------------------------------------------------------------------------------
	//# Prepare and Execute the template
	//#----------------------------------------------------------------------------------------------
	  $template->assign( 'action_page',        $_SERVER['PHP_SELF'] );      // Define Actioning PHP page
	  $template->assign( 'max_family_members', array_fill( 1, $family_members, '' ) ); // Number of family member templates
	  $template->assign( 'parish_ids',         $t_parish_ids );             // Assign values for 'parish_ids'
	  $template->assign( 'parish_names',       $t_parish_names );           // Assign values for 'parish_names'
	  $template->assign( 'parish',             'parish');                   // Assign values for 'parish_names'
	  $template->assign( 'parish_value',       $parish );                   // Assign values for 'parish_names'
	  $template->assign( 'role_ids',           $t_role_ids );               // Assign values for 'role_ids'
	  $template->assign( 'role_names',         $t_role_names );             // Assign values for 'role_names'
	  $template->assign( 'gender_ids',         $t_gender_ids );             // Assign values for 'gender_ids'
	  $template->assign( 'gender_names',       $t_gender_names );           // Assign values for 'gender_names'
	  $template->assign( 'title_names',        $t_title_names );            // Assign values for 'title_names'
	//#----------------------------------------------------------------------------------------------
	  $template->assign( 'familymembers',      $family_members );           // Get value from previous page 
	  $template->assign( 'stateid',            $state_id );                 // Get value from previous page
	  $template->assign( 'lastname',           $last_name );                // Get value from previous page 
	  $template->assign( 'homephone',          $home_phone );               // Get value from previous page
	  $template->assign( 'homephone2',         $home_phone2 );              // Get value from previous page
	  $template->assign( 'homefax',            $home_fax );                 // Get value from previous page
	  $template->assign( 'street_name',        $street );                   // Get value from previous page
	  $template->assign( 'suburbname',         $suburb_name );              // Get value from previous page
	  $template->assign( 'postcode',           $post_code );                // Get value from previous page 
	  $template->assign( 'homefax',            $home_fax );                 // Get value from previous page 
	//#----------------------------------------------------------------------------------------------
	  $template->assign( 'family_members',     'family_members' );          // Assign Field Name
	  $template->assign( 'state_id',           'state_id' );                // Assign Field Name
	  $template->assign( 'last_name',          'last_name' );               // Assign Field Name
	  $template->assign( 'home_phone',         'home_phone' );              // Assign Field Name
	  $template->assign( 'home_phone2',        'home_phone2' );             // Assign Field Name
	  $template->assign( 'home_fax',           'home_fax' );                // Assign Field Name
	  $template->assign( 'street',             'street' );                  // Assign Field Name
	  $template->assign( 'suburb_name',        'suburb_name' );             // Assign Field Name
	  $template->assign( 'post_code',          'post_code' );               // Assign Field Name
	  $template->assign( 'home_fax',           'home_fax' );                // Assign Field Name
	//#----------------------------------------------------------------------------------------------
	  $template->assign( 'title',               'title[]' );                // Assign Field Name
	  $template->assign( 'first_name',          'first_name[]' );           // Assign Field Name
	  $template->assign( 'middle_name',         'middle_name[]' );          // Assign Field Name
	  $template->assign( 'last_name',           'last_name[]' );            // Assign Field Name
	  $template->assign( 'email',               'email[]' );                // Assign Field Name
	  $template->assign( 'occupation',          'occupation[]' );           // Assign Field Name
	  $template->assign( 'mobile_phone',        'mobile_phone[]' );         // Assign Field Name
	  $template->assign( 'dob',                 'dob[]' );			// Assign Field Name
	  $template->assign( 'mob',                 'mob[]' );			// Assign Field Name
	  $template->assign( 'yob',                 'yob[]' );			// Assign Field Name
	  $template->assign( 'gender',              'gender[]' );		// Assign Field Name
	  $template->assign( 'primary_parish_id',   'primary_parish_id[]' );    // Assign Field Name
	  $template->assign( 'secondary_parish_id', 'secondary_parish_id[]' );  // Assign Field Name
	  $template->assign( 'role',                'role[]' );                 // Assign Field Name


	  $template->run($name);                                		// Execute template


}


//#----------------------------------------------------------------------------------------------
//# Routine:            Family Add Data 
//# Creation:           18/03/2004
//# Description:
//# Reference:		Fields are escapes before inserting them into an SQL statment, then they
//#			are inserted in the approriate tables 'core_families', 'core_addresses'.
//#			Please note, 'core_postal_address' is NOT inserted here as there is not
//#			reference to such information of the originating form.
//#			Family Members are inserted into the 'Core_Parishioners' table, and associated
//#			by family_id and Role int the 'core_family_members'; 
//# History:
//#----------------------------------------------------------------------------------------------
function family_add_data(&$template,&$diocese_db,$name,$last_name,$home_phone,$home_phone2,$home_fax,$street,$suburb_name,$post_code,$state_id,$parish,$title,$first_name,$middle_name,$last_name,$email,$occupation,$mobile_phone,$gender,$dob,$mob,$yob,$primary_parish_id,$secondary_parish_id,$role,$family_members)
{
	global $cfg_standalone;


        //#----------------------------------------------------------------------------------------------
        //# CONNECT TO DB
        //#----------------------------------------------------------------------------------------------
    	$diocese_db->connect(); 						//connect to database

	$t_core_suburbs = table( 'core_suburbs' );
	$t_core_addresses = table( 'core_addresses' );
	$t_core_families = table( 'core_families' );
	$t_core_parishioners = table( 'core_parishioners' );
	$t_core_family_members = table( 'core_family_members' );

        //#----------------------------------------------------------------------------------------------
	//# Escape variables before injecting them in SQL
        //#----------------------------------------------------------------------------------------------
    	$sql_parish_id     = db_prepare_string( $parish );			//
    	$sql_last_name     = db_prepare_string( $last_name[0] );		//
    	$sql_home_phone    = db_prepare_string( $home_phone );			//
    	$sql_home_phone2   = db_prepare_string( $home_phone2 );			//
    	$sql_home_fax      = db_prepare_string( $home_fax );			//
    	$sql_street        = db_prepare_string( $street );			//
    	$sql_suburb_name   = db_prepare_string( $suburb_name );			//
    	$sql_post_code     = db_prepare_string( $post_code);			//
    	$sql_state_id      = db_prepare_string( $state_id );			//
        $sql_now           = $diocese_db->prepare_timestamp( time() );
	$sql_approved      = $cfg_standalone ? 0 : 1;

        //#----------------------------------------------------------------------------------------------
    	//# Insert or Update Suburb
        //#----------------------------------------------------------------------------------------------

    	$query = "SELECT * FROM $t_core_suburbs WHERE name = $sql_suburb_name AND state_id = $sql_state_id AND post_code = $sql_post_code";
    	
	$suburbRecordSet = $diocese_db->execute( $query );

    	$suburb = array();
    	$suburb['name'] = $suburb_name;
    	$suburb['state_id'] = $state_id;
    	$suburb['post_code'] = $post_code;

    	if ( $suburbRecordSet->EOF )
    	{
        	$query = $diocese_db->_adodb->GetInsertSQL( $suburbRecordSet, $suburb );
        	$new_suburb_id = $diocese_db->get_insert_id();

        	$suburbRecordSet = &$diocese_db->execute( $query );
    	}
    	else
    	{
        	$new_suburb_id = $suburbRecordSet->fields['suburb_id'];
    	}
 

	$query1 = "SELECT suburb_id from $t_core_suburbs where name = $sql_suburb_name and post_code = $sql_post_code";
	$rs=$diocese_db->execute( $query1);
        while ( !$rs->EOF )
        {
                $new_suburb_id = $rs->fields['suburb_id'];
         	$rs->MoveNext();  //  Moves to the next row

	}

        //#----------------------------------------------------------------------------------------------
    	//# Insert Address
        //#----------------------------------------------------------------------------------------------

    	$add_address = "INSERT INTO $t_core_addresses (street, suburb_id) VALUES ($sql_street, $new_suburb_id)";
    	$recordSet2 = &$diocese_db->execute( $add_address );
    	$new_address_id = $diocese_db->get_insert_id();


        //#----------------------------------------------------------------------------------------------
    	//# Insert Family
        //#----------------------------------------------------------------------------------------------

    	$add_family = "INSERT INTO $t_core_families (last_name, address_id, home_phone, home_phone2, home_fax, parish_id, approved, date_added, date_updated) VALUES ($sql_last_name, $new_address_id, $sql_home_phone, $sql_home_phone2, $sql_home_fax, $sql_parish_id, $sql_approved, $sql_now, $sql_now)";
    
	$recordSet3 = &$diocese_db->execute( $add_family );
    	$family_id = $diocese_db->get_insert_id();				// Get Family ID


        //#----------------------------------------------------------------------------------------------
	//# All all Family Member information 
        //#----------------------------------------------------------------------------------------------
	for($X=0;$X<$family_members;$X++)
	{

        $birthday = &new Date;
        $birthday->Set( $yob[$X], $mob[$X], $dob[$X] );

        //#----------------------------------------------------------------------------------------------
        //# Escape variables before injecting them in SQL
        //#----------------------------------------------------------------------------------------------
        $sql_title      	= db_prepare_string( $title[$X] );                     	// Title
        $sql_first_name 	= db_prepare_string( $first_name[$X] );                 // First Name
        $sql_middle_name 	= db_prepare_string( $middle_name[$X] );                // Middle Name
        $sql_lastname 		= db_prepare_string( $last_name[$X] );                  // Surname
        $sql_email 		= db_prepare_string( $email[$X] );                     	// email
        $sql_occupation         = db_prepare_string( $occupation[$X] );                 // occupation
	$sql_gender		= db_prepare_string( $gender[$X] );
        $sql_mobile 		= db_prepare_string( $mobile_phone[$X] );              	// Mobile Number
	$sql_birthday		= db_prepare_string( $birthday->ToString() );		// Formated Birthday
        $sql_prim_parish 	= db_prepare_string( $primary_parish_id[$X] );          // Primary Parish 
        $sql_sec_parish 	= db_prepare_string( $secondary_parish_id[$X] );        // Secondary Parish
        $sql_role 		= db_prepare_string( $role[$X] );                	// Role
	
        //#----------------------------------------------------------------------------------------------
	//# Insert Parishioners
        //#----------------------------------------------------------------------------------------------
	$add_parishioner="INSERT INTO $t_core_parishioners (title,first_name,middle_name,last_name,email,occupation,date_of_birth,gender,daytime_phone,mobile_phone,primary_parish_id,secondary_parish_id,approved,date_added,date_updated) VALUES ($sql_title,$sql_first_name,$sql_middle_name,$sql_lastname,$sql_email,$sql_occupation,$sql_birthday,$sql_gender,$sql_home_phone,$sql_mobile,$sql_prim_parish,$sql_sec_parish, $sql_approved, $sql_now, $sql_now)";

	$recordSet4 = &$diocese_db->execute( $add_parishioner );			// Insert new parishioner
    	$new_parishioner_id = $diocese_db->get_insert_id();				// Get parishioner ID



        //#----------------------------------------------------------------------------------------------
        //# Insert 'Core_Family_Members'
        //#----------------------------------------------------------------------------------------------
        $add_corefamilymembers="INSERT INTO $t_core_family_members (family_id,parishioner_id,role) VALUES ('$family_id','$new_parishioner_id','$role[$X]')";

        $recordSet5 = &$diocese_db->execute( $add_corefamilymembers );                    // Insert new Core Family Members 



	}

	#
	# Redirect to family_view_page to display details about the added family
	#
	$t_url = 'family_view_page.php?family_id=' . $family_id;
	if ( access_is_standalone() )
        {
	        $t_calculated_pass = access_encrypt( 'family_view' . $family_id );
		$t_url .= '&pass=' . $t_calculated_pass;
        }
	header_redirect( $t_url );
}




//#----------------------------------------------------------------------------------------------
//# Routine:            Family find and edit
//# Creation:           18/03/2004
//# Description:        Give options to select the appropriate family record you wish to edit.
//# Reference:
//# History:
//#----------------------------------------------------------------------------------------------
function family_find_add(&$template,&$diocese_db,$name)
{

        //#----------------------------------------------------------------------------------------------
        //# CONNECT TO DB
        //#----------------------------------------------------------------------------------------------
        $diocese_db->connect();                                               // Establish connection to DB
        $template->assign( 'last_name',    'last_name' );             	      // Assign field name 
        $template->assign( 'action_page', $_SERVER['PHP_SELF'] );             // Define Actioning PHP page

        //#----------------------------------------------------------------------------------------------

          $template->run($name);                                                // Execute template

}



//#----------------------------------------------------------------------------------------------
//# Routine:            Family find and move 
//# Creation:           18/03/2004
//# Description:        Give options to select the appropriate family record you wish to edit.
//# Reference:
//# History:
//#----------------------------------------------------------------------------------------------
function family_find_move(&$template,&$diocese_db,$name)
{

        //#----------------------------------------------------------------------------------------------
        //# CONNECT TO DB
        //#----------------------------------------------------------------------------------------------
        $diocese_db->connect();                                               // Establish connection to DB
        $template->assign( 'last_name',    'last_name' );                     // Assign field name
        $template->assign( 'action_page', $_SERVER['PHP_SELF'] );             // Define Actioning PHP page

        //#----------------------------------------------------------------------------------------------

          $template->run($name);                                                // Execute template

}


//#----------------------------------------------------------------------------------------------
//# Routine:            Family find and edit 
//# Creation:           18/03/2004
//# Description:        Give options to select the appropriate family record you wish to edit. 
//# Reference:
//# History:
//#----------------------------------------------------------------------------------------------
function family_find_and_edit(&$template,&$diocese_db,$name)
{

	//#----------------------------------------------------------------------------------------------
	//# CONNECT TO DB
	//#----------------------------------------------------------------------------------------------
  	$diocese_db->connect();                                               	// Establish connection to DB


	//#----------------------------------------------------------------------------------------------
	//# DEFINE OR RETRIEVE DATA FOR PAGE
	//#----------------------------------------------------------------------------------------------
	  $t_states   = states_get_id_name_map( array( '' => 'any' ) );	       // Get state mappings (address_inc.php)
	  $t_state_ids = array_keys( $t_states );                              // Get Internal Values for States
 	  $t_state_names = array_values( $t_states );                          // Get State Name Values for page
          $t_state_names = array_values( $t_states );                          // Get State Name Values for page
          $t_parishes = parish_get_id_name_map();        		       // Get parish mapping (parish_inc.php)
          $t_parish_ids = array_keys( $t_parishes );                           // Get Internal parish values
          $t_parish_names = array_values( $t_parishes );                       // Get Parish Names for page

	  if ( access_limited_to_one_parish() )
	     $t_parishes = parish_get_id_name_map();  
	  else
	     $t_parishes = parish_get_id_name_map( array( '' => 'any' ) );  

	  $t_parish_ids = array_keys( $t_parishes );
	  $t_parish_names = array_values( $t_parishes );

	//#----------------------------------------------------------------------------------------------

	  $template->assign( 'state_ids',          $t_state_ids );              // Assign values for 'state_ids'
	  $template->assign( 'state_initials',     $t_state_names );            // Assign values for 'state_names'
	  $template->assign( 'parish_ids',	   $t_parish_ids );
	  $template->assign( 'parish_names',	   $t_parish_names );
	  $template->assign( 'parish',		   'parish' );
	  $template->assign( 'action_page', $_SERVER['PHP_SELF'] );       	// Define Actioning PHP page
  	  $template->assign( 'state_id',           'state_id' );                // Assign Field Name
          $template->assign( 'last_name',          'last_name' );               // Assign Field Name
          $template->assign( 'home_phone',         'home_phone' );              // Assign Field Name
  	  $template->assign( 'home_phone2',        'home_phone2' );             // Assign Field Name
  	  $template->assign( 'home_fax',           'home_fax' );                // Assign Field Name
  	  $template->assign( 'street',             'street' );                  // Assign Field Name
  	  $template->assign( 'suburb_name',        'suburb_name' );             // Assign Field Name
  	  $template->assign( 'post_code',          'post_code' );               // Assign Field Name
  	  $template->assign( 'home_fax',           'home_fax' );                // Assign Field Name
  	  $template->assign( 'parish',             'parish' );                  // Assign Field Name
  	  $template->assign( 'parish_ids',         $t_parish_ids );             // Get field values
  	  $template->assign( 'parish_names',       $t_parish_names );           // Get field values 
	

	//#----------------------------------------------------------------------------------------------

	  $template->run($name);                                          	// Execute template

}




//#----------------------------------------------------------------------------------------------
//# Routine:            Family find and edit 
//# Description:
//# Reference:
//# History:
//#----------------------------------------------------------------------------------------------
function family_list_for_edit(&$template,&$diocese_db,$name,$parish,$last_name)
{

        //#----------------------------------------------------------------------------------------------
        //# CONNECT TO DB
        //#----------------------------------------------------------------------------------------------
        $diocese_db->connect();                                                 // Establish connection to DB

	$t_core_families = table( 'core_families' );
	$t_core_family_members = table( 'core_family_members' );
	$t_core_parishioners = table( 'core_parishioners' );

        //#----------------------------------------------------------------------------------------------
        //# DEFINE OR RETRIEVE DATA FOR PAGE
        //#----------------------------------------------------------------------------------------------
          $t_states   = states_get_id_name_map( array( '' => 'any' ) );         // Get state mappings (address_inc.php)
          $t_state_ids = array_keys( $t_states );                               // Get Internal Values for States
          $t_state_names = array_values( $t_states );                           // Get State Name Values for page
          $t_parishes = parish_get_id_name_map();                               // Get parish mapping (parish_inc.php)
          $t_parish_ids = array_keys( $t_parishes );                            // Get Internal parish values
          $t_parish_names = array_values( $t_parishes );                        // Get Parish Names for page

        //#----------------------------------------------------------------------------------------------


        //#----------------------------------------------------------------------------------------------
        //# Search Variables
        //#----------------------------------------------------------------------------------------------

        $sql_lastname      = db_prepare_string( $last_name );                   //
        $sql_parish      = db_prepare_string( $parish );                     //


	$query = "SELECT DISTINCT ( family_id ), last_name, home_phone, home_fax, parish_id FROM $t_core_families WHERE (1 = 1)";

	if ( $last_name != '' )
	{
		$query .= " AND ( last_name LIKE $sql_lastname )";
	}
	if ( $parish != '' )
	{
		$query .= " AND ( parish_id = $sql_parish )";
	}


        $recordSet4 = &$diocese_db->execute( $query );                        // Insert new parishioner
        $records =0;                                                          // Number of returned records


        while ( !$recordSet4->EOF )
        {
		$family_members[$records]=0;
                $family_id[$records] = $recordSet4->fields['family_id'];
                $lastname[$records] = $recordSet4->fields['last_name'];
                $home_phone[$records] = $recordSet4->fields['home_phone'];
                $home_fax[$records] = $recordSet4->fields['home_fax'];
                $parish_id[$records] = $recordSet4->fields['parish_id'];
                $recordSet4->MoveNext();  //  Moves to the next row

                $query1="SELECT p.first_name FROM $t_core_parishioners AS p, $t_core_families AS f, $t_core_family_members AS fm WHERE f.family_id = fm.family_id AND fm.parishioner_id = p.parishioner_id and f.family_id=$family_id[$records]";
                $recordSet5 = &$diocese_db->execute( $query1 );                        // Insert new parishioner

		$t_family_names = array();
                while (!$recordSet5->EOF)
                {
                        $t_family_names[] = $recordSet5->fields['first_name'];
                        $recordSet5->MoveNext();  //  Moves to the next row
			$family_members[$records]++;
                }

		$family_names[$records] = implode( ', ', $t_family_names );

                $records++;

        }  // end while


        if($records < 0 )
        {
                $family_id=0;                                                   // Insert null value into family_id
                $void_return=1;                                                 // Set VOID result flag
        }
        else
        {
                $void_return=0;                                                 // UnSet VOID result flag
        }

         $template->assign( 'family_id',           $family_id );
         $template->assign( 'last_name',           $lastname );
         $template->assign( 'home_phone',          $home_phone );
         $template->assign( 'home_fax',            $home_fax );
         $template->assign( 'parish_id',           $parish_id );
         $template->assign( 'family_names',        $family_names );
         $template->assign( 'family_members',      $family_members );
         $template->assign( 'records',             $records );
         $template->assign( 'void_return',         $void_return );
         $template->assign( 'parish_ids',         $t_parish_ids );             // Assign values for 'parish_ids'
         $template->assign( 'parish_names',       $t_parish_names );           // Assign values for 'parish_names'
         $template->assign( 'parish',             'parish');                   // Assign values for 'parish_names'
         $template->assign( 'action_page', $_SERVER['PHP_SELF'] );             // Define Actioning PHP page

        //#----------------------------------------------------------------------------------------------

          $template->run($name);                                                // Execute template

}




//#----------------------------------------------------------------------------------------------
//# Routine:            Family edit page
//# Description:
//# Reference:
//# History:
//#----------------------------------------------------------------------------------------------
function family_edit_page(&$template,&$diocese_db,$name,$family_id,$family_members)
{

        //#----------------------------------------------------------------------------------------------
        //# CONNECT TO DB
        //#----------------------------------------------------------------------------------------------
        $diocese_db->connect();                                                 // Establish connection to DB

	$t_core_families = table( 'core_families' );
	$t_core_addresses = table( 'core_addresses' );
	$t_core_suburbs = table( 'core_suburbs' );

        //#----------------------------------------------------------------------------------------------
        //# DEFINE OR RETRIEVE DATA FOR PAGE
        //#----------------------------------------------------------------------------------------------
          $t_states   = states_get_id_name_map( array( '' => 'any' ) );         // Get state mappings (address_inc.php)
          $t_state_ids = array_keys( $t_states );                               // Get Internal Values for States
          $t_state_names = array_values( $t_states );                           // Get State Name Values for page
	  $t_family_values = array( '1','2','3','4','5','6','7','8','9','10');  // Define 'family_members' values
          $t_parishes = parish_get_id_name_map( array( '' => 'any' ) );         // Get parish mapping (parish_inc.php)
          $t_parish_ids = array_keys( $t_parishes );                            // Get Internal parish values
          $t_parish_names = array_values( $t_parishes );                        // Get Parish Names for page

        //#----------------------------------------------------------------------------------------------


        //#----------------------------------------------------------------------------------------------
        //# Search Variables
        //#----------------------------------------------------------------------------------------------

        $sql_family_id      = db_prepare_string( $family_id );                   //

        $query = "SELECT DISTINCT ( family_id ), last_name, home_phone, home_phone2, home_fax,address_id, parish_id FROM $t_core_families where family_id =$sql_family_id";


        $recordSet4 = &$diocese_db->execute( $query );                        // Insert new parishioner

        while ( !$recordSet4->EOF )
        {
                $family_id = $recordSet4->fields['family_id'];
                $lastname = $recordSet4->fields['last_name'];
                $home_phone = $recordSet4->fields['home_phone'];
                $home_phone2 = $recordSet4->fields['home_phone2'];
                $home_fax = $recordSet4->fields['home_fax'];
                $parish_id = $recordSet4->fields['parish_id'];
		$address_id= $recordSet4->fields['address_id'];
		
        		$query1 = "SELECT street,suburb_id from $t_core_addresses where address_id=$address_id";
        		$recordSet5 = &$diocese_db->execute( $query1 );          
        		while ( !$recordSet5->EOF )
			{
				$street=$recordSet5->fields['street'];
				$suburb_id=$recordSet5->fields['suburb_id'];
                		$recordSet5->MoveNext();  //  Moves to the next row
			}
			
		     if($suburb_id !="")				      // Check that suburb variabl exists
		     {	
                        $query2 = "SELECT name, state_id, post_code from $t_core_suburbs where suburb_id=$suburb_id";
                        $recordSet6 = &$diocese_db->execute( $query2 );         
                        while ( !$recordSet6->EOF )
                        {
                                $suburb=$recordSet6->fields['name'];
                                $post_code=$recordSet6->fields['post_code'];
                                $statename=$recordSet6->fields['state_id'];
                                $recordSet6->MoveNext();  //  Moves to the next row
                        }
		     }
                $recordSet4->MoveNext();  //  Moves to the next row

        }  // end while


         $template->assign( 'family_id',           'family_id' );
         $template->assign( 'last_name',           'last_name' );
         $template->assign( 'home_phone',          'home_phone' );
         $template->assign( 'home_phone2',         'home_phone2' );
         $template->assign( 'home_fax',            'home_fax' );
         $template->assign( 'post_code',           'post_code' );
         $template->assign( 'parish_id',           'parish_id' );
         $template->assign( 'parish_names',        'parish_names' );
         $template->assign( 'parish',              'parish' );
         $template->assign( 'street',              'street' );
         $template->assign( 'suburb_name',         'suburb_name' );
         $template->assign( 'family_members_field','family_members_field' );


         $template->assign( 'family_id',          $family_id );
         $template->assign( 'family_members',     $family_members );
         $template->assign( 'family_values',      $t_family_values );
         $template->assign( 'lastname',           $lastname );
         $template->assign( 'homephone',          $home_phone );
         $template->assign( 'homephone2',         $home_phone2 );
         $template->assign( 'postcode',           $post_code );
         $template->assign( 'homefax',            $home_fax );
         $template->assign( 'parish_ids',         $t_parish_ids );             // Assign values for 'parish_ids'
         $template->assign( 'parish_names',       $t_parish_names );           // Assign values for 'parish_names'
         $template->assign( 'parish',             $parish_id);                 // Assign values for 'parish_names'
         $template->assign( 'streetname',         $street );
         $template->assign( 'suburbname',         $suburb );
         $template->assign( 'postcode',           $post_code );
         $template->assign( 'state_ids',          $t_state_ids );              // Assign values for 'state_ids'
         $template->assign( 'state_initials',     $t_state_names );            // Assign values for 'state_names' 
         $template->assign( 'statename',          $statename );                // Assign values for 'state_names' 


         $template->assign( 'action_page', $_SERVER['PHP_SELF'] );             // Define Actioning PHP page

        //#----------------------------------------------------------------------------------------------

          $template->run($name);                                                // Execute template

}











//#----------------------------------------------------------------------------------------------
//# Routine:            Family find and delete 
//# Creation:           18/03/2004
//# Description:	Get information to select the approprate family record to delete.
//# Reference:
//# History:
//#----------------------------------------------------------------------------------------------
function family_find_and_delete(&$template,&$diocese_db,$name)
{

	//#----------------------------------------------------------------------------------------------
        //# CONNECT TO DB
        //#----------------------------------------------------------------------------------------------
          $diocese_db->connect();                                               // Establish connection to DB


        //#----------------------------------------------------------------------------------------------
        //# DEFINE OR RETRIEVE DATA FOR PAGE
        //#----------------------------------------------------------------------------------------------
	  if ( access_limited_to_one_parish() )
	     $t_parishes = parish_get_id_name_map();  
	  else
	     $t_parishes = parish_get_id_name_map( array( '' => 'any' ) );  

	  $t_parish_ids = array_keys( $t_parishes );
	  $t_parish_names = array_values( $t_parishes );

        //#----------------------------------------------------------------------------------------------

          $template->assign( 'parish_ids',         $t_parish_ids );             // Assign values for 'parish_ids'
          $template->assign( 'parish_names',       $t_parish_names );           // Assign values for 'parish_names'
          $template->assign( 'parish',             'parish');                   // Assign values for 'parish_names'
          $template->assign( 'last_name',          'last_name' );               // Assign Field Name
          $template->assign( 'action_page', $_SERVER['PHP_SELF'] );             // Define Actioning PHP page
          $template->run($name);                                                // Execute template

}





//#----------------------------------------------------------------------------------------------
//# Routine:            Family list for delete
//# Creation:           18/03/2004
//# Description:        
//# Reference:
//# History:
//#----------------------------------------------------------------------------------------------
function family_list_for_delete(&$template,&$diocese_db,$name,$parish,$last_name)
{

        //#----------------------------------------------------------------------------------------------
        //# CONNECT TO DB
        //#----------------------------------------------------------------------------------------------
        $diocese_db->connect();                                                 // Establish connection to DB

	$t_core_families = table( 'core_families' );
	$t_core_parishioners = table( 'core_parishioners' );
	$t_core_family_members = table( 'core_family_members' );

        //#----------------------------------------------------------------------------------------------
        //# DEFINE OR RETRIEVE DATA FOR PAGE
        //#----------------------------------------------------------------------------------------------
          $t_states   = states_get_id_name_map( array( '' => 'any' ) );         // Get state mappings (address_inc.php)
          $t_state_ids = array_keys( $t_states );                               // Get Internal Values for States
          $t_state_names = array_values( $t_states );                           // Get State Name Values for page
          $t_parishes = parish_get_id_name_map();                               // Get parish mapping (parish_inc.php)
          $t_parish_ids = array_keys( $t_parishes );                            // Get Internal parish values
          $t_parish_names = array_values( $t_parishes );                        // Get Parish Names for page

        //#----------------------------------------------------------------------------------------------


        //#----------------------------------------------------------------------------------------------
	//# Search Variables
        //#----------------------------------------------------------------------------------------------

	$sql_lastname      = db_prepare_string( $last_name );                   //
	$sql_parish      = db_prepare_string( $parish );                     //


	$query = "SELECT DISTINCT ( family_id ), last_name, home_phone, home_fax, parish_id FROM $t_core_families WHERE (1 = 1)";

	if ( $last_name != '' )
	{
		$query .= " AND ( last_name LIKE $sql_lastname )";
	}

	if ( $parish != '' )
	{
		$query .= " AND ( parish_id = $sql_parish )";
	}


        $recordSet4 = &$diocese_db->execute( $query );                        // Insert new parishioner
	$records =0;							      // Number of returned records


  	while ( !$recordSet4->EOF )
    	{
        	$family_id[$records] = $recordSet4->fields['family_id'];
        	$lastname[$records] = $recordSet4->fields['last_name'];
        	$home_phone[$records] = $recordSet4->fields['home_phone'];
        	$home_fax[$records] = $recordSet4->fields['home_fax'];
        	$parish_id[$records] = $recordSet4->fields['parish_id'];
		$recordSet4->MoveNext();  //  Moves to the next row
		
		$query1="SELECT p.first_name FROM $t_core_parishioners AS p, $t_core_families AS f, $t_core_family_members AS fm WHERE f.family_id = fm.family_id AND fm.parishioner_id = p.parishioner_id and f.family_id=$family_id[$records]";
        	$recordSet5 = &$diocese_db->execute( $query1 );                        // Insert new parishioner

		$family_names[$records] = '';
		while (!$recordSet5->EOF)
		{
			$family_names[$records] .= $recordSet5->fields['first_name'];
			$family_names[$records] .=",";
			$recordSet5->MoveNext();  //  Moves to the next row
		}

		$records++;

    	}  // end while


	if($records < 0 )
	{
		$family_id=0;							// Insert null value into family_id
		$void_return=1;							// Set VOID result flag
	}
	else
	{
		$void_return=0;							// UnSet VOID result flag
	}


	 $template->assign( 'family_id',           $family_id );	
	 $template->assign( 'last_name',           $lastname );	
	 $template->assign( 'home_phone',          $home_phone );	
	 $template->assign( 'home_fax',            $home_fax );	
	 $template->assign( 'parish_id',           $parish_id );	
	 $template->assign( 'family_names',        $family_names );	
	 $template->assign( 'records',             $records );	
	 $template->assign( 'void_return',         $void_return );	
         $template->assign( 'parish_ids',         $t_parish_ids );             // Assign values for 'parish_ids'
         $template->assign( 'parish_names',       $t_parish_names );           // Assign values for 'parish_names'
         $template->assign( 'parish',             'parish');                   // Assign values for 'parish_names'
         $template->assign( 'action_page', $_SERVER['PHP_SELF'] );             // Define Actioning PHP page

        //#----------------------------------------------------------------------------------------------

          $template->run($name);                                                // Execute template

}





//#----------------------------------------------------------------------------------------------
//# Routine:            Family delete all data  
//# Creation:           18/03/2004
//# Description:	Delete all associated records to a family
//# Reference:
//# History:
//#----------------------------------------------------------------------------------------------
function family_delete_all_data(&$template,&$diocese_db,$name,$family_id)
{

        //#----------------------------------------------------------------------------------------------
        //# CONNECT TO DB
        //#----------------------------------------------------------------------------------------------
        $diocese_db->connect();                                                 // Establish connection to DB

        family_delete( $family_id );

        //#----------------------------------------------------------------------------------------------

         $template->assign( 'family_id',           $family_id );
         $template->assign( 'action_page', $_SERVER['PHP_SELF'] );             // Define Actioning PHP page

        //#----------------------------------------------------------------------------------------------

          $template->run($name);                                                // Execute template

}





//#----------------------------------------------------------------------------------------------
//# END
//#----------------------------------------------------------------------------------------------

?>
