<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: check.php,v 1.3 2004/10/14 10:50:36 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'src' .
                  DIRECTORY_SEPARATOR . 'common_inc.php' );

    require_once( $src_path . 'family_inc.php' );
    require_once( $src_path . 'family_member_inc.php' );
    require_once( $src_path . 'parishioner_inc.php' );
    require_once( $src_path . 'database_inc.php' );
    require_once( $src_path . 'address_inc.php' );
    require_once( $src_path . 'gpc_api_inc.php' );
    require_once( $src_path . 'access_api_inc.php' );

    access_ensure_not_standalone();

    disable_timeout();

    $diocese_db->connect();

    $t_core_parishioners = table( 'core_parishioners' );
    $t_core_family_members = table( 'core_family_members' );

    #
    # Check that all suburbs in the database are used.
    #

    $array_suburb_state_postcode = file( $src_path . 'au_suburb_state_postcode.csv' );

    for ( $i = 0; $i < count( $array_suburb_state_postcode ); $i++ )
        $array_suburb_state_postcode[$i] = trim( $array_suburb_state_postcode[$i] );

    $t_states_map = states_get_id_name_map();

    $t_suburb_ids = suburb_get_all_ids();
    $t_suburb_errors = array();

    foreach ( $t_suburb_ids as $t_suburb_id )
    {
        if ( !suburb_is_used( $t_suburb_id ) )
        {
            $t_suburb_name = suburb_get_name( $t_suburb_id );
            $t_suburb_errors[$t_suburb_id] = "Suburb '$t_suburb_name' is not used in any addresses.";
        }
        else
        {
            $t_state_id = suburb_get_field( $t_suburb_id, 'state_id' );
            $t_suburb_state = strtoupper( $t_states_map[ $t_state_id ] );
            $t_suburb_name = strtoupper( suburb_get_name( $t_suburb_id ) );
            $t_suburb_postcode = strtoupper( suburb_get_field( $t_suburb_id, 'post_code' ) );

            $t_key = "$t_suburb_name,$t_suburb_state,$t_suburb_postcode";
// echo $t_suburb_id . '    ' . $t_state_id . '    ' . $t_key . '<br />'; flush();
            if ( !in_array( $t_key, $array_suburb_state_postcode ) )
                $t_suburb_errors[$t_suburb_id] = "Unknown suburb '$t_key'";
        }
    }

    unset( $array_suburb_state_postcode );
    unset( $t_state_map );
    unset( $t_suburb_ids );

    
    #
    # Check all family records for valid values in the different fields
    #

    $t_family_errors = array();
    $t_family_ids = family_get_all_ids();

    foreach ( $t_family_ids as $t_family_id )
    {
        $family = $diocese_db->family_load( $t_family_id );
        $return = $family->validate();

        if ( $return !== true )
            $t_family_errors[$t_family_id] = implode( '<br />', $return );
    }

    unset( $t_family_ids );


    #
    # Check all parishioner records for valid values in the different fields
    #

    $t_parishioner_errors = array();
    $t_parishioner_ids = parishioner_get_all_ids();

    foreach ( $t_parishioner_ids as $t_parishioner_id )
    {
        $parishioner = $diocese_db->parishioner_load( $t_parishioner_id );
        $return = $parishioner->validate();

        if ( $return !== true )
            $t_parishioner_errors[$t_parishioner_id] = implode( '<br />', $return );
    }

    unset( $t_parishioner_ids );

    $template->assign( 'suburb_errors',       $t_suburb_errors );
    $template->assign( 'family_errors',       $t_family_errors );
    $template->assign( 'parishioner_errors',  $t_parishioner_errors );

    $template->run( 'check' );
?>