<?php
/*
#----------------------------------------------------------------------------------------------
#
#  Reference:  	E-ARK  -  Census Management Page
#
#  File:     	~/family_admin.php 
#  Project:    	E-ARK
#  Version:     $Id: family_admin.php,v 1.2 2004/04/15 13:59:11 vboctor Exp $	
#  State:       Beta
#  Author:      Ian Atherton
#  Creation:    17/03/2004
#
#
#  Comments:    
#
#  Routines:
#       Routine                     Date            Description
#       -----------------------------------------------------------------------
#
#
#  Update History:
#       -----------------------------------------------------------------------
#       $Log: family_admin.php,v $
#       Revision 1.2  2004/04/15 13:59:11  vboctor
#       M family_admin.php
#       - State field was not updated and the current value was not sent to the template correctly.
#
#       M src/address_inc.php
#       - (state_get_id): Added to get state id given state initials.
#       - (state_get_field): Gets the value of the specified field from the state with the specified id.
#
#       M src/family_inc.php
#       - Re-implemented family_update(), the new implementation is much simpler since it uses family/address loading/saving implemented in database_inc.php.  It also fixes some issues.
#
#       M src/database_inc.php
#       - Fixing some issues in handling address update.  Currently, when an address is updated, changes in suburb name, or state/post code will cause the creation of a new suburb and using it from the family address.  This will not affect other families using the old suburb name.  This is important if a family moved from suburb X to Y, we don't want all other families in suburb X to move to Y as well!
#
#       M templates/family_edit.tpl
#       - The states combo box was not initialised correctly.
#
#       Revision 1.1  2004/04/13 10:51:16  iatherton
#       Extension to the family_view.php page for managing details
#
#
#
#  Documentation Details:
#       -----------------------------------------------------------------------
#       Code Documenton:        
#       Author:                 Ian Atherton
#       Contact Number:         0409656609
#       Email:                  Iatherton@users.sourceforge.net 
#
#
#  Terms of Use:
#       -----------------------------------------------------------------------
#  	Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
#  	This program is distributed under the terms and conditions of the GPL
#  	See the README and LICENSE files for details
#
#----------------------------------------------------------------------------------------------
*/
 
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'src' .
                  DIRECTORY_SEPARATOR . 'common_inc.php' );

    require_once( $src_path . 'family_inc.php' );
    require_once( $src_path . 'family_member_inc.php' );
    require_once( $src_path . 'parishioner_inc.php' );
    require_once( $src_path . 'database_inc.php' );
    require_once( $src_path . 'address_inc.php' );
    require_once( $src_path . 'gpc_api_inc.php' );
    require_once( $src_path . 'access_api_inc.php' );
 
     //--------------------------------------------------------
    // CHECK SUPPLIED VALUES BEFORE RUNNING SCRIPT      
    //--------------------------------------------------------
    if($cfg_standalone == true)					                        // System is not in standalone mode
    {
            trigger_error("Illegal Action",E_USER_ERROR);
            exit;
    }

    
  
    $diocese_db->connect();
    
    //--------------------------------------------------------
    // Direct Page functionality
    //--------------------------------------------------------
    switch ($option)
	{
		
	    case 'edit':
	    
	       access_ensure_to_family( $family_id );

           $family =& $diocese_db->family_load( $family_id );
           if ( $family === false )
           {
                $template->assign( 'family_id', $family_id );
                $template->run( 'family_not_found' );
                exit;
           }

            $address =& $diocese_db->address_load( $family->get_address_id() );

            $template->assign( 'family',          $family );
            $template->assign( 'address',         $address );
	    
	    	//#----------------------------------------------------------------------------------------------
	        //# DEFINE OR RETRIEVE DATA FOR PAGE 
	        //#----------------------------------------------------------------------------------------------
	        $t_states   = states_get_id_name_map();                               // Get state mappings (address_inc.php)
	        $t_state_ids = array_keys( $t_states );                               // Get Internal Values for States
	        $t_state_names = array_values( $t_states );                           // Get State Name Values for page
                $t_current_state_id = state_get_id( $address->get_state() );
            $t_parishes = parish_get_id_name_map();                               // Get parish mapping (parish_inc.php)
            $t_parish_ids = array_keys( $t_parishes );                            // Get Internal parish values
	        $t_parish_names = array_values( $t_parishes );                        // Get Parish Names for page


	        //#----------------------------------------------------------------------------------------------
	        //# Prepare and Execute the template
	        //#----------------------------------------------------------------------------------------------
	        $template->assign( 'state_ids',          $t_state_ids );              // Assign values for 'state_ids'
	        $template->assign( 'state_initials',     $t_state_names );            // Assign values for 'state_names'
                $template->assign( 'current_state_id',   $t_current_state_id );
	        $template->assign( 'state_id',           'state_id' );                // Assign Field Name
	        $template->assign( 'last_name',          'last_name' );               // Assign Field Name
	        $template->assign( 'home_phone',         'home_phone' );              // Assign Field Name
	        $template->assign( 'home_phone2',        'home_phone2' );             // Assign Field Name
	        $template->assign( 'home_fax',           'home_fax' );                // Assign Field Name
	        $template->assign( 'street',             'street' );                  // Assign Field Name
	        $template->assign( 'suburb_name',        'suburb_name' );             // Assign Field Name
	        $template->assign( 'post_code',          'post_code' );               // Assign Field Name
	        $template->assign( 'home_fax',           'home_fax' );                // Assign Field Name
	        $template->assign( 'parish',             'parish' );                  // Assign Field Name
            $template->assign( 'parish_ids',         $t_parish_ids );             // Assign values for 'parish_ids'
            $template->assign( 'parish_names',       $t_parish_names );           // Assign values for 'parish_names'
            $template->assign( 'family_id',          $family_id);                 // Assign value for family_id

	        //#----------------------------------------------------------------------------------------------
	    	$template->assign( 'standalone',   $cfg_standalone );	
	    	$template->assign( 'family_id',   $family_id );	            
	    	$template->assign( 'action_page',   $_SERVER['PHP_SELF'] );	
  	        $template->run('family_edit');						// Execute template
	    break;
	    	
	    case 'commit':
                $state_initials = state_get_field( $state_id, 'initials' );
	        family_update( $family_id, $last_name, $home_phone, $home_phone2, $home_fax, $parish, 
                               $street, $suburb_name, $state_initials, $post_code );
	        
	        //--------------------------------------------------------
            // Redirect to family_view_page to display details about the added family
            //--------------------------------------------------------
	        $t_url = 'family_view_page.php?family_id=' . $family_id ;
	        header_redirect( $t_url );
	    break; 
	    
		default:
		        echo "$option"; 
		        trigger_error("Illegal Action",E_USER_ERROR);
                exit;
		break;
	}

    

  
?>
