<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004  e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #Add a column that includes comma separated list of first names for family members in family_list_page.php
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: family_list_page.php,v 1.18 2004/10/14 10:50:36 vboctor Exp $
    # -------------------------------------------------------------------------

    $t_src_path = dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR;

    require_once( $t_src_path . 'common_inc.php' );
    require_once( $t_src_path . 'database_inc.php' );
    require_once( $t_src_path . 'utils_api_inc.php' );
    require_once( $t_src_path . 'gpc_api_inc.php' );
    require_once( $t_src_path . 'family_inc.php' );
    require_once( $t_src_path . 'family_member_inc.php' );
    require_once( $t_src_path . 'parishioner_inc.php' );
    require_once( $t_src_path . 'validate_au.php' );
    require_once( $t_src_path . 'address_inc.php' );
    require_once( $t_src_path . 'access_api_inc.php' );
 
    access_ensure_not_standalone();

    disable_timeout();

    define( 'ITEMS_PER_PAGE', 25 );

    $diocese_db->connect(); //connect to database

    # Get Post Variables
    $f_last_name     = gpc_get_string( 'last_name',  '' );
    $f_home_phone    = gpc_get_string( 'home_phone', '' );
    $f_home_fax      = gpc_get_string( 'home_fax', '' );

    $f_suburb_name   = gpc_get_string( 'suburb', '' );
    $f_state_id      = gpc_get_string( 'state_id', '' );
    $f_post_code     = gpc_get_string( 'post_code', '' );
    $f_parish_id     = gpc_get_string( 'parish_id', '' );
    $f_approved      = gpc_get_int( 'approved', 1 );

    $f_page          = gpc_get_int( 'page_number', 1 );

    # Escape variables before injecting them in SQL
    $sql_last_name     = db_prepare_string( $f_last_name );
    $sql_home_phone    = db_prepare_string( '%' . Validate_AU::_normalisePhoneNumber( $f_home_phone ) . '%' );
    $sql_home_fax      = db_prepare_string( '%' . Validate_AU::_normalisePhoneNumber( $f_home_fax ) . '%' );
    $sql_suburb_name   = db_prepare_string( '%' . $f_suburb_name . '%');
    $sql_state_id      = db_prepare_string( $f_state_id );
    $sql_post_code     = db_prepare_string( $f_post_code );
    $sql_parish_id     = db_prepare_string( $f_parish_id );
    $sql_approved      = db_prepare_string( $f_approved );

    if ( $f_page < 1 )
        $f_page = 1;

    $t_core_parishioners = table( 'core_parishioners' );
    $t_core_family_members = table( 'core_family_members' );
    $t_core_families = table( 'core_families' );
    $t_core_suburbs = table( 'core_suburbs' );
    $t_core_addresses = table('core_addresses');
    $t_core_states = table('core_states');
    $t_core_parishes = table('core_parishes');

    // this is searching using last name, home number and post code, and state.

    $query = "SELECT __PUT_SELECT_PORTION_HERE__
                  FROM $t_core_families as f, $t_core_suburbs as s, 
                       $t_core_addresses as a, $t_core_states as st,
                       $t_core_parishes as parishes 
                  WHERE f.address_id = a.address_id AND 
                        a.suburb_id = s.suburb_id AND
                        s.state_id = st.state_id AND
                        f.parish_id = parishes.parish_id AND
                        f.approved = $sql_approved";

    if ( !is_blank2( $sql_last_name ) )
    {
        $query .= " AND f.last_name = $sql_last_name";
    }
	
    if ( !is_blank2( $sql_home_phone ) )
    {
        $query .= " AND ( ( f.home_phone like $sql_home_phone ) OR ( f.home_phone2 like $sql_home_phone ) )";
    }
	
    if ( !is_blank2( $sql_home_fax ) )
    {
        $query .= " AND f.home_fax like $sql_home_fax";
    }
	
    if( !is_blank2( $sql_state_id ) || !is_blank2( $sql_suburb_name ) || !is_blank2( $sql_post_code ) )
    {
       if ( !is_blank2( $sql_suburb_name ) )
           $query .= " AND s.name like $sql_suburb_name";

       if( !is_blank2( $sql_state_id ) )
           $query .= " AND st.state_id = $sql_state_id";

       if( !is_blank2( $sql_post_code ) )
           $query .= " AND s.post_code = $sql_post_code";
    }

    if ( access_limited_to_one_parish() )
    {
        $query .= " AND parishes.parish_id = " . access_get_parish_id();
    }
    else
    {
        if ( !is_blank2( $sql_parish_id ) )
        {
            $query .= " AND parishes.parish_id = $sql_parish_id";
        }
    }

    $t_count_query = str_replace( '__PUT_SELECT_PORTION_HERE__', 'COUNT( DISTINCT family_id )', $query );

    $t_count = $diocese_db->get_one( $t_count_query );
    $t_num_of_pages = (integer) ( $t_count / ITEMS_PER_PAGE );
    $t_num_of_pages += ( $t_count % ITEMS_PER_PAGE ) == 0 ? 0 : 1;

    $query = str_replace( '__PUT_SELECT_PORTION_HERE__', 'DISTINCT( family_id )', $query );

    # Sort by first name then last name
    $query .= " ORDER BY f.last_name ASC, f.family_id ASC";

    $recordSet = &$diocese_db->execute( $query, ITEMS_PER_PAGE, ( $f_page - 1 ) * ITEMS_PER_PAGE );

    # Collect parishioners' info into an array to send to template
    $families = array();

    # Collect first names into an array to send to template
    $familiesFirstNames = array();

    $familiesDuplicateFlags = array();

    while ( !$recordSet->EOF )
    {
        $family_id = $recordSet->fields['family_id'];
        $c_family_id = $diocese_db->prepare_int( $family_id );

        $family = $diocese_db->family_load( $family_id );
        $families[] = $family;

        $firstNames = array();

        $members_query = "SELECT first_name FROM $t_core_parishioners as p, $t_core_family_members as fm, $t_core_families as f
                          WHERE ( f.family_id = $c_family_id ) AND
                                ( fm.family_id = $c_family_id ) AND 
                                ( p.parishioner_id = fm.parishioner_id )
                          ORDER BY date_of_birth ASC";

        $membersResultSet = &$diocese_db->execute( $members_query );

        while ( !$membersResultSet->EOF )
        {
            $firstNames[] = $membersResultSet->fields['first_name'];
            $membersResultSet->MoveNext();  //  Moves to the next family member
        }

        $familiesFirstNames[] = $firstNames;

        $familiesDuplicateFlags[] = count( family_get_duplicate_ids( $family_id ) ) > 0;

        $recordSet->MoveNext();  //  Moves to the next family
    }  // end while

    # Prepare GET variables
    $t_get_vars = "last_name=$f_last_name&home_phone=$f_home_phone&home_fax=$f_home_fax&suburb=$f_suburb_name&state_id=$f_state_id&post_code=$f_post_code&parish_id=$f_parish_id&approved=$f_approved";

    $t_page_links = string_page_links( $_SERVER['PHP_SELF'] . "?$t_get_vars", 1, $t_num_of_pages, $f_page );

    # Execute the templates
    $template->assign( 'families',           $families );
    $template->assign( 'familiesFirstNames', $familiesFirstNames );
    $template->assign( 'familiesDuplicateFlags', $familiesDuplicateFlags );
    $template->assign( 'page_links', $t_page_links );

    $template->run( 'family_list_page' );
?>
