<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: import_abusefien_st_mary.php,v 1.5 2004/04/04 07:35:04 vboctor Exp $
    # -------------------------------------------------------------------------

    ###########################################################################
    # A script to import parishioners data from St. Abanoub Excel sheet after exporting
    # to CSV format.
    ###########################################################################

    // Generic Importing Code
    require_once dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'import_inc.php';

    if ( !isset( $parish ) )
    {
        $t_parish_name = 'St Mary & St Mercurius  Rhodes';
        echo "<h1>$t_parish_name</h1>";

        $t_parish_name = preprocess_value( $t_parish_name );

        $t_parish_id = parish_get_id( $t_parish_name );
        if ( $t_parish_id == false )
        {
            echo $t_parish_name . ' does not exist in the database.';
            exit;
        }

        $parish = $diocese_db->parish_load( $t_parish_id );
    }

    echo $parish->dump() . '<br />';

    $input = implode( '\n', $input );
    $segments = explode( '=*=*=*=*=*=', $input );
    $families = explode( '\n', $segments[0] );
    $children = explode( '\n', $segments[1] );

    // FAMILY FIELDS
    // FamID,Surname,FIRST,Spouse,Tel,MobileFirst,MobileSpouse,OccupationFirst,OccupationSpouse,email,Address,Suburb,Post Code,DOA,DOBFirst,DOBSpouse,Updated,ChurchCode,Decon

    // Separator between family information and children information
    // =*=*=*=*=*=

    for ($i = 1; $i < count($families); $i++)
    {
        $family_row = explode(',', $families[$i]);

        //
        // Extract Needed Information
        //

        for ( $n = 0; $n < 20; ++$n )
        {
            if ( !isset( $family_row[$n] ) )
                $family_row[$n] = '';
        }

        $family_id = preprocess_value( $family_row[0] );
        $surname = preprocess_value( $family_row[1] );
        $phone   = preprocess_value( $family_row[4] );
        $street  = preprocess_value( $family_row[10] );
        $suburb  = preprocess_value( $family_row[11] );
        $state   = 'NSW';
        $postcode = preprocess_value( $family_row[12] );

        //
        // Family Information
        //

        $family =& new Family;
        $family->set_home_phone($phone);
        $family->set_last_name( $surname );
        $family->set_parish_id( $parish->get_id() );
        $family->set_extra_information( 'DOA', $family_row[13] );
        $family->set_extra_information( 'DEACON', $family_row[18] );

        //
        // Family Address Details
        //

        $address =& new Address;
        $address->set_street_details( $street );
        $address->set_suburb( $suburb );
        $address->set_state( $state );
        $address->set_post_code( $postcode );
        $address->set_country( 'Australia' );
        $diocese_db->address_save( $address );

        $family->set_address_id( $address->get_id() );

        $col = 10;
        for ( $member = 1; $member <= 2; $member++ )
        {
            $firstname = preprocess_value( $family_row[ ( $member == 1 ) ? 2 : 3] );
            if ( strlen( trim( $firstname ) ) == 0 )
                break;

            $parishioner =& new Parishioner;
            $family_member =& new FamilyMember;

            $parishioner->set_primary_parish_id( $parish->get_id() );
            $parishioner->set_first_name( $firstname );
            $parishioner->set_last_name( $surname );

            $dob = australian_date_to_standard( remove_time_from_date_time( preprocess_value( $family_row[($member == 1) ? 14 : 15] ) ) );
            if ( $dob !== false )
                $parishioner->set_date_of_birth( $dob );

            $parishioner->set_extra_information( PARISHIONER_OCCUPATION, preprocess_value( $family_row[( $member == 1 ) ? 7 : 8] ) );

            $relation = preprocess_value( ( $member == 1 ) ? 'HUSBAND' : 'WIFE' );

            $parishioner->set_mobile_number( preprocess_value( $family_row[ ( $member == 1 ) ? 5 : 6 ] ) );

            $gender = relation_to_gender( $relation );
            if ( $gender !== false )
                $parishioner->set_gender( $gender );

            $role = relation_to_family_role( $relation );
            if ( $role !== false )
                $family_member->set_role( $role );

            if ( !relation_is_valid( $relation ) )
            {
                if ( strlen( trim( $relation ) ) == 0 )
                    trigger_error ("Empty relation for parishioner $firstname $surname.", E_USER_WARNING);
                else
                    trigger_error ("Invalid relation '$relation' for parishioner $firstname $surname.", E_USER_WARNING);
            }

            $diocese_db->parishioner_save( $parishioner );
            $family_member->set_parishioner_id( $parishioner->get_id() );

            $family->add_family_member( $family_member );
        }

        // CHILD FIELDS
        // FamID,Name,Occupation,MobileNo,DOB,Sex,Decon,BapCert

        for ( $j = 1; $j < count( $children ); ++$j )
        {
            $child_row = explode( ',', $children[$j] );
            if ( $child_row[0] != $family_id )
                continue;

            $firstname = $child_row[1];
            if ( strlen( trim( $firstname ) ) == 0 )
                continue;

            //
            // Extract Needed Information
            //

            for ( $n = 0; $n < 7; ++$n )
            {
                if ( !isset( $child_row[$n] ) )
                    $child_row[$n] = '';
            }

            $parishioner =& new Parishioner;
            $family_member =& new FamilyMember;

            $parishioner->set_primary_parish_id( $parish->get_id() );
            $parishioner->set_first_name( preprocess_value( $firstname ) );
            $parishioner->set_last_name( preprocess_value( $surname ) );
            $parishioner->set_mobile_number( preprocess_value( $child_row[3] ) );
            $parishioner->set_gender( preprocess_value( $child_row[5] ) );

            $dob = australian_date_to_standard( remove_time_from_date_time( preprocess_value( $child_row[4] ) ) );
            if ( $dob !== false )
                $parishioner->set_date_of_birth( $dob );

            $parishioner->set_extra_information( PARISHIONER_OCCUPATION, preprocess_value( $child_row[2] ) );
            $parishioner->set_extra_information( 'DECON', preprocess_value( $child_row[6] ) );
            $parishioner->set_extra_information( 'BAPTISM_CERTIFICATE', preprocess_value( $child_row[7] ) );

            $diocese_db->parishioner_save( $parishioner );
            $family_member->set_parishioner_id( $parishioner->get_id() );
            $family_member->set_role( 'C' );

            $family->add_family_member( $family_member );
        }

        //
        // Save Family Information
        //

        $diocese_db->family_save( $family );

        //
        // Dump the results
        //

        echo $family->dump() . '<br />';

        $diocese_db->flush_cache();
    }
?>