<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: import_stantony.php,v 1.16 2004/04/06 12:58:54 vboctor Exp $
    # -------------------------------------------------------------------------

    ###########################################################################
    # A script to import parishioners data from St. Antony Excel sheet after exporting
    # to CSV format.
    ###########################################################################

    $t_src_path = dirname( dirname( __FILE__ ) ) . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR;

    require_once  $t_src_path. 'date_inc.php';

    // Generic Importing Code
    require_once dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'import_inc.php';

    // Specific Importing Code
    $lastPul = 'x';

    //
    // Parish Information
    //

    if ( !isset( $parish ) )
    {
        $t_parish_name = 'St Antonious & St Paul - Guildford';
        echo "<h1>$t_parish_name</h1>";

        $t_parish_name = preprocess_value( $t_parish_name );

        $t_parish_id = parish_get_id( $t_parish_name );
        if ( $t_parish_id == false )
        {
            echo $t_parish_name . ' does not exist in the database.';
            exit;
        }

        $parish = $diocese_db->parish_load( $t_parish_id );
    }

    echo $parish->dump() . '<br />';

    for ($i = 2; $i < count($input); $i++)
    {
        $row = explode( ',', $input[$i] );

        if ( count( $row ) < 22 )
            continue;

        //
        // Extract Needed Information
        //

        $surname      = preprocess_value( $row[1] );
        $pul          = preprocess_value( $row[2] );
        $father       = preprocess_value( $row[8] );
        $father_dob   = american_date_to_standard( preprocess_value( $row[13] ) );
        $father_occup = preprocess_value( $row[18] );
        $mother       = preprocess_value( $row[9] );
        $child1       = preprocess_value( $row[10] );
        $child2       = preprocess_value( $row[11] );
        $child3       = preprocess_value( $row[12] );
        $mother_dob   = american_date_to_standard( preprocess_value( $row[14] ) );
        $child1_dob   = american_date_to_standard( preprocess_value( $row[15] ) );
        $child2_dob   = american_date_to_standard( preprocess_value( $row[16] ) );
        $child3_dob   = american_date_to_standard( preprocess_value( $row[17] ) );
        $mother_occup = preprocess_value( $row[19] );
        $child1_occup = preprocess_value( $row[20] );
        $child2_occup = preprocess_value( $row[21] );
        $child3_occup = preprocess_value( $row[22] );
        $phone        = preprocess_value( $row[3] );
        $mobile       = preprocess_value( $row[4] );
        $street       = preprocess_value( $row[5] );
        $suburb       = preprocess_value( $row[6] );
        $state        = 'NSW';
        $postcode     = preprocess_value( $row[7] );

        if ($pul == $lastPul) {
           echo "Error: Family split on multiple rows (Pul = $pul).\r\n";
           echo "======================================================\r\n\r\n";
           continue;
        }

        if (strlen(trim($surname)) == 0) {
            continue;
        }

        //
        // Family Information
        //

        $family =& new Family;
        $family->set_home_phone($phone);
        $family->set_last_name( $surname );
        $family->set_parish_id( $parish->get_id() );

        //
        // Family Address Details
        //

        $address =& new Address;
        $address->set_street_details( $street );
        $address->set_suburb( $suburb );
        $address->set_state( $state );
        $address->set_post_code( $postcode );
        $address->set_country( 'Australia' );
        $diocese_db->address_save( $address );

        $family->set_address_id( $address->get_id() );

        //
        // Father Information
        //

        if ( !empty( $father ) )
        {
            $father_parishioner =& new Parishioner;
            $father_parishioner->set_first_name( $father );
            $father_parishioner->set_last_name( $surname );
            $father_parishioner->set_mobile_number( $mobile );
            $father_parishioner->set_date_of_birth( $father_dob );
            $father_parishioner->set_extra_information( PARISHIONER_OCCUPATION, $father_occup );
            $father_parishioner->set_gender( 'M' );
            $father_parishioner->set_primary_parish_id( $parish->get_id() );
            $diocese_db->parishioner_save( $father_parishioner );

            $father_member =& new FamilyMember;
            $father_member->set_parishioner_id( $father_parishioner->get_id() );
            $father_member->set_role( 'H' );  // Husband
            $family->add_family_member( $father_member );
        }

        //
        // Mother Information
        //

        if ( !empty( $mother ) )
        {
            $mother_parishioner =& new Parishioner;
            $mother_parishioner->set_first_name( $mother );
            $mother_parishioner->set_last_name( $surname );
            $mother_parishioner->set_date_of_birth( $mother_dob );
            $mother_parishioner->set_extra_information( PARISHIONER_OCCUPATION, $mother_occup );
            $mother_parishioner->set_gender( 'F' );
            $mother_parishioner->set_primary_parish_id( $parish->get_id() );
            $diocese_db->parishioner_save( $mother_parishioner );

            $mother_member =& new FamilyMember;
            $mother_member->set_parishioner_id( $mother_parishioner->get_id() );
            $mother_member->set_role( 'W' );  // Wife
            $family->add_family_member( $mother_member );
        }

        //
        // Child 1 Information
        //

        if ( !empty( $child1 ) )
        {
            $child1_parishioner =& new Parishioner;
            $child1_parishioner->set_first_name( $child1 );
            $child1_parishioner->set_last_name( $surname );
            $child1_parishioner->set_date_of_birth( $child1_dob );
            $child1_parishioner->set_extra_information( PARISHIONER_OCCUPATION, $child1_occup );
            $child1_parishioner->set_primary_parish_id( $parish->get_id() );
            $diocese_db->parishioner_save( $child1_parishioner );

            $child1_member =& new FamilyMember;
            $child1_member->set_parishioner_id( $child1_parishioner->get_id() );
            $child1_member->set_role( 'C' );  // Child
            $family->add_family_member( $child1_member );
        }

        //
        // Child 2 Information
        //

        if ( !empty( $child2 ) )
        {
            $child2_parishioner =& new Parishioner;
            $child2_parishioner->set_first_name( $child2 );
            $child2_parishioner->set_last_name( $surname );
            $child2_parishioner->set_date_of_birth( $child2_dob );
            $child2_parishioner->set_extra_information( PARISHIONER_OCCUPATION, $child2_occup );
            $child2_parishioner->set_primary_parish_id( $parish->get_id() );
            $diocese_db->parishioner_save( $child2_parishioner );

            $child2_member =& new FamilyMember;
            $child2_member->set_parishioner_id( $child2_parishioner->get_id() );
            $child2_member->set_role( 'C' );  // Child
            $family->add_family_member( $child2_member );
        }

        //
        // Child 3 Information
        //

        if ( !empty( $child3 ) )
        {
            $child3_parishioner =& new Parishioner;
            $child3_parishioner->set_first_name( $child3 );
            $child3_parishioner->set_last_name( $surname );
            $child3_parishioner->set_date_of_birth( $child3_dob );
            $child3_parishioner->set_extra_information( PARISHIONER_OCCUPATION, $child3_occup );
            $child3_parishioner->set_primary_parish_id( $parish->get_id() );
            $diocese_db->parishioner_save( $child3_parishioner );

            $child3_member =& new FamilyMember;
            $child3_member->set_parishioner_id( $child3_parishioner->get_id() );
            $child3_member->set_role( 'C' );  // Child
            $family->add_family_member( $child3_member );
        }

        //
        // Save Family Information
        //

        $diocese_db->family_save( $family );

        //
        // Dump the results
        //

        echo $family->dump() . '<br />';

        $diocese_db->flush_cache();

        $lastPul = $pul;
    }
?>
