<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004  e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: import_stmary_stmina.php,v 1.5 2004/04/04 07:35:04 vboctor Exp $
    # -------------------------------------------------------------------------

    ###########################################################################
    # A script to import parishioners data from St. Mark Excel sheet after exporting
    # to CSV format.
    ###########################################################################

    $t_src_path = dirname( dirname( __FILE__ ) ) . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR;

    require_once  $t_src_path. 'date_inc.php';

    // Generic Importing Code
    require_once dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'import_inc.php';

    if ( !isset( $parish ) )
    {
        $t_parish_name = 'St Mary & St Mina  Bexley';
        echo "<h1>$t_parish_name</h1>";

        $t_parish_name = preprocess_value( $t_parish_name );

        $t_parish_id = parish_get_id( $t_parish_name );
        if ( $t_parish_id == false )
        {
            echo $t_parish_name . ' does not exist in the database.';
            exit;
        }

        $parish = $diocese_db->parish_load( $t_parish_id );
    }

    echo $parish->dump() . '<br />';

    // SurName,Street No,Street Name,Suburb,State,Post Code,Phone,Church Attended,Church Code,Family Membership,
    // Name 1,DOB,Occupation,Relation1,Mobile No1,Member A,
    // Name 2,DOB P2,Occupation P2,Relation2,Mobile No2,Member B,B,
    // Name 3,DOB 3,Occupation 3,Relation3,Mobile No3,Member C,
    // Name 4,DOB 4,Occupation 4,Relation4,Mobile No4,Member D,
    // Name 5,DOB 5,Occupation 5,Relation5,Mobile No5,Member E,
    // Name 6,DOB 6,Occupation 6,Relation6,Mobile No6,Member F,
    // Name 7,DOB 7,Occupation 7,Relation7,Mobile No7,Member G,
    // Name 8,DOB 8,Occupation 8,Relation8,Mobile No8,Member H,
    // Name 9,DOB 9,Occupation 9,Relation9,Mobile No9,Member I,
    // Name 10,DOB 10,Occupation 10,Relation10,Mobile No10,Member J,
    // Name 11,DOB 11,Occupation 11,Relation11,Mobile No11,Member K,
    // Name 12,DOB 12,Occupation 12,Mobile No12,Relation12,Member L

    for ($i = 1; $i < count($input); $i++)
    {
        $row = explode(',', $input[$i]);

        //
        // Extract Needed Information
        //

        for ( $n = 0; $n < 70; ++$n )
        {
            if ( !isset( $row[$n] ) )
                $row[$n] = '';

            $row[$n] = trim( $row[$n] );

            if ( strlen( $row[$n] ) == 0 )
                continue;

            if ( $row[$n] == str_pad( '', strlen( $row[$n] ), '-' ) )
                $row[$n] = '';
        }

        $family_id = preprocess_value( $row[9] );
        $surname = preprocess_value( $row[0] );
        $phone   = preprocess_value( $row[6] );
        $street  = preprocess_value( $row[1] . ' ' . $row[2] );
        $suburb  = preprocess_value( $row[3] );
        $state   = preprocess_value( $row[4] );
        $postcode = preprocess_value( $row[5] );

        //
        // Family Information
        //

        $family =& new Family;
        $family->set_home_phone($phone);
        $family->set_last_name( $surname );
        $family->set_parish_id( $parish->get_id() );
        $family->set_extra_information( 'FAMILY_MEMBERSHIP', $family_id );

        //
        // Family Address Details
        //

        $address =& new Address;
        $address->set_street_details( $street );
        $address->set_suburb( $suburb );
        $address->set_state( $state );
        $address->set_post_code( $postcode );
        $address->set_country( 'Australia' );
        $diocese_db->address_save( $address );

        $family->set_address_id( $address->get_id() );

        $col = 10;
        for ( $member = 0; $member < 12; $member++ )
        {
            $firstname = preprocess_value( $row[$col++] );
            if ( strlen( trim( $firstname ) ) == 0 )
                break;

            $parishioner =& new Parishioner;
            $family_member =& new FamilyMember;

            $parishioner->set_primary_parish_id( $parish->get_id() );
            $parishioner->set_first_name( $firstname );
            $parishioner->set_last_name( $surname );

            $dob = australian_date_to_standard( preprocess_value( $row[$col++] ) );
            if ( $dob !== false )
                $parishioner->set_date_of_birth( $dob );

            $parishioner->set_extra_information( PARISHIONER_OCCUPATION, preprocess_value( $row[$col++] ) );

            $relation = preprocess_value( $row[$col++] );

            # In St. Mark data, 'S' stands for 'SON'
            if ( ( $relation == 'S' ) || ( $relation == 's' ) )
                $relation =  'SON';

            $parishioner->set_mobile_number( preprocess_value( $row[$col++] ) );

            $gender = relation_to_gender( $relation );
            if ( $gender !== false )
                $parishioner->set_gender( $gender );

            $role = relation_to_family_role( $relation );
            if ( $role !== false )
                $family_member->set_role( $role );

            if ( !relation_is_valid( $relation ) )
            {
                if ( strlen( trim( $relation ) ) == 0 )
                    trigger_error ("Empty relation for parishioner $firstname $surname.", E_USER_WARNING);
                else
                    trigger_error ("Invalid relation '$relation' for parishioner $firstname $surname.", E_USER_WARNING);
            }

            $diocese_db->parishioner_save( $parishioner );
            $family_member->set_parishioner_id( $parishioner->get_id() );

            $family->add_family_member( $family_member );

            $col++;
            if ( $col == 22 )
                $col++;
        }

        //
        // Save Family Information
        //

        $diocese_db->family_save( $family );

        //
        // Dump the results
        //

        echo $family->dump() . '<br />';

        $diocese_db->flush_cache();
    }
?>
