<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004  e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: shuffle.php,v 1.11 2004/10/14 10:50:36 vboctor Exp $
    # -------------------------------------------------------------------------

    $t_src_path = dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR;

    require_once( $t_src_path . 'common_inc.php' );
    require_once( $t_src_path . 'database_inc.php' );
    require_once( $t_src_path . 'utils_api_inc.php' );
    require_once( $t_src_path . 'gpc_api_inc.php' );
    require_once( $t_src_path . 'family_inc.php' );
    require_once( $t_src_path . 'family_member_inc.php' );
    require_once( $t_src_path . 'address_inc.php' );
    require_once( $t_src_path . 'parishioner_inc.php' );
    require_once( $t_src_path . 'parish_inc.php' );
    require_once( $t_src_path . 'access_api_inc.php' );
 
    access_ensure_not_standalone();

    if ( $cfg_allow_purge_db === false )
       trigger_error( 'Shuffle DB option is disabled', E_USER_ERROR );

    disable_timeout();

    $family_count = gpc_get_int( 'family_count', 500 );
    $confirm = gpc_get( 'confirm', 'n' );

    if ( $confirm == 'n' )
    {
       echo '<p>This operation will remove all data in the database and reply it with auto-generated date.  Are you sure? <a href="' . $_SERVER['PHP_SELF']  . '?confirm=y&family_count=' . $family_count . '">yes</a></p>';
       exit;
    }

    $diocese_db->connect(); //connect to database

    $t_core_parishioners = table( 'core_parishioners' );
    $t_core_family_members = table( 'core_family_members' );
    $t_core_families = table( 'core_families' );

    $maleFirstNames = array();
    $femaleFirstNames = array();
    $surNames = array();
    $phonePrefixes = array();
    $mobilePrefixes = array();
    $streetNames = array();
    $streetTypes = array();
    $addresses = array();

    $parish_map = parish_get_id_name_map();
    $parish_ids = array_keys( $parish_map );

    $query = "SELECT family_id FROM $t_core_families";
    
    $recordSet = &$diocese_db->execute( $query );

    while ( !$recordSet->EOF )
    {
        $family_id = $recordSet->fields['family_id'];

        $family = $diocese_db->family_load( $family_id );

        // 029500
	$phone = $family->get_home_phone();
	if ( strlen( $phone ) == 8 ) {
		$phone = '02' . $phone;
	}
        $phonePrefix = substr( $phone, 0, 6 );
        $phonePrefixes[] = $phonePrefix;

        $address_id = $family->get_address_id();
        if ( $address_id != 0 )
        {
            $address = $diocese_db->address_load( $address_id );
            $addresses[] = $address;
            $streetDetails = $address->get_street_details();

            $offset1 = strpos( $streetDetails, ' ', 0 );
            if ( $offset1 !== false )
            {
                $offset2 = strpos( $streetDetails, ' ', $offset1+1 );
                if ( $offset2 !== false )
                {
                    $streetName = substr( $streetDetails, $offset1+1, $offset2-$offset1-1 );

                    if ( strpos( $streetName, "'" ) === false )
                        $streetNames[] = ucwords( $streetName );
                }
            }
        }

        $recordSet->MoveNext();  //  Moves to the next family
    }  // end while

    $query = "SELECT parishioner_id FROM $t_core_parishioners";

    $recordSet = &$diocese_db->execute( $query );

    while ( !$recordSet->EOF )
    {
        $parishioner_id = $recordSet->fields['parishioner_id'];

        $parishioner = $diocese_db->parishioner_load( $parishioner_id );

        $firstName = ucwords( $parishioner->get_first_name() );
        $gender = $parishioner->get_gender();

        if ( strpos( $firstName, ' ' ) === false )
        {
            if ( $gender == 'M' )
                $maleFirstNames[] = $firstName;
            else
                $femaleFirstNames[] = $firstName;
        }

        $surNames[] = ucwords( $parishioner->get_last_name() );

        $mobileNumber = $parishioner->get_mobile_number();
        if ( ( $mobileNumber != '' ) && ( substr( $mobileNumber, 0, 2 ) == '04' ) )
            $mobilePrefixes[] = substr( $mobileNumber, 0, 4 );

        $recordSet->MoveNext();  //  Moves to the next family
    }  // end while

    $maleFirstNames = array_unique( $maleFirstNames );
    sort( $maleFirstNames );

    $femaleFirstNames = array_unique( $femaleFirstNames );
    sort( $femaleFirstNames );

    $surNames = array_unique( $surNames );
    sort( $surNames );

    $phonePrefixes = array_unique( $phonePrefixes );
    sort( $phonePrefixes );

    $mobilePrefixes = array_unique( $mobilePrefixes );
    sort( $mobilePrefixes );

    $streetNames = array_unique( $streetNames );
    sort( $streetNames );

    $streetTypes = array( 'St', 'Pde', 'Pl', 'Rd', 'Cr', 'Ct', 'Ave', 'Blv' );
    sort( $streetTypes );

    $diocese_db->purge_table( table( 'core_families' ) );
    $diocese_db->purge_table( table( 'core_family_members' ) );
    $diocese_db->purge_table( table( 'core_parishioners' ) );
    $diocese_db->purge_table( table( 'core_priests' ) );
    $diocese_db->purge_table( table( 'core_addresses' ) );
    $diocese_db->purge_table( table( 'core_postal_addresses' ) );

    for ($i = 1; $i <= $family_count; $i++)
    {
        $surname = $surNames[rand( 0, count( $surNames ) - 1 )];
        $approved = rand( 1, 10 ) == 1 ? 0 : 1;  // 10% are entered through the web.
        $phone   = $phonePrefixes[rand( 0, count( $phonePrefixes ) - 1)] . rand( 1000, 9999 );
        $street  = rand( 1, 250 ) . ' ' . $streetNames[rand( 0, count( $streetNames ) - 1)] . ' ' . $streetTypes[rand( 0, count( $streetTypes ) - 1 )];
        $parish_id = $parish_ids[ rand( 0, count( $parish_ids ) - 1 ) ];

        $t_address_idx = rand( 0, count( $addresses ) - 1 );

        $suburb  = $addresses[$t_address_idx]->get_suburb();
        $state   = $addresses[$t_address_idx]->get_state();
        $postcode = $addresses[$t_address_idx]->get_post_code();

        //
        // Family Information
        //

        $family =& new Family;
        $family->set_home_phone($phone);
        $family->set_last_name( $surname );
        $family->set_parish_id( $parish_id );
        $family->set_approved( $approved );

        //
        // Family Address Details
        //

        $address =& new Address;
        $address->set_street_details( $street );
        $address->set_suburb( $suburb );
        $address->set_state( $state );
        $address->set_post_code( $postcode );
        $address->set_country( 'Australia' );
        $diocese_db->address_save( $address );

        $family->set_address_id( $address->get_id() );

        $members = rand( 1, 6 );
        for ( $member = 0; $member < $members; $member++ )
        {
            if ( $member == 0 )
            {
               $gender = 'M';
               $role = $members == 1 ? 'S' : 'H';
            }
            else if ( $member == 1 )
            {
               $gender = 'F';
               $role = 'W';
            }
            else
            {
               $gender = rand( 0, 1 ) == 1 ? 'M' : 'F';
               $role = 'C';
            }

            if ( $gender == 'M' )
               $firstname = $maleFirstNames[rand(0, count( $maleFirstNames ) - 1)];
            else
               $firstname = $femaleFirstNames[rand(0, count( $femaleFirstNames ) - 1)];

            $parishioner =& new Parishioner;
            $family_member =& new FamilyMember;

            $parishioner->set_primary_parish_id( $parish_id );
            $parishioner->set_first_name( $firstname );
            $parishioner->set_last_name( $surname );
            $parishioner->set_approved( $approved );

            if ( $member == 0 )
                $year_of_birth = rand( 1940, 1970 );
            else if ( $member == 1 )
                $year_of_birth += 4;
            else if ( $member == 2 )
                $year_of_birth += 20;
            else 
                $year_of_birth += 3;

            $month_of_birth = rand( 1, 12 );
            $day_of_birth = rand( 1, 28 );

            $dob = sprintf("%04d-%02d-%02d", $year_of_birth, $month_of_birth, $day_of_birth );
            $parishioner->set_date_of_birth( $dob );

            $age = Date('Y') - $year_of_birth;

            if ( $age > 15 )
                $parishioner->set_mobile_number( $mobilePrefixes[ rand(0, count( $mobilePrefixes ) - 1 ) ] . rand( 100000, 999999 ) );

            if ( ( $age > 12 ) && ( $age <= 60 ) )
            {
                $email = strtolower( $firstname . '.' . $surname . '@example.com' );
                $parishioner->set_email( $email );
            }

            $parishioner->set_gender( $gender );

            $family_member->set_role( $role );

            $diocese_db->parishioner_save( $parishioner );
            $family_member->set_parishioner_id( $parishioner->get_id() );

            $family->add_family_member( $family_member );
        }


        //
        // Save Family Information
        //

        $diocese_db->family_save( $family );

        //
        // Dump the results
        //

        echo $family->dump() . '<br />';

        $diocese_db->flush_cache();
    }

    // scramble the data of the parishes
    for ( $i = 0; $i < count( $parish_ids ); $i++ )
    {
        $parish = $diocese_db->parish_load( $parish_ids[$i] );
        $email = 'church ' . ($i+1) . '@example.com';
        $parish->set_email( $email );
        $parish->set_website( 'http://www.example.com' );    
        $parish->set_phone( '0295000000' );
        $parish->set_phone2( '' );
        $parish->set_fax( '0296000000' );
        $diocese_db->parish_save( $parish );
    }
?>