<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: access_api_inc.php,v 1.5 2004/08/27 11:17:47 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'parish_inc.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'parishioner_inc.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'family_inc.php' );

    function access_denied()
    {
        trigger_error( 'Access Denied', E_USER_ERROR );
    }

    # Get the parish ids the current user has access to (currently this only depends
    # on the config file and not the login)
    function access_parish_ids()
    {
        global $cfg_parish_name;

        if ( $cfg_parish_name == '' )
        {
            $map = parish_get_id_name_map();
            return array_keys( $map );
        }

        return array( parish_get_id( $cfg_parish_name ) );
    }

    function access_is_standalone()
    {
        global $cfg_standalone;
        return $cfg_standalone;
    }

    // ############################################
    // # If Standalone mode is set to TRUE, trigger
    // # an error if admin tasks are attempted.
    // ############################################
    function access_ensure_not_standalone() 
    {
        if ( access_is_standalone() )
            access_denied();
    }

    function access_limited_to_one_parish()
    {
        global $cfg_parish_name;
        return $cfg_parish_name != '';
    }

    function access_get_parish_id()
    {
        global $cfg_parish_name;

        $t_parish_name = string_add_magic_quotes( $cfg_parish_name );

        return parish_get_id( $t_parish_name );
    }

    function access_has_to_parish( $p_parish_id )
    {
        if ( access_limited_to_one_parish() === false ) 
            return true;

        if ( access_get_parish_id() == $p_parish_id )
            return true;

        return false;
    }

    function access_ensure_to_parish( $p_parish_id )
    {
        if ( !access_has_to_parish( $p_parish_id ) )
            access_denied();
    }

    function access_has_to_parishioner( $p_parishioner_id )
    {
        if ( !access_limited_to_one_parish() )
            return true;

        global $diocese_db;

        $parishioner = $diocese_db->parishioner_load( $p_parishioner_id );
        if ( $parishioner === false )
           return false;

        $t_parish_id = $parishioner->get_primary_parish_id();
        if ( ( $t_parish_id != 0 ) && ( access_has_to_parish( $t_parish_id ) ) )
           return true;

        $t_parish_id = $parishioner->get_secondary_parish_id();
        if ( ( $t_parish_id != 0 ) && ( access_has_to_parish( $t_parish_id ) ) )
           return true;

        return false;
    }

    function access_ensure_to_parishioner( $p_parishioner_id )
    {
        if ( !access_has_to_parishioner( $p_parishioner_id ) )
            access_denied();
    }

    function access_has_to_family( $p_family_id )
    {
        if ( !access_limited_to_one_parish() )
            return true;

        global $diocese_db;

        $family = $diocese_db->family_load( $p_family_id );
        if ( $family === false )
           return false;

        return access_has_to_parish( $family->get_parish_id() );
    }

    function access_ensure_to_family( $p_family_id )
    {
        if ( access_has_to_family( $p_family_id ) === false )
            access_denied();
    }

    function access_encrypt( $p_parameter )
    {
        global $cfg_encryption_token;
        return md5( $cfg_encryption_token . $p_parameter );
    }
?>
