<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003  e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: address_inc.php,v 1.12 2004/04/15 13:59:11 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'ark_inc.php' );

    /**
     * The address class contains all the information about a Family's address.
     * It does not contain postal address information.  The fact that this data
     * is saved in multiple tables is hidden from the user of this class.
     *
     * All is_valid_* methods does minor validation since it does not use
     * other fields.  For example, is_valid_post_code() can not check the state
     * field.  Hence, the main validation is to be implemented in the validate()
     * method which considers the whole object state during validation.
     */
    class Address extends Ark
    {
        function Address()
        {
            $this->Ark();

            $this->_id = 0;
            $this->_street_details = '';
            $this->_suburb = '';
            $this->_state = '';
            $this->_post_code = '';
            $this->_country = 'Australia';
        }

        function is_valid_id( $p_address_id )
        {
            return $p_address_id >= 0;
        }

        function set_id( $p_address_id )
        {
            $this->_id = (integer)$p_address_id;
            return Address::is_valid_id( $p_address_id );
        }

        function get_id()
        {
            return $this->_id;
        }

        function is_valid_street_details( $p_street_details )
        {
            return strlen( trim( $p_street_details ) ) != 0;
        }

        function set_street_details( $p_street_details )
        {
            $this->_street_details = $p_street_details;
            return Address::is_valid_street_details( $this->_street_details );
        }

        function get_street_details()
        {
            return $this->_street_details;
        }

        function is_valid_suburb( $p_suburb )
        {
            return strlen( trim( $p_suburb ) ) > 0;
        }

        function set_suburb( $p_suburb )
        {
            $this->_suburb = trim( $p_suburb );
            return Address::is_valid_suburb( $p_suburb );
        }

        function get_suburb()
        {
            return $this->_suburb;
        }

        function is_valid_state( $p_state )
        {
            return strlen( trim( $p_state ) ) > 0;
        }

        function set_state( $p_state )
        {
            $this->_state = trim( $p_state );
            return Address::is_valid_state( $p_state );
        }

        function get_state()
        {
            return $this->_state;
        }

        function is_valid_post_code( $p_post_code )
        {
            return strlen( trim( $p_post_code ) ) > 0;
        }

        function set_post_code( $p_post_code )
        {
            $this->_post_code = trim( $p_post_code );
            return Address::is_valid_post_code( $this->_post_code );
        }

        function get_post_code()
        {
            return $this->_post_code;
        }

        function is_valid_country( $p_country )
        {
            # :TODO: this check can be enhanced.
            return strlen( trim( $p_country ) ) > 0;
        }

        function set_country( $p_country )
        {
            $this->_country = trim( $p_country );
            return Address::is_valid_country( $p_country );
        }

        function get_country()
        {
            return $this->_country;
        }

        function validate()
        {
             # :TODO: To be implemented.
             return true;
        }

        function dump()
        {
            $dump  = '<table border="1" cellspacing="0" cellpadding="3" width="100%">';
            $dump .= get_dump_row( 'Address Id', $this->_id );
            $dump .= get_dump_row( 'Street Details', $this->_street_details );
            $dump .= get_dump_row( 'Suburb', $this->_suburb );
            $dump .= get_dump_row( 'State', $this->_state );
            $dump .= get_dump_row( 'Post Code', $this->_post_code );
            $dump .= get_dump_row( 'Country', $this->_country );

            $validation_result = $this->validate();
            if ( $validation_result !== true )
            {
                $errors = implode( '<br />', $validation_result );
                $dump .= get_dump_row( 'Validation', $errors );
            }
            else
            {
                $dump .= get_dump_row( 'Validation', '' );
            }

            $dump .= '</table>';

            return $dump;
        }

        //
        // Private
        //

        var $_id;
        var $_street_details;
        var $_suburb;
        var $_state;
        var $_post_code;
        var $_country;
    }

    // Return the value of a field in a suburb record specified by the id.
    function suburb_get_field( $p_suburb_id, $p_field_name )
    {
        global $diocese_db;

        $t_core_suburbs = table( 'core_suburbs' );
        $sql_suburb_id = $diocese_db->prepare_int( $p_suburb_id );
        $sql_field_name = $p_field_name;   // trusted parameter + can't prepare_string otherwise it will be quoted which will return field name as query result

        $query = "SELECT $sql_field_name from $t_core_suburbs WHERE suburb_id = $sql_suburb_id";
        $field_value = $diocese_db->get_one( $query, 1 );

        return $field_value;
    }

    // Return suburb name corresponding to specified id, or false if not found.
    function suburb_get_name( $p_suburb_id )
    {
        return suburb_get_field( $p_suburb_id, 'name' );
    }

    function states_get_id_name_map( $p_extra_entries = array() )
    {
        global $diocese_db;

        $t_core_states = table( 'core_states' );

        $query = "SELECT state_id, initials FROM $t_core_states";
        $recordSet = &$diocese_db->execute( $query );

        $t_states = $p_extra_entries;

        while ( !$recordSet->EOF )
        {
            $t_states[(integer)$recordSet->fields['state_id']] = $recordSet->fields['initials'];
            $recordSet->MoveNext(); 
        }

        return $t_states;
    }

    function state_get_id( $p_state_initials )
    {
        global $diocese_db;

        $t_core_states = table( 'core_states' );
        $sql_state_initials = $diocese_db->prepare_string( $p_state_initials );

        $query = "SELECT state_id from $t_core_states WHERE initials = $sql_state_initials";
        $t_state_id = $diocese_db->get_one( $query, 1 );

        return $t_state_id;
    }

    function state_get_field( $p_state_id, $p_field_name )
    {
        global $diocese_db;

        $t_core_states = table( 'core_states' );
        $sql_state_id = $diocese_db->prepare_int( $p_state_id );
        $sql_field_name = $p_field_name;   // trusted parameter + can't prepare_string otherwise it will be quoted which will return field name as query result

        $query = "SELECT $sql_field_name from $t_core_states WHERE state_id = $sql_state_id";
        $field_value = $diocese_db->get_one( $query, 1 );

        return $field_value;
    }

    function suburb_get_id( $p_suburb_name )
    {
        global $diocese_db;

        $t_core_suburbs = table( 'core_suburbs' );

        $sql_suburb_name = db_prepare_string( $p_suburb_name );

        $query = "SELECT suburb_id from $t_core_suburbs where name = $sql_suburb_name";
        $t_suburb_id = &$diocese_db->get_one( $query );

        return $t_suburb_id;
    }

    function suburb_is_used( $p_suburb_id )
    {
        global $diocese_db;

        $t_core_addresses = table( 'core_addresses' );

        $sql_suburb_id = $diocese_db->prepare_int( $p_suburb_id );

        # Delete suburb only if no more addresses use it.
        $query = "SELECT COUNT(*) FROM $t_core_addresses WHERE suburb_id = $sql_suburb_id";
        $count = $diocese_db->get_one( $query );

        return ( $count > 0 );
    }

    function suburb_get_all_ids()
    {
        global $diocese_db;

        $t_core_suburbs = table( 'core_suburbs' );

        $query = "SELECT suburb_id from $t_core_suburbs";

        $t_suburb_ids = array();
        for ( $rs = &$diocese_db->execute( $query ); !$rs->EOF; $rs->MoveNext() )
            $t_suburb_ids[] = $rs->fields['suburb_id'];

        return $t_suburb_ids;
    }

    function suburb_delete( $p_suburb_id )
    {
        global $diocese_db;

        $t_core_suburbs = table( 'core_suburbs' );

        $sql_suburb_id = db_prepare_string( $p_suburb_name );

        $query = "DELETE FROM $t_core_suburbs WHERE suburb_id = $sql_suburb_id";
        $rs = &$diocese_db->execute( $query, 1 );
    }

    # Delete the specified address.  If the suburb is no longer referenced by other indices
    # then it should be deleted as well.
    function address_delete( $p_address_id )
    {
        global $diocese_db;

        $t_core_addresses = table( 'core_addresses' );

        $address = $diocese_db->address_load( $p_address_id );

        $query = "DELETE FROM $t_core_addresses WHERE address_id = " . $address->get_id();
        $rs = &$diocese_db->execute( $query, 1 );

        $t_suburb_id = suburb_get_id( $address->get_suburb() );
        if ( !suburb_is_used( $t_suburb_id ) )
            suburb_delete( $t_suburb_id );
    }
?>