<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: database_inc.php,v 1.22 2004/04/15 14:44:39 vboctor Exp $
    # -------------------------------------------------------------------------


    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'ark_inc.php' );
    require_once( $cfg_adodb_path . 'adodb.inc.php' );

    $queries_executed = array();

    class DioceseDB extends Ark
    {
        function DioceseDB()
        {
            $this->Ark();

            $this->flush_cache();

            $this->_adodb = null;
            $this->_db_sim = false;
        }

        function &connect()
        {
            global $cfg_database_name, $cfg_database_user, $cfg_database_password,
                   $cfg_database_host, $cfg_database_type;

            $adodb =& ADONewConnection( $cfg_database_type );
            $adodb->Connect( $cfg_database_host, $cfg_database_user, 
                             $cfg_database_password, $cfg_database_name );
            $adodb->SetFetchMode(ADODB_FETCH_ASSOC); 

            $this->_adodb = &$adodb;

            return $adodb;	
        }

        function purge_table( $p_table_name )
        {
            $sql = "DELETE FROM $p_table_name";
            $this->execute( $sql );
        }

        function purge()
        {
            $this->purge_table( table( 'core_parishes' ) );
            $this->purge_table( table( 'core_families' ) );
            $this->purge_table( table( 'core_family_members' ) );
            $this->purge_table( table( 'core_parishioners' ) );
            $this->purge_table( table( 'core_priests' ) );

            $this->purge_table( table( 'core_addresses' ) );
            $this->purge_table( table( 'core_postal_addresses' ) );
            $this->purge_table( table( 'core_suburbs' ) );

            // state / country tables should not be purged
        }

        function prepare_string( $p_value )
        {
            return $this->_adodb->qstr( $p_value, get_magic_quotes_gpc() );
        }

        function prepare_int( $p_value )
        {
            return (integer)$p_value;
        }

        function prepare_date( $p_date )
        {
            // Dates are saved as strings
            return $this->prepare_string( $p_date );
        }

        function prepare_timestamp( $p_timestamp )
        {
            return $this->_adodb->DBTimeStamp( $p_timestamp );
        }

        function unix_timestamp( $p_timestamp )
        {
            if ( null !== $p_timestamp )
                $t_timestamp = $this->_adodb->UnixTimeStamp( $p_timestamp );
            else
                $t_timestamp = time();

            return $t_timestamp;
        }

        function flush_cache()
        {
            $this->_parishes_cache = array();
            $this->_families_cache = array();
            $this->_family_members_cache = array();
            $this->_parishioners_cache = array();
            $this->_priests_cache = array();
            $this->_addresses_cache = array();
            $this->_postal_addresses_cache = array();
        }

        # --------------------
        # execute query, requires connection to be opened
        # If $p_error_on_failure is true (default) an error will be triggered
        # if there is a problem executing the query.
        function execute( $p_query, $p_limit = -1, $p_offset = -1 ) {
            global $queries_executed;
            array_push ( $queries_executed, $p_query );

            if ( $p_limit != -1 || $p_offset != -1 ) {
                $t_result = $this->_adodb->SelectLimit( $p_query, $p_limit, $p_offset );
            } else {
                $t_result = $this->_adodb->Execute( $p_query );
            }

            if ( false === $t_result ) {
                trigger_error( $this->_adodb->ErrorMsg(), E_USER_ERROR );
            }

            return $t_result;
        }

        # --------------------
        # Execute query and get one value from the result (useful for counts, ...etc)
        function get_one( $p_query )
        {
            global $queries_executed;
            array_push ( $queries_executed, $p_query );

            $t_result = $this->_adodb->GetOne( $p_query );
            if ( $t_result === false )
                trigger_error( $this->_adodb->ErrorMsg(), E_USER_ERROR );

            return $t_result;
        }

        # --------------------
        # returns the id of the last inserted record
        function get_insert_id()
        {
            return $this->_adodb->Insert_ID();
        }

        function family_load( $p_family_id )
        {
            $db_family_id = $this->prepare_int( $p_family_id );

            if ( $db_family_id == 0 )
                return new Family;

            if ( isset( $this->_families_cache[$db_family_id] ) )
                return $this->_families_cache[$db_family_id];

            $t_core_families = table( 'core_families' );
            $query = "SELECT * FROM $t_core_families WHERE family_id = $db_family_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                $family = &new Family;
                $family->set_id( $fields['family_id'] );
                $family->set_last_name( $fields['last_name'] );
                $family->set_address_id( $fields['address_id'] );
                $family->set_postal_address_id( $fields['postal_address_id'] );
                $family->set_home_phone( $fields['home_phone'] );
                $family->set_home_phone2( $fields['home_phone2'] );
                $family->set_home_fax( $fields['home_fax'] );
                $family->set_parish_id( $fields['parish_id'] );
                $family->set_approved( $fields['approved'] );
                $family->set_date_added( $this->unix_timestamp( $fields['date_added'] ) );
                $family->set_date_updated( $this->unix_timestamp( $fields['date_updated'] ) );

                $t_core_family_members = table( 'core_family_members' );
                $query = "SELECT member_id FROM $t_core_family_members WHERE family_id = $db_family_id ORDER BY member_id ASC";
                $family_members_rs = &$this->execute( $query );

                $family_member_ids = array();
                while ( !$family_members_rs->EOF )
                {
                    $member_id = $family_members_rs->fields['member_id'];
                    $family_member_ids[] = $this->_family_member_load( $member_id );
                    $family_members_rs->fetchRow();
                }

                $family->set_family_members( $family_member_ids );

                $this->_families_cache[$db_family_id] = $family;
                return $this->family_load( $db_family_id );
            }

            return false;
        }

        function family_save( &$p_family_object )
        {
            $t_core_families = table( 'core_families' );

            $db_family_id = $this->prepare_int( $p_family_object->get_id() );
            $db_last_name = $this->prepare_string( $p_family_object->get_last_name() );
            $db_address_id = $this->prepare_int( $p_family_object->get_address_id() );
            $db_postal_address_id = $this->prepare_int( $p_family_object->get_postal_address_id() );
            $db_home_phone = $this->prepare_string( $p_family_object->get_home_phone() );
            $db_home_phone2 = $this->prepare_string( $p_family_object->get_home_phone2() );
            $db_home_fax = $this->prepare_string( $p_family_object->get_home_fax() );
            $db_parish_id = $this->prepare_int( $p_family_object->get_parish_id() );
            $db_approved = $this->prepare_int( $p_family_object->get_approved() );
            $db_date_added = $this->prepare_timestamp( $p_family_object->get_date_added() );
            $db_date_updated = $this->prepare_timestamp( $p_family_object->get_date_updated() );

            if ( $p_family_object->get_id() == 0 )
            {
                if ( $this->_db_sim )
                {
                    static $family_counter = 1;
                    $p_family_object->set_id( $family_counter++ );
                }
                else
                {
                    $sql = "INSERT INTO $t_core_families (last_name, address_id, postal_address_id, home_phone, home_phone2, home_fax, parish_id, approved, date_added, date_updated)
                                 VALUES ( $db_last_name,
                                          $db_address_id,
                                          $db_postal_address_id,
                                          $db_home_phone,
                                          $db_home_phone2,
                                          $db_home_fax,
                                          $db_parish_id,
                                          $db_approved,
                                          $db_date_added,
                                          $db_date_updated)";

                    $this->execute( $sql );
                    $p_family_object->set_id( $this->get_insert_id() );
                }
            }
            else
            {
                $p_family_object->set_date_updated();
                $db_date_updated = $this->prepare_timestamp( $p_family_object->get_date_updated() );

                $sql = "UPDATE $t_core_families SET
                               last_name = $db_last_name,
                               address_id = $db_address_id,
                               postal_address_id = $db_postal_address_id,
                               home_phone = $db_home_phone,
                               home_phone2 = $db_home_phone2,
                               home_fax = $db_home_fax,
                               parish_id = $db_parish_id,
                               approved = $db_approved,
                               date_added = $db_date_added,
                               date_updated = $db_date_updated
                        WHERE  family_id = $db_family_id";

                $this->execute( $sql );
            }

            for ( $i = 0; $i < count( $p_family_object->get_family_members() ); ++$i )
            {
               $family_members = &$p_family_object->get_family_members();
               $family_member = &$family_members[$i];
               $this->_family_member_save( $p_family_object->get_id(), $family_member );
            }

            $this->_families_cache[$p_family_object->get_id()] = $p_family_object;

            return true;
        }

        function _family_member_load( $p_family_member_id )
        {
            $db_family_member_id = $this->prepare_int( $p_family_member_id );

            if ( $db_family_member_id == 0 )
                return new FamilyMember;

            if ( isset( $this->_family_members_cache[$db_family_member_id] ) )
                return $this->_family_members_cache[$db_family_member_id];

            $t_core_family_members = table( 'core_family_members' );
            $query = "SELECT * FROM $t_core_family_members WHERE member_id = $db_family_member_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                $family_member = &new FamilyMember;
                $family_member->set_id( $fields['member_id'] );
                // $family_member->set_family_id( $fields['family_id'] );
                $family_member->set_parishioner_id( $fields['parishioner_id'] );
                $family_member->set_role( $fields['role'] );
                $this->_family_members_cache[$db_family_member_id] = $family_member;

                return $this->_family_member_load( $db_family_member_id );
            }

            return false;
        }

        function _family_member_save( $p_family_id, &$p_family_member_object )
        {
            $t_core_family_members = table( 'core_family_members' );

            $db_family_member_id = $this->prepare_int( $p_family_member_object->get_id() );
            $db_family_id = $this->prepare_int( $p_family_id );
            $db_parishioner_id = $this->prepare_int( $p_family_member_object->get_parishioner_id() );
            $db_role = $this->prepare_string( $p_family_member_object->get_role() );

            if ( $p_family_member_object->get_id() == 0 )
            {
                if ( $this->_db_sim )
                {
                    static $family_members_counter = 1;
                    $p_family_member_object->set_id( $family_members_counter++ );
                }
                else
                {
                    $sql = "INSERT INTO $t_core_family_members
                                (family_id, parishioner_id, role)
                                VALUES ( $db_family_id,
                                         $db_parishioner_id,
                                         $db_role)";

                    $this->execute( $sql );
                    $p_family_member_object->set_id( $this->get_insert_id() );
                }
            }
            else
            {
                $sql = "UPDATE $t_core_family_members SET
                               family_id = $db_family_id,
                               parishioner_id = $db_parishioner_id,
                               role = $db_role
                        WHERE member_id = $db_family_member_id";

                $this->execute( $sql );
            }

            $this->_family_members_cache[$p_family_member_object->get_id()] = $p_family_member_object;

            return true;
        }

        function parishioner_load( $p_parishioner_id )
        {
            $db_parishioner_id = $this->prepare_int( $p_parishioner_id );

            if ( $db_parishioner_id == 0 )
                return new Parishioner;

            if ( isset( $this->_parishioners_cache[$db_parishioner_id] ) )
               return $this->_parishioners_cache[$db_parishioner_id];

            $t_core_parishioners = table( 'core_parishioners' );
            $query = "SELECT * FROM $t_core_parishioners WHERE parishioner_id = $db_parishioner_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                $parishioner = &new Parishioner;
                $parishioner->set_id( $fields['parishioner_id'] );
                $parishioner->set_title( $fields['title'] );
                $parishioner->set_first_name( $fields['first_name'] );
                $parishioner->set_middle_name( $fields['middle_name'] );
                $parishioner->set_last_name( $fields['last_name'] );
                $parishioner->set_email( $fields['email'] );
                $parishioner->set_occupation( $fields['occupation'] );
                $parishioner->set_date_of_birth( $fields['date_of_birth'] );
                $parishioner->set_date_of_decease( $fields['date_of_decease'] );
                $parishioner->set_gender( $fields['gender'] );
                $parishioner->set_day_time_phone( $fields['daytime_phone'] );
                $parishioner->set_mobile_number( $fields['mobile_phone'] );
                $parishioner->set_date_of_annulment( $fields['date_of_annulment'] );
                $parishioner->set_primary_parish_id( $fields['primary_parish_id'] );
                $parishioner->set_secondary_parish_id( $fields['secondary_parish_id'] );
                $parishioner->set_approved( $fields['approved'] );
                $parishioner->set_date_added( $this->unix_timestamp( $fields['date_added'] ) );
                $parishioner->set_date_updated( $this->unix_timestamp( $fields['date_updated'] ) );

                $this->_parishioners_cache[$db_parishioner_id] = $parishioner;

                return $this->parishioner_load( $db_parishioner_id );
            }

            return false;
        }

        function parishioner_save( &$p_parishioner_object )
        {
            $t_core_parishioners = table( 'core_parishioners' );
            $db_parishioner_id = $this->prepare_int( $p_parishioner_object->get_id() );
            $db_title = $this->prepare_string( $p_parishioner_object->get_title() );
            $db_first_name = $this->prepare_string( $p_parishioner_object->get_first_name() );
            $db_middle_name = $this->prepare_string( $p_parishioner_object->get_middle_name() );
            $db_last_name = $this->prepare_string( $p_parishioner_object->get_last_name() );
            $db_email = $this->prepare_string( $p_parishioner_object->get_email() );
            $db_occupation = $this->prepare_string( $p_parishioner_object->get_occupation() );
            $db_date_of_birth = $this->prepare_date( $p_parishioner_object->get_date_of_birth() );
            $db_date_of_decease = $this->prepare_date( $p_parishioner_object->get_date_of_decease() );
            $db_gender = $this->prepare_string( $p_parishioner_object->get_gender() );
            $db_day_time_phone = $this->prepare_string( $p_parishioner_object->get_day_time_phone() );
            $db_mobile_phone = $this->prepare_string( $p_parishioner_object->get_mobile_number() );
            $db_date_of_annulment = $this->prepare_date( $p_parishioner_object->get_date_of_annulment() );
            $db_primary_parish_id = $this->prepare_int( $p_parishioner_object->get_primary_parish_id() );
            $db_secondary_parish_id = $this->prepare_int( $p_parishioner_object->get_secondary_parish_id() );            
            $db_approved = $this->prepare_int( $p_parishioner_object->get_approved() );            
            $db_date_added = $this->prepare_timestamp( $p_parishioner_object->get_date_added() );
            $db_date_updated = $this->prepare_timestamp( $p_parishioner_object->get_date_updated() );

            if ( $p_parishioner_object->get_id() == 0 )
            {
                if ( $this->_db_sim )
                {
                    static $parishioner_counter = 1;
                    $p_parishioner_object->set_id( $parishioner_counter++ );
                }
                else
                {
                    $sql = "INSERT INTO $t_core_parishioners
                                (title, first_name, middle_name, last_name, email, occupation, date_of_birth, date_of_decease, gender, daytime_phone, mobile_phone, date_of_annulment, primary_parish_id, secondary_parish_id, approved, date_added, date_updated )
                                VALUES ( $db_title,
                                         $db_first_name,
                                         $db_middle_name,
                                         $db_last_name,
                                         $db_email,
                                         $db_occupation,
                                         $db_date_of_birth,
                                         $db_date_of_decease,
                                         $db_gender,
                                         $db_day_time_phone,
                                         $db_mobile_phone,
                                         $db_date_of_annulment,
                                         $db_primary_parish_id,
                                         $db_secondary_parish_id,
                                         $db_approved,
                                         $db_date_added,
                                         $db_date_updated)";

                    $this->Execute( $sql );
                    $p_parishioner_object->set_id( $this->get_insert_id() );
                }
            }
            else
            {
                $p_parishioner_object->set_date_updated();
                $db_date_updated = $this->prepare_timestamp( $p_parishioner_object->get_date_updated() );

                $sql = "UPDATE $t_core_parishioners SET
                               title = $db_title,
                               first_name = $db_first_name,
                               middle_name = $db_middle_name,
                               last_name = $db_last_name,
                               email = $db_email,
                               occupation = $db_occupation,
                               date_of_birth = $db_date_of_birth,
                               date_of_decease = $db_date_of_decease,
                               gender = $db_gender,
                               daytime_phone = $db_day_time_phone,
                               mobile_phone = $db_mobile_phone,
                               date_of_annulment = $db_date_of_annulment,
                               primary_parish_id = $db_primary_parish_id,
                               secondary_parish_id = $db_secondary_parish_id,
                               approved = $db_approved,
                               date_added = $db_date_added,
                               date_updated = $db_date_updated
                        WHERE parishioner_id = $db_parishioner_id";

                $this->execute( $sql );
            }

            $this->_parishioners_cache[$p_parishioner_object->get_id()] = $p_parishioner_object;

            return true;
        }

        function priest_load( $p_priest_id )
        {
            $db_priest_id = $this->prepare_int( $p_priest_id );

            if ( $db_priest_id == 0 )
                return new Priest;

            if ( isset( $this->_priests_cache[$db_priest_id] ) )
                return $this->_priests_cache[$db_priest_id];

            $t_core_priests = table( 'core_priests' );
            $query = "SELECT * FROM $t_core_priests WHERE priest_id = $db_priest_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                $priest = &new Priest;
                $priest->set_id( $fields['priest_id'] );
                $priest->set_parishioner_id( $fields['parishioner_id'] );
                $priest->set_ordainment_date( $fields['date_of_ordainment'] );
                $this->_priests_cache[$db_priest_id] = $priest;

                return $this->priest_load( $db_priest_id );
            }

            return false;
        }

        function priest_save( $p_priest_object )
        {
            $t_core_priests = table( 'core_priests' );
            $db_priest_id = $this->prepare_int( $p_priest_object->get_id() );
            $db_parishioner_id = $this->prepare_int( $p_priest_object->get_parishioner_id() );
            $db_date_of_ordainment = $this->prepare_date( $p_priest_object->get_date_of_ordainment() );

            if ( $p_priest_object->get_id() == 0 )
            {
                if ( $this->_db_sim )
                {
                    static $priest_counter = 1;
                    $p_priest_object->set_id( $priest_counter++ );
                }
                else
                {
                    $sql = "INSERT INTO $t_core_priests " .
                                "( parishioner_id, date_of_ordainment ) " .
                                "VALUES ( " . $db_parishioner_id . ", " .
                                              $db_date_of_ordainment . ")";

                    $this->execute( $sql );
                    $p_priest_object->set_id( $this->get_insert_id() );
                }
            }
            else
            {
                $sql = "UPDATE $t_core_priests SET
                               parishioner_id = $db_parishioner_id,
                               date_of_ordainment = $db_date_of_ordainment
                        WHERE  priest_id = $db_priest_id";

                $this->execute( $sql );
            }

            $this->_priests_cache[$p_priest_object->get_id()] = $p_priest_object;

            return true;
        }

        # return an address class instance or null if no address found with the specified id.
        function address_load( $p_address_id )
        {
            $db_address_id = $this->prepare_int( $p_address_id );

            if ( $db_address_id == 0 )
               return new Address;

            if ( isset( $this->_addresses_cache[$db_address_id] ) )
               return $this->_addresses_cache[$db_address_id];

            $address = &new Address;
            $address->set_id( $p_address_id );

            $t_core_addresses = table( 'core_addresses' );
            $query = "SELECT * FROM $t_core_addresses WHERE address_id = $db_address_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                $address->set_street_details( $fields['street'] );
            }
            else
            {
                return null;
            }

            $t_core_suburbs = table( 'core_suburbs' );
            $db_suburb_id = $this->prepare_int( $fields['suburb_id'] );
            $query = "SELECT * FROM $t_core_suburbs WHERE suburb_id = $db_suburb_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                $address->set_suburb( $fields['name'] );
                $address->set_post_code( $fields['post_code'] );
            }

            $t_core_states = table( 'core_states' );
            $db_state_id = $this->prepare_int( $fields['state_id'] );
            $query = "SELECT * FROM $t_core_states WHERE state_id = $db_state_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                $address->set_state( $fields['initials'] );
            }

            $t_core_countries = table( 'core_countries' );
            $db_country_id = $this->prepare_int( $fields['country_id'] );
            $query = "SELECT * FROM $t_core_countries WHERE country_id = $db_country_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                $address->set_country( $fields['name'] );
            }

            $this->_addresses_cache[$db_address_id] = $address;
            return $this->address_load( $db_address_id );
        }

        function address_save( &$p_address_object )
        {
            $t_core_addresses = table( 'core_addresses' );

            if ( $p_address_object->get_id() == 0 )
            {
                if ( $this->_db_sim )
                {
                    static $address_counter = 1;
                    $p_address_object->set_id( $address_counter++ );
                }
                else
                {
                    $country_id = $this->country_save( $p_address_object->get_country() );
                    $state_id = $this->state_save( $p_address_object->get_state(), $country_id );

                    $db_suburb_id = $this->prepare_int( $this->suburb_save( $p_address_object->get_suburb(), $state_id, $p_address_object->get_post_code() ) );
                    $db_street = $this->prepare_string( $p_address_object->get_street_details() );

                    $sql = "INSERT INTO $t_core_addresses " .
                                "( street, suburb_id ) " .
                                "VALUES ( $db_street, $db_suburb_id )";

                    $this->execute( $sql );
                    $p_address_object->set_id( $this->get_insert_id() );
                }
            }
            else
            {
                $country_id = $this->country_save( $p_address_object->get_country() );
                $state_id = $this->state_save( $p_address_object->get_state(), $country_id );

                $db_address_id = $this->prepare_int( $p_address_object->get_id() );
                $db_street = $this->prepare_string( $p_address_object->get_street_details() );
                $db_suburb_id = $this->prepare_int( $this->suburb_save( $p_address_object->get_suburb(), $state_id, $p_address_object->get_post_code() ) );

                $sql = "UPDATE $t_core_addresses SET
                               street = $db_street,
                               suburb_id = $db_suburb_id
                        WHERE  address_id = $db_address_id";

                $this->execute( $sql );
            }

            $this->_addresses_cache[$p_address_object->get_id()] = $p_address_object;

            return true;
        }

        function parish_load( $p_parish_id )
        {
            $db_parish_id = $this->prepare_int( $p_parish_id );

            if ( $db_parish_id == 0 )
                return new Parish;

            if ( isset( $this->_parishes_cache[$db_parish_id] ) )
                return $this->_parishes_cache[$db_parish_id];

            $t_core_parishes = table( 'core_parishes' );
            $query = "SELECT * FROM $t_core_parishes WHERE parish_id = $db_parish_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                $parish = &new Parish;
                $parish->set_id( $fields['parish_id'] );
                $parish->set_name( $fields['name'] );
                $parish->set_address_id( $fields['address_id'] );
                $parish->set_postal_address_id( $fields['postal_address_id'] );
                $parish->set_phone( $fields['phone'] );
                $parish->set_phone2( $fields['phone2'] );
                $parish->set_fax( $fields['fax'] );
                $parish->set_website( $fields['website'] );
                $parish->set_email( $fields['email'] );

                $this->_parishes_cache[$db_parish_id] = $parish;

                return $this->parish_load( $db_parish_id );
            }

            return false;
        }

        function parish_save( &$p_parish_object )
        {
            $t_core_parishes = table( 'core_parishes' );
            $db_parish_id = $this->prepare_int( $p_parish_object->get_id() );
            $db_name = $this->prepare_string( $p_parish_object->get_name() );
            $db_address_id = $this->prepare_int( $p_parish_object->get_address_id() );
            $db_postal_address_id = $this->prepare_int( $p_parish_object->get_postal_address_id() );
            $db_phone = $this->prepare_string( $p_parish_object->get_phone() );
            $db_phone2 = $this->prepare_string( $p_parish_object->get_phone2() );
            $db_fax = $this->prepare_string( $p_parish_object->get_fax() );
            $db_website = $this->prepare_string( $p_parish_object->get_website() );
            $db_email = $this->prepare_string( $p_parish_object->get_email() );

            if ( $p_parish_object->get_id() == 0 )
            {
                if ( $this->_db_sim )
                {
                    static $parish_counter = 1;
                    $p_parish_object->set_id( $parish_counter++ );
                }
                else
                {
                    $sql = "INSERT INTO $t_core_parishes
                                ( name, address_id, postal_address_id, phone, phone2, fax, website, email )
                                VALUES ( $db_name,
                                         $db_address_id, 
                                         $db_postal_address_id, 
                                         $db_phone, 
                                         $db_phone2, 
                                         $db_fax, 
                                         $db_website, 
                                         $db_email)";

                    $this->execute( $sql );
                    $p_parish_object->set_id( $this->get_insert_id() );
                }
            }
            else
            {
                $sql = "UPDATE $t_core_parishes SET
                             name = $db_name,
                             address_id = $db_address_id,
                             phone = $db_phone,
                             phone2 = $db_phone2,
                             fax = $db_fax,
                             website = $db_website,
                             email = $db_email
                        WHERE parish_id = $db_parish_id";

                $this->execute( $sql );
            }

            $this->_parishes_cache[$p_parish_object->get_id()] = $p_parish_object;

            return true;
        }

        function suburb_load( $p_suburb_id )
        {
            $t_core_suburbs = table( 'core_suburbs' );
            $db_suburb_id = $this->prepare_int( $p_suburb_id );

            $query = "SELECT * FROM $t_core_suburbs WHERE suburb_id = $db_suburb_id";
            $rs = &$this->Execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                return( $fields['name'] );
            }

            return false;            
        }

        function suburb_save( $p_suburb, $p_state_id, $p_post_code, $p_suburb_id = null )
        {
            $t_core_suburbs = table( 'core_suburbs' );
            $db_suburb = $this->prepare_string( $p_suburb );
            $db_state_id = $this->prepare_int( $p_state_id );
            $db_post_code = $this->prepare_int( $p_post_code );

            if ( null == $p_suburb_id )
            {
                $query = "SELECT * FROM $t_core_suburbs WHERE ( name = $db_suburb ) AND ( state_id = $db_state_id ) AND ( post_code = $db_post_code )";
                $rs = &$this->execute( $query );

                if ( !$rs->EOF )
                {
                    $fields = $rs->fields;
                    return( $fields['suburb_id'] );
                }

                // Country not already existing, add it.
                $sql = "INSERT INTO $t_core_suburbs ( name, state_id, post_code ) 
                                         VALUES ( $db_suburb, $db_state_id, $db_post_code )";

                $this->execute( $sql );
                $db_suburb_id = $this->prepare_int( $this->get_insert_id() );
            }
            else
            {
                // state id specified, so update the specified id
                $db_suburb_id = $this->prepare_int( $p_suburb_id );

                $sql = "UPDATE $t_core_suburbs SET
                             name = $db_suburb,
							 state_id = $db_state_id,
							 post_code = $db_post_code
                        WHERE suburb_id = $db_suburb_id";

                $this->execute( $sql, 1 );
            }

            return $db_suburb_id;
        }

        function state_load( $p_state_id )
        {
            $t_core_states = table( 'core_states' );
            $db_state_id = $this->prepare_int( $p_state_id );

            $query = "SELECT * FROM $t_core_states WHERE state_id = $db_state_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                return( $fields['initials'] );
            }

            return false;            
        }

        function state_save( $p_state, $p_country_id, $p_state_id = null )
        {
            $t_core_states = table( 'core_states' );
            $db_state = $this->prepare_string( $p_state );
            $db_country_id = $this->prepare_int( $p_country_id );

            if ( null == $p_state_id )
            {
                $query = "SELECT * FROM $t_core_states WHERE initials = $db_state";
                $rs = &$this->execute( $query );

                if ( !$rs->EOF )
                {
                    $fields = $rs->fields;
                    return( $fields['state_id'] );
                }

                // Country not already existing, add it.
                $sql = "INSERT INTO $t_core_states ( initials, country_id ) 
                                         VALUES ( $db_state, $db_country_id )";

                $this->execute( $sql );
                $db_state_id = $this->prepare_int( $this->get_insert_id() );
            }
            else
            {
                // state id specified, so update the specified id
                $db_state_id = $this->prepare_int( $p_state_id );

                $sql = "UPDATE $t_core_states SET
                             initials = $db_state,
                             country_id = $db_country_id
                        WHERE state_id = $db_state_id";

                $this->execute( $sql );
            }

            return $db_state_id;
        }

        function country_load( $p_country_id )
        {
            $t_core_countries = table( 'core_countries' );
            $db_country_id = $this->prepare_int( $p_country_id );

            $query = "SELECT * FROM $t_core_countries WHERE country_id = $db_country_id";
            $rs = &$this->execute( $query );

            if ( !$rs->EOF )
            {
                $fields = $rs->fields;
                return( $fields['name'] );
            }

            return false;            
        }

        // returns the id of the saved country
        function country_save( $p_country, $p_country_id = null )
        {
            $t_core_countries = table( 'core_countries' );
            $db_country_id = 0;
            $db_name = $this->prepare_string( $p_country );

            if ( null === $p_country_id )
            {
                $query = "SELECT * FROM $t_core_countries WHERE name = $db_name";
                $rs = &$this->execute( $query );

                if ( !$rs->EOF )
                {
                    $fields = $rs->fields;
                    return( $fields['country_id'] );
                }

                // Country not already existing, add it.
                $sql = "INSERT INTO $t_core_countries ( name ) VALUES ( $db_name )";

                $this->execute( $sql );
                $db_country_id = $this->prepare_int( $this->get_insert_id() );
            }
            else
            {
                // country id specified, so update the specified id
                $db_country_id = $this->prepare_int( $p_country_id );

                $sql = "UPDATE $t_core_countries SET
                             name = $db_name
                        WHERE country_id = $db_country_id";

                $this->execute( $sql );
            }

            return $db_country_id;
        }

        function dump_queries()
        {
            global $queries_executed;
            echo '<br />' . implode( '<br />', $queries_executed );
        }

        //
        // Private
        //

        var $_parishes_cache = array();
        var $_families_cache = array();
        var $_family_members_cache = array();
        var $_parishioners_cache = array();
        var $_priests_cache = array();
        var $_addresses_cache = array();
        var $_postal_addresses_cache = array();
        var $_adodb;
        var $_db_sim;
    }

    function table( $p_table_name )
    {
        global $cfg_tables_prefix;

        if ( $cfg_tables_prefix == '' )
            return $p_table_name;

        return $cfg_tables_prefix . '_' . $p_table_name;
    }  
?>