<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: date_inc.php,v 1.4 2004/04/03 15:21:55 vboctor Exp $
    # -------------------------------------------------------------------------

    /**
     * A class that handles al ldate related operations.  The advantage of using
     * this class compared to the standard date function are:
     *
     * - Date() only supports date back to 01/01/1970 under Windows.
     * - Using standard date functions will not allow the cases where a parishioner
     *   specifies part of the date (eg: DD/MM but not the year) or (MM/YY but not DD)
     */
    class Date
    {
        function Date()
        {
            $this->_day   = null;
            $this->_month = null;
            $this->_year  = null;
        }

        function Set( $p_year, $p_month, $p_day )
        {
            $this->_year = Date::get_string_value( $p_year );
            $this->_month = Date::get_string_value( $p_month );
            $this->_day = Date::get_string_value( $p_day );
        }

        # Parses YYYY/MM/DD (separator can be specified or auto-detected)
        # Parses YY/MM/DD (separator can be specified or auto-detected)
        function FromString( $p_date_str, $p_separator = null )
        {
            if ( ( $p_date_str !== null ) && ( strlen( trim( $p_date_str ) ) > 0 ) )
            {
                $p_date_str = trim( $p_date_str );

                $p_separator = Date::get_separator( $p_date_str, $p_separator );
                if ( $p_separator === false )
                    return false;

                $numbers = explode( $p_separator, $p_date_str );
                if ( count( $numbers ) < 3 )
                    return false;

                $this->_year = Date::get_string_value( $numbers[0] );
                $this->_month = Date::get_string_value( $numbers[1] );
                $this->_day = Date::get_string_value( $numbers[2] );
            }
            else
                $this->reset();

            return $this->is_valid() || $this->is_null();
        }

        function reset()
        {
            $this->_day = null;
            $this->_month = null;
            $this->_year = null;
        }

        # Parses MM/DD/YYYY
        # Parses MM/DD/YY
        function FromAmerican( $p_date_str, $p_separator = null  )
        {
            $this->reset();

            if ( ( $p_date_str === null ) || ( strlen( trim( $p_date_str ) ) == 0 ) )
                return true;

            $p_date_str = trim( $p_date_str );
            $p_separator = Date::get_separator( $p_date_str, $p_separator );

            $numbers = explode( $p_separator, $p_date_str );
            if ( count( $numbers ) < 3 )
                return false;

            $this->_month = Date::get_string_value( $numbers[0] );
            $this->_day = Date::get_string_value( $numbers[1] );
            $this->_year = Date::normalise_year( Date::get_string_value( $numbers[2] ) );

            return $this->is_valid() || $this->is_null();
        }

        # Parses DD/MM/YYYY
        # Parses DD/MM/YY
        function FromAustralian( $p_date_str, $p_separator = null  )
        {
            $this->reset();

            if ( ( $p_date_str === null ) || ( strlen( trim( $p_date_str ) ) == 0 ) )
                return true;

            $p_date_str = trim( $p_date_str );
            $p_separator = Date::get_separator( $p_date_str, $p_separator );

            $numbers = explode( $p_separator, $p_date_str );
            if ( count( $numbers ) < 3 )
                return false;

            $this->_day = Date::get_string_value( $numbers[0] );
            $this->_month = Date::get_string_value( $numbers[1] );
            $this->_year = Date::normalise_year( Date::get_string_value( $numbers[2] ) );

            return $this->is_valid() || $this->is_null();
        }

        # Generate current date as DD-MMM-YYYY
        function ToDDMMMYYYY()
        {
           return $this->DayToDD() . '-' . $this->MonthToMMM() . '-' . $this->YearToYYYY();
        }

        # Generate current date as YYYY-MM-DD
        function ToYYYYMMDD()
        {
           return $this->YearToYYYY() . '-' . $this->MonthToMM() . '-' . $this->DayToDD();
        }

        function ToString()
        {
            return $this->ToYYYYMMDD();
        }

        function get_null_date()
        {
            $date = new Date();
            return $date->ToString();
        }

        function is_null()
        {
            return ( ( $this->_day === null ) && ( $this->_month === null ) &&
                     ( $this->_year === null ) );
        }

        function is_valid()
        {
            if ( $this->_month !== null )
            {
                if ( ( $this->_month < 1 ) || ( $this->_month > 12 ) )
                    return false;
            }

            if ( $this->_day !== null )
            {
                if ( ( $this->_day < 1 ) || ( $this->_day > 31 ) )
                    return false;
            }

            if ( $this->_year !== null )
            {
                if ( ( $this->_year < 1900 ) || ( $this->_year > 2038 ) )
                    return false;
            }

            if ( ( $this->_month !== null ) && ( $this->_day !== null ) )
            {
                $max_day = array ( 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 ); 
                if ( ( $this->_day > $max_day[(integer)$this->_month-1] ) )
                    return false;
            }

            return true;
        }

        function get_separator( $p_date_str, $p_specified_separator )
        {
           if ( $p_specified_separator !== null )
               return $p_specified_separator;

           if ( strpos( $p_date_str, '/' ) !== false )
               return '/';

           if ( strpos( $p_date_str, '-' ) !== false )
               return '-';

           if ( strpos( $p_date_str, '.' ) !== false )
               return '.';

           return false;
        }

        function DayToDD()
        {
            if ( $this->_day === null )
                return '??';

            return sprintf( '%02d', $this->_day );
        }

        function MonthToMM()
        {
            if ( $this->_month === null )
                return '??';

            return sprintf( '%02d', $this->_month );
        }

        function MonthToMMM()
        {
            if ( $this->_month === null )
                return '???';

            $months = array( 'JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN',
                             'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC' );

            return $months[ $this->_month - 1 ];
        }

        function YearToYYYY()
        {
            if ( $this->_year === null )
                return '????';

            return sprintf( '%04d', $this->_year );
        }

        function get_string_value( $p_str )
        {
            $p_str = trim( $p_str );
            if ( strlen( $p_str ) == 0 )
                return null;

            if ( substr( $p_str, 1, 1 ) === '?' )
                return null;

            return (integer) $p_str;
        }

        # Add century if not there.
        # if null, return null
        # if > 99, return as is
        # if > 10, add 1900
        # otherwise add 2000
        function normalise_year( $p_year )
        {
            if ( $p_year === null )
                return null;

            if ( $p_year > 99 )
                return $p_year;

            $p_year = (integer) $p_year;
            if ( $p_year > 10 )
                return $p_year += 1900;

            return $p_year += 2000;
        }

        var $_day;
        var $_month;
        var $_year;
     }

     function american_date_to_standard( $p_date_str )
     {
         $date = new Date();
         if ( $date->FromAmerican( $p_date_str ) === false )
             return false;

         return $date->ToYYYYMMDD();
     }

     function australian_date_to_standard( $p_date_str )
     {
         $date = new Date();
         if ( $date->FromAustralian( $p_date_str ) === false )
             return false;

         return $date->ToYYYYMMDD();
     }
?>
