<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003  e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: family_inc.php,v 1.27 2004/04/15 14:44:39 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'ark_inc.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'validate_au.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'parishioner_inc.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'family_member_inc.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'access_api_inc.php' );

    class Family extends Ark
    {
        function Family()
        {
            $this->Ark();

            $this->_id = 0;
            $this->_last_name = '';
            $this->_address_id = 0;
            $this->_postal_address_id = 0;
            $this->_home_phone = '';
            $this->_home_phone2 = '';
            $this->_home_fax = '';
            $this->_parish_id = 0;
            $this->_approved = 1;
            $this->_date_added = time();
            $this->_date_updated = time();
            $this->_family_members = array();
            $this->_extra_info = array();
        }

        function is_valid_id( $p_id )
        {
            return is_numeric( $p_id ) && ( $p_id >= 0 );
        }

        function set_id( $p_id )
        {
            $this->_id = $p_id;
            return Family::is_valid_id( $this->_id );
        }

        function get_id()
        {
            return $this->_id;
        }

        /**
         * Set family's last name
         *
         * @param $p_last_name  Family's last name (can't be empty)
         *
         * @retval true  success
         * @retval false failure
         */
        function set_last_name( $p_last_name )
        {
           $this->_last_name = trim( $p_last_name );
           return Parishioner::is_valid_last_name( $p_last_name );
        }

        /**
         * Get family's last name
         *
         * @return (string) last name
         */
        function get_last_name()
        {
            return $this->_last_name;
        }

        function is_valid_address_id( $p_address_id )
        {
            return is_numeric( $p_address_id ) && ( $p_address_id >= 0 );
        }

        function set_address_id( $p_address_id )
        {
            $this->_address_id = $p_address_id;
            return Family::is_valid_address_id( $this->_address_id );
        }

        function get_address_id()
        {
            return $this->_address_id;
        }

        function is_valid_postal_address_id( $p_postal_address_id )
        {
            return is_numeric( $p_postal_address_id ) && ( $p_postal_address_id >= 0 );
        }

        function set_postal_address_id( $p_postal_address_id )
        {
            $this->_postal_address_id = $p_postal_address_id;
            return Family::is_valid_postal_address_id( $this->_postal_address_id );
        }

        function get_postal_address_id()
        {
            return $this->_postal_address_id;
        }

        function is_valid_home_phone( $p_home_phone )
        {
            return is_valid_phone( $p_home_phone );
        }

        function set_home_phone( $p_home_phone )
        {
            $this->_home_phone = Validate_AU::_normalisePhoneNumber( $p_home_phone );
            return Family::is_valid_home_phone( $this->_home_phone );
        }

        function get_home_phone()
        {
            return $this->_home_phone;
        }

        function is_valid_home_phone2( $p_home_phone2 )
        {
            return ( strlen( $p_home_phone2 ) == 0 ) || is_valid_phone( $p_home_phone2 );
        }

        function set_home_phone2( $p_home_phone2 )
        {
            $this->_home_phone2 = Validate_AU::_normalisePhoneNumber( $p_home_phone2 );
            return Family::is_valid_home_phone2( $this->_home_phone2 );
        }

        function get_home_phone2()
        {
            return $this->_home_phone2;
        }

        function is_valid_home_fax( $p_home_fax )
        {
            return ( strlen( $p_home_fax ) == 0 ) || ( is_valid_phone( $p_home_fax ) );
        }

        function set_home_fax( $p_home_fax )
        {
            $this->_home_fax = Validate_AU::_normalisePhoneNumber( $p_home_fax );
            return Family::is_valid_home_fax( $this->_home_fax );
        }

        function get_home_fax()
        {
            return $this->_home_fax;
        }

        function set_parish_id( $p_parish_id )
        {
            $this->_parish_id = (integer)$p_parish_id;
        }

        function get_parish_id()
        {
            return $this->_parish_id;
        }

        function set_approved( $p_approved )
        {
            $this->_approved = $p_approved ? 1 : 0;
        }

        function get_approved()
        {
            return $this->_approved;
        }

        function set_date_added( $p_timestamp = null )
        {
            if ( $p_timestamp === null )
                $p_timestamp = time();

            $this->_date_added = $p_timestamp;
        }

        function get_date_added()
        {
            return $this->_date_added;
        }

        function set_date_updated( $p_timestamp = null )
        {
            if ( $p_timestamp === null )
                $p_timestamp = time();

            $this->_date_updated = $p_timestamp;
        }

        function get_date_updated()
        {
            return $this->_date_updated;
        }

        function set_family_members( $p_family_members )
        {
            $this->_family_members = $p_family_members;
        }

        function add_family_member( &$p_family_member )
        {
            $this->_family_members[] = $p_family_member;
        }

        function &get_family_members()
        {
            return $this->_family_members;
        }

        function set_extra_information( $p_field, $p_value )
        {
            $p_field = strtoupper( trim( $p_field ) );
            $p_value = trim( $p_value );

            if ( ( strlen( $p_field ) == 0 ) || ( strlen( $p_value ) == 0 ) )
                return false;

            $this->_extra_info[$p_field] = trim( $p_value );
            return true;
        }

        /**
         * Validates all parishioner information
         *
         * @retval true   All parishioner information is valid.
         * @retval errors (array) of strings that describes all errors.
         */
        function validate()
        {
            $valid = true;
            $errors = array();

            if ( !Family::is_valid_id( $this->_id ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid family id '" . $this->_id . "'";
            }

            if ( !Family::is_valid_home_phone( $this->_home_phone ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid home phone '" . $this->_home_phone . "'";
            }

            if ( !Family::is_valid_home_phone2( $this->_home_phone2 ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid home phone 2 '" . $this->_home_phone2 . "'";
            }

            if ( !Family::is_valid_home_fax( $this->_home_fax ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid home fax '" . $this->_home_fax . "'";
            }

            if ( !Family::is_valid_address_id( $this->_address_id ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid family address id '" . $this->_address_id . "'";
            }

            if ( !Family::is_valid_postal_address_id( $this->_postal_address_id ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid family postal address id '" . $this->_postal_address_id . "'";
            }

            if ( count( $this->_family_members ) == 0 )
            {
                $valid = false;
                $errors[] = 'Error: family does not contain any family members.';
            }

            return $valid ? true : $errors;
        }

        /**
         * Return all family information as a string.
         *
         * @return (string) Dump of all family data
         */
        function dump()
        {
            global $cfg_timestamp_format;

            $dump  = '<table border="1" cellspacing="0" cellpadding="3" width="100%">';
            $dump .= get_dump_row( 'Family Id', $this->_id );
            $dump .= get_dump_row( 'Family Name', $this->_last_name );
            $dump .= get_dump_row( 'Home Phone', $this->_home_phone );
            $dump .= get_dump_row( 'Home Phone 2', $this->_home_phone2 );
            $dump .= get_dump_row( 'Home Fax', $this->_home_fax );
            $dump .= get_dump_row( 'Parish Id', $this->_parish_id );
            $dump .= get_dump_row( 'Approved', $this->_approved == 1 ? 'yes' : 'no' );
            $dump .= get_dump_row( 'Date Added', date( $cfg_timestamp_format, $this->_date_added ) );
            $dump .= get_dump_row( 'Date Updated', date( $cfg_timestamp_format, $this->_date_updated ) );

            global $diocese_db;
            $address = $diocese_db->address_load( $this->_address_id );
            $dump .= get_dump_row( 'Address', $address->dump() );
            $dump .= get_dump_row( 'Postal Address Id', $this->_postal_address_id );

            foreach ( $this->_extra_info as $field => $value )
                $dump .= get_dump_row( "$field (extra)", $value );

            $member_count = 1;
            foreach ( $this->_family_members as $family_member )
            {
                $member_info = $family_member->dump();
                $dump .= get_dump_row( "Family Member $member_count", $member_info );
                $member_count++;
            }

            $validation_result = $this->validate();
            if ( $validation_result !== true )
            {
                $errors = implode( '<br />', $validation_result );
                $dump .= get_dump_row( 'Validation', $errors );
            }
            else
            {
                $dump .= get_dump_row( 'Validation', '' );
            }

            $dump .= '</table>';

            return $dump;
        }

        //--------------------------------------------------
        // Private Member Attributes
        //--------------------------------------------------

        var $_id;
        var $_last_name;
        var $_address_id;
        var $_postal_address_id;
        var $_home_phone;
        var $_home_phone2;
        var $_home_fax;
        var $_parish_id;
        var $_family_members;
        var $_approved;
        var $_date_added;
        var $_date_updated;
        var $_extra_info;
    };

    # Get all accessible family ids
    function family_get_all_ids()
    {
        global $diocese_db;

        $t_core_families = table( 'core_families' );

        $query = "SELECT family_id from $t_core_families";

        if ( access_limited_to_one_parish() )
            $query .= " WHERE parish_id = " . access_get_parish_id();

        $t_family_ids = array();
        for ( $rs = &$diocese_db->execute( $query ); !$rs->EOF; $rs->MoveNext() )
            $t_family_ids[] = $rs->fields['family_id'];

        return $t_family_ids;
    }

    # Get the family member ids associated with the specified family
    function family_get_family_member_ids( $p_family_id )
    {
        global $diocese_db;

        $family = $diocese_db->family_load( $p_family_id );
        $family_members = $family->get_family_members();

        $family_member_ids = array();
        foreach ( $family_members as $family_member )
            $family_member_ids[] = $family_member->get_id();

        return $family_member_ids;
    }

    # Get the parishioner ids associated with the specified family
    function family_get_parishioner_ids( $p_family_id )
    {
        global $diocese_db;

        $family = $diocese_db->family_load( $p_family_id );
        $family_members = $family->get_family_members();

        $parishioner_ids = array();
        foreach ( $family_members as $family_member )
            $parishioner_ids[] = $family_member->get_parishioner_id();

        return $parishioner_ids;
    }

    # approve family and all its family members in the database.
    function family_approve( $p_family_id )
    {
        global $diocese_db;

        $family = $diocese_db->family_load( $p_family_id );
        $family->set_date_updated();
        $family->set_approved(1);
        $diocese_db->family_save( $family );

        $parishioner_ids = family_get_parishioner_ids( $p_family_id );

        foreach ( $parishioner_ids as $parishioner_id )
            parishioner_approve( $parishioner_id );
    }

    function family_delete( $p_family_id )
    {
        global $diocese_db;

        $sql_family_id = $diocese_db->prepare_int( $p_family_id );

	    $family = $diocese_db->family_load( $p_family_id );
        if ( $family === false )
            trigger_error( "Family id $p_family_id not found.", E_USER_ERROR );

        # Delete Family
        $t_core_families = table( 'core_families' );
        $query = "DELETE FROM $t_core_families WHERE family_id = $sql_family_id";
        $rs = &$diocese_db->execute( $query, 1 );

        # Delete Family Members
        $t_core_family_members = table( 'core_family_members' );
        $query = "DELETE FROM $t_core_family_members WHERE family_id = $sql_family_id";
        $rs = &$diocese_db->execute( $query );

        # Delete Parishioners
        $family_members = $family->get_family_members();
        foreach ( $family_members as $family_member )
            parishioner_delete( $family_member->get_parishioner_id() );

        address_delete( $family->get_address_id() );
    }

    //#----------------------------------------------------------------------------------------------   
    //# Routine:      Update Family Details
    //# Description:    
    //# History:
    //#----------------------------------------------------------------------------------------------

    function family_update( $p_family_id, $p_last_name, $p_home_phone, $p_home_phone2, $p_home_fax, $p_parish_id,
                            $p_street, $p_suburb_name, $p_state, $p_post_code )
    {
        global $diocese_db;

        $family = $diocese_db->family_load( $p_family_id );

        $family->set_last_name( $p_last_name );
        $family->set_home_phone( $p_home_phone );
        $family->set_home_phone2( $p_home_phone2 );
        $family->set_home_fax( $p_home_fax );
        $family->set_parish_id( $p_parish_id );

        $t_address_id = $family->get_address_id();

        $address = $diocese_db->address_load( $t_address_id );

        $address->set_street_details( $p_street );
        $address->set_suburb( $p_suburb_name );
        $address->set_state( $p_state );
        $address->set_post_code( $p_post_code );

        $diocese_db->family_save( $family );
        $diocese_db->address_save( $address );

        $diocese_db->flush_cache();
    }

    //#----------------------------------------------------------------------------------------------   
    //# Routine:      Delete Parishioner From Family
    //# Description:    
    //# History:
    //#----------------------------------------------------------------------------------------------
    function family_delete_parishioner( $p_parishioner_id, $p_family_id )
    {
        global $diocese_db;

        $sql_family_id = $diocese_db->prepare_int( $p_family_id );
        $sql_parishioner_id = $diocese_db->prepare_int( $p_parishioner_id );
	    $sql_now           = $diocese_db->prepare_timestamp( time() );              // Current Time
	    $family = $diocese_db->family_load( $p_family_id );
	    
        if ( $family === false )
        {
            trigger_error( "Family id $p_family_id not found.", E_USER_ERROR );
        }

        //#----------------------------------------------------------------------------------------------
        //# Delete Family Member related to parishioner
        //#----------------------------------------------------------------------------------------------
        $t_core_family_members = table( 'core_family_members' );
        $query = "DELETE FROM $t_core_family_members WHERE family_id = $sql_family_id and parishioner_id=$sql_parishioner_id";
        $rs = &$diocese_db->execute( $query );

        //#----------------------------------------------------------------------------------------------
        //# Delete Parishioner
        //#----------------------------------------------------------------------------------------------
        parishioner_delete( $p_parishioner_id );
        
        //#----------------------------------------------------------------------------------------------
	    //# Update family, to show a change has occured
	    //#----------------------------------------------------------------------------------------------
        $t_core_families = table( 'core_families' );
        $update_familychange="update $t_core_families SET date_updated=$sql_now where family_id=$sql_family_id";
        $rc2 = &$diocese_db->execute( $update_familychange );

    }

    //#----------------------------------------------------------------------------------------------   
    //# Routine:      Add Parishioner to Family
    //# Description:    
    //# History:
    //#----------------------------------------------------------------------------------------------
    function family_add_parishioner( $p_family_id, $p_yob, $p_mob, $p_dob, $p_title, $p_first_name, $p_middle_name, $p_last_name, $p_email, $p_occupation, $p_gender,$p_mobile_phone, $p_primary_parish_id, $p_secondary_parish_id, $p_role, $p_approved, $p_home_number  )
    {
        global $diocese_db;

        //#----------------------------------------------------------------------------------------------
	    //# Define tables
        //#----------------------------------------------------------------------------------------------     
        $t_core_parishioners = table( 'core_parishioners' );
	    $t_core_family_members = table( 'core_family_members' );
	    $t_core_families = table( 'core_families' );
	    
	    
        $birthday = &new Date;
        $birthday->Set( $p_yob, $p_mob, $p_dob );


        //#----------------------------------------------------------------------------------------------
	    //# check that value is not blank
        //#----------------------------------------------------------------------------------------------
	    if($p_first_name == '') 
	    { 
		    trigger_error("First Name is Blank",E_USER_ERROR);
		    exit;
	    }   

        //#----------------------------------------------------------------------------------------------
        //# Escape variables before injecting them in SQL
        //#----------------------------------------------------------------------------------------------
        $sql_family_id      = db_prepare_string( $p_family_id );                    // Title
        $sql_title      	= db_prepare_string( $p_title );                     	// Title
        $sql_first_name 	= db_prepare_string( $p_first_name );                   // First Name
        $sql_middle_name 	= db_prepare_string( $p_middle_name );                  // Middle Name
        $sql_lastname 		= db_prepare_string( $p_last_name );                    // Surname
        $sql_email 		    = db_prepare_string( $p_email );                     	// email
        $sql_occupation         = db_prepare_string( $p_occupation );                // Occupation
	    $sql_gender		    = db_prepare_string( $p_gender );
        $sql_mobile 		= db_prepare_string( $p_mobile_phone );              	// Mobile Number
	    $sql_birthday		= db_prepare_string( $birthday->ToString() );		    // Formated Birthday
        $sql_prim_parish 	= db_prepare_string( $p_primary_parish_id );            // Primary Parish 
        $sql_sec_parish 	= db_prepare_string( $p_secondary_parish_id );          // Secondary Parish
        $sql_role 		    = db_prepare_string( $p_role );                	        // Role
	    $sql_now            = $diocese_db->prepare_timestamp( time() );              // Current Time
	    $sql_approved       = db_prepare_string( $p_approved );
	    $sql_home_phone     = db_prepare_string( $p_home_number );
	    
        //#----------------------------------------------------------------------------------------------
	    //# Insert Parishioners
        //#----------------------------------------------------------------------------------------------
	    $add_parishioner="INSERT INTO $t_core_parishioners (title,first_name,middle_name,last_name,email,occupation,date_of_birth,gender,daytime_phone,mobile_phone,primary_parish_id,secondary_parish_id,approved,date_added,date_updated) VALUES ($sql_title,$sql_first_name,$sql_middle_name,$sql_lastname,$sql_email,$sql_occupation,$sql_birthday,$sql_gender,$sql_home_phone,$sql_mobile,$sql_prim_parish,$sql_sec_parish, $sql_approved, $sql_now, $sql_now)";
	    $rc = &$diocese_db->execute( $add_parishioner );			// Insert new parishioner
    	$new_parishioner_id = $diocese_db->get_insert_id();			// Get parishioner ID

        //#----------------------------------------------------------------------------------------------
        //# Insert 'Core_Family_Members'
        //#----------------------------------------------------------------------------------------------
        $add_corefamilymembers="INSERT INTO $t_core_family_members (family_id,parishioner_id,role) VALUES ('$p_family_id','$new_parishioner_id','$p_role')";
        $rc1 = &$diocese_db->execute( $add_corefamilymembers );      

        //#----------------------------------------------------------------------------------------------
        //# Update family, to show a change has occured	
        //#----------------------------------------------------------------------------------------------
	    $update_familychange="update $t_core_families SET date_updated=$sql_now where family_id=$sql_family_id";
        $rc2 = &$diocese_db->execute( $update_familychange );      
     
    }


    //#----------------------------------------------------------------------------------------------   
    //# Routine:      Update Parishioner attached to a Family
    //# Description:    
    //# History:
    //#----------------------------------------------------------------------------------------------
    function family_update_parishioner( $p_family_id,$p_parishioner_id,$p_title,$p_first_name,$p_middle_name,$p_last_name,$p_dodec,$p_modec,$p_yodec,$p_dob,$p_mob,$p_yob,$p_mobile_phone,$p_day_time_phone,$p_email,$p_occupation,$p_doannul,$p_moannul,$p_yoannul,$p_primary_parish_id,$p_secondary_parish_id,$p_gender)
    {
        global $diocese_db;
        
        //#----------------------------------------------------------------------------------------------
	    //# Prerequisite check
        //#----------------------------------------------------------------------------------------------
	    if($p_first_name == '') 
	    { 
		    trigger_error("First Name is Blank",E_USER_ERROR);
		    exit;
	    }   
	    
        //#----------------------------------------------------------------------------------------------
	    //# Define tables
        //#----------------------------------------------------------------------------------------------     
        $t_core_parishioners = table( 'core_parishioners' );
	    $t_core_family_members = table( 'core_family_members' );
        $t_core_families = table( 'core_families' );
        
        //#----------------------------------------------------------------------------------------------
	    //# Create Dates
        //#----------------------------------------------------------------------------------------------     
	    $decease  = &new Date;
	    $decease->Set( $p_yodec, $p_modec, $p_dodec);
	    $annul  = &new Date;
	    $annul->Set( $p_yoannul, $p_moannul, $p_doannul);
        $birthday = &new Date;
        $birthday->Set( $p_yob, $p_mob, $p_dob );


        //#----------------------------------------------------------------------------------------------
        //# Escape variables before injecting them in SQL
        //#----------------------------------------------------------------------------------------------
        	    
	    $sql_family_id      = $diocese_db->prepare_int( $p_family_id );
        $sql_parishioner_id = $diocese_db->prepare_int( $p_parishioner_id );
        $sql_title      	= db_prepare_string( $p_title );                     	// Title
        $sql_first_name 	= db_prepare_string( $p_first_name );                   // First Name
        $sql_middle_name 	= db_prepare_string( $p_middle_name );                  // Middle Name
        $sql_last_name 		= db_prepare_string( $p_last_name );                    // Surname
        $sql_email 		    = db_prepare_string( $p_email );                     	// email
        $sql_occupation         = db_prepare_string( $p_occupation );
	    $sql_gender		    = db_prepare_string( $p_gender );
        $sql_mobile 		= db_prepare_string( $p_mobile_phone );              	// Mobile Number
	    $sql_birthday		= db_prepare_string( $birthday->ToString() );		    // Formated Birthday
	    $sql_annul		    = db_prepare_string( $annul->ToString() );		        // Formated Annulment
	    $sql_decease		= db_prepare_string( $decease->ToString() );		    // Formated Decease
        $sql_prim_parish 	= db_prepare_string( $p_primary_parish_id );            // Primary Parish 
        $sql_sec_parish 	= db_prepare_string( $p_secondary_parish_id );          // Secondary Parish
      //$sql_role 		    = db_prepare_string( $p_role );                	        // Role
	    $sql_now            = $diocese_db->prepare_timestamp( time() );             // Current Time
	  //$sql_approved       = db_prepare_string( $p_approved );
	    $sql_day_time_phone = db_prepare_string( $p_day_time_phone );
	    
	    
	    
        //#----------------------------------------------------------------------------------------------
	    //# Update Parishioner
        //#----------------------------------------------------------------------------------------------
	    $update_parishioner="UPDATE $t_core_parishioners SET title=$sql_title, first_name=$sql_first_name, middle_name=$sql_middle_name,last_name=$sql_last_name,email=$sql_email,occupation=$sql_occupation, date_of_birth=$sql_birthday,date_of_decease=$sql_decease,date_of_annulment=$sql_annul,gender=$sql_gender,daytime_phone=$sql_day_time_phone,mobile_phone=$sql_mobile,primary_parish_id=$sql_prim_parish,secondary_parish_id=$sql_sec_parish,date_updated=$sql_now WHERE parishioner_id=$sql_parishioner_id";

	    $rc = &$diocese_db->execute( $update_parishioner, 1 );			                // Update parishioner

        //#----------------------------------------------------------------------------------------------
        //# Update 'Core_Family_Members'
        //#----------------------------------------------------------------------------------------------
        //$update_corefamilymembers="UPDATE $t_core_family_members set role=$sql_role WHERE parishioner_id=$sql_parishioner_id";
        //$rc = &$diocese_db->execute( $update_corefamilymembers );      
        
        //#----------------------------------------------------------------------------------------------
        //# Update 'Core_Families' to show a change has occured
        //#----------------------------------------------------------------------------------------------
	    
	    $update_familychange="update $t_core_families SET date_updated=$sql_now where family_id=$sql_family_id";
        $rc = &$diocese_db->execute( $update_familychange );      
      
        
    }







    # returns an array of duplicate ids.
    function family_get_duplicate_ids( $p_family_id )
    {
        global $diocese_db;

        $t_core_families = table( 'core_families' );
        $sql_family_id = $diocese_db->prepare_int( $p_family_id );

        $query = "SELECT f2.family_id as family_id
                         FROM $t_core_families as f1, $t_core_families as f2
                         WHERE ( f1.family_id = $sql_family_id ) AND
                               ( f1.family_id <> f2.family_id ) AND 
                               ( f1.home_phone = f2.home_phone ) AND 
                               ( f1.last_name = f2.last_name )";

        $t_duplicate_ids = array();

        for ( $rs = $diocese_db->execute( $query ); !$rs->EOF; $rs->MoveNext() )
            $t_duplicate_ids[] = $rs->fields['family_id'];

        return $t_duplicate_ids;
    }
?>
