<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003  e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: family_member_inc.php,v 1.10 2004/04/03 14:40:39 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'ark_inc.php' );

    class FamilyMember extends Ark
    {
        function FamilyMember()
        {
            $this->Ark();

            $this->_id = 0;
            $this->_parishioner_id = 0;
            $this->_role = '';
        }

        function is_valid_id( $p_id )
        {
            return is_numeric( $p_id ) && ( $p_id >= 0 );
        }

        function set_id( $p_id )
        {
            $this->_id = $p_id;
            return FamilyMember::is_valid_id( $this->_id );
        }

        function get_id()
        {
            return $this->_id;
        }

        function set_parishioner_id( $p_parishioner_id )
        {
            $this->_parishioner_id = $p_parishioner_id;
            return Parishioner::is_valid_id( $this->_parishioner_id );
        }

        function get_parishioner_id()
        {
            return $this->_parishioner_id;
        }

        function is_valid_role( $p_role )
        {
            $role = trim( $p_role );

            switch( $role )
            {
            case '':    // unknown
            case 'H':   // husband
            case 'W':   // wife
            case 'C':   // child
            case 'S':   // single
            case 'GF':  // grand father
            case 'GM':  // grand mother
            case 'GC':  // grand child
                return true;
            }

            return false;
        }

        function set_role( $p_role )
        {
            $this->_role = trim( $p_role );
            return FamilyMember::is_valid_role( $this->_role );
        }

        function get_role()
        {
            return $this->_role;
        }

        function validate()
        {
            $valid = true;
            $errors = array();

            if ( !FamilyMember::is_valid_id( $this->_id ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid family member id "' . $this->_id . '"';
            }

            if ( !Parishioner::is_valid_id( $this->_parishioner_id ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid family member parishioner id "' . $this->_parishioner_id . '"';
            }

            if ( !FamilyMember::is_valid_role( $this->_role ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid family member role "' . $this->_role . '"';
            }

            return $valid ? true : $errors;            
        }

        function dump()
        {
            $dump  = '<table border="1" cellspacing="0" cellpadding="3" width="100%">';
            $dump .= get_dump_row( 'Family Member Id', $this->_id );

            global $diocese_db;

            $parishioner = $diocese_db->parishioner_load( $this->_parishioner_id );
            $dump .= get_dump_row( 'Parishioner', $parishioner->dump() );
            $dump .= get_dump_row( 'Role', $this->_role );

            $validation_result = $this->validate();
            if ( $validation_result !== true )
            {
                $errors = implode( '<br />', $validation_result );
                $dump .= get_dump_row( 'Validation', $errors );
            }
            else
            {
                $dump .= get_dump_row( 'Validation', '' );
            }

            $dump .= '</table>';

            return $dump;
        }

        //--------------------------------------------------
        // Private Member Attributes
        //--------------------------------------------------

        var $_id;
        var $_parishioner_id;
        var $_role;
    }

    function family_member_get_role_id_name_map( $p_extra_entries = array() )
    {
        $map = $p_extra_entries;
        $map['H'] = 'Husband';
        $map['W'] = 'Wife';
        $map['C'] = 'Child';
        $map['GF'] = 'Grand Father';
        $map['GM'] = 'Grand Mother';
        $map['S'] = 'Single';
        $map['WD'] = 'Widow';

        return $map;
    }
?>