<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003  e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: parish_inc.php,v 1.11 2004/04/07 10:21:43 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'ark_inc.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'address_inc.php' );

    class Parish extends Ark
    {
        function Parish()
        {
            $this->Ark();

            $this->_id = 0;
            $this->_name = '';
            $this->_address_id = '';
            $this->_postal_address_id = '';
            $this->_phone = '';
            $this->_phone2 = '';
            $this->_fax = '';
            $this->_website = '';
            $this->_email = '';
            $this->_extra_info = array();
        }

        function is_valid_id( $p_id )
        {
            return $p_id >= 0;
        }

        function set_id( $p_parish_id )
        {
            $this->_id = $p_parish_id;
            return Parish::is_valid_id( $this->_id );
        }

        function get_id()
        {
            return $this->_id;
        }

        function is_valid_name( $p_name )
        {
            return !is_blank( $p_name );
        }

        function set_name( $p_name )
        {
            $this->_name = trim( $p_name );
            return Parish::is_valid_name( $this->_name );
        }

        function get_name()
        {
            return $this->_name;
        }

        function is_valid_address_id( $p_address_id )
        {
            return $p_address_id >= 0;
        }

        function set_address_id( $p_address_id )
        {
            $this->_address_id = (integer)$p_address_id;
            return Parish::is_valid_address_id( $this->_address_id );
        }

        function get_address_id()
        {
            return $this->_address_id;
        }

        function is_valid_postal_address_id( $p_postal_address_id )
        {
            return $p_postal_address_id >= 0;
        }

        function set_postal_address_id( $p_postal_address_id )
        {
            $this->_postal_address_id = (integer)$p_postal_address_id;
            return Parish::is_valid_postal_address_id( $p_postal_address_id );
        }

        function get_postal_address_id()
        {
            return $this->_postal_address_id;
        }

        function is_valid_phone( $p_phone )
        {
            return is_blank( $p_phone ) || is_valid_phone( $p_phone );
        }

        function set_phone( $p_phone )
        {
            $this->_phone = trim( $p_phone );
            return Parish::is_valid_phone( $this->_phone );
        }

        function get_phone()
        {
            return $this->_phone;
        }

        function is_valid_phone2( $p_phone2 )
        {
            return is_blank( $p_phone2 ) || is_valid_phone( $p_phone2 );
        }

        function set_phone2( $p_phone2 )
        {
            $this->_phone2 = trim( $p_phone2 );
            return Parish::is_valid_phone2( $this->_phone2 );
        }

        function get_phone2()
        {
            return $this->_phone2;
        }

        function is_valid_fax( $p_fax )
        {
            return is_blank( $p_fax ) || is_valid_phone( $p_fax );
        }

        function set_fax( $p_fax )
        {
            $this->_fax = trim( $p_fax );
            return Parish::is_valid_fax( $this->_fax );
        }

        function get_fax()
        {
            return $this->_fax;
        }

        function is_valid_website( $p_website )
        {
            return true;
        }

        function set_website( $p_website )
        {
            $this->_website = trim( $p_website );
            return Parish::is_valid_website( $this->_website );
        }

        function get_website()
        {
            return $this->_website;
        }

        function is_valid_email( $p_email )
        {
            return true;
        }

        function set_email( $p_email )
        {
            $this->_email = trim( $p_email );
            return Parish::is_valid_email( $this->_email );
        }

        function get_email()
        {
            return $this->_email;
        }
  
        /**
         * Return all parish information as a string.
         *
         * @return (string) Dump of all parishioner data
         */
        function dump()
        {
            $dump  = '<table border="1" cellspacing="0" cellpadding="3" width="100%">';
            $dump .= get_dump_row( 'Parish Id', $this->_id );
            $dump .= get_dump_row( 'Name', $this->_name );
            $dump .= get_dump_row( 'Phone', $this->_phone );
            $dump .= get_dump_row( 'Phone2', $this->_phone2 );
            $dump .= get_dump_row( 'Fax', $this->_fax );
            $dump .= get_dump_row( 'Email', $this->_email );
            $dump .= get_dump_row( 'Website', $this->_website );

            global $diocese_db;

            if ( $this->_address_id != 0 )
            {
                $address = $diocese_db->address_load( $this->_address_id );
                if ( $address !== false )
                    $dump .= get_dump_row( 'Address', $address->dump() );
                else
                    $dump .= get_dump_row( 'Address Id', $this->_address_id . ' (not found)' );
            }
            else
                $dump .= get_dump_row( 'Address', 'Not Available' );

            $dump .= get_dump_row( 'Postal Address Id', $this->_postal_address_id );

            foreach ( $this->_extra_info as $field => $value )
                $dump .= get_dump_row( "$field (extra)", $value );

            $validation_result = $this->validate();
            if ( $validation_result !== true )
            {
                $errors = implode( '<br />', $validation_result );
                $dump .= get_dump_row( 'Validation', $errors );
            }
            else
            {
                $dump .= get_dump_row( 'Validation', '' );
            }

            $dump .= '</table>';

            return $dump;
        }

        /**
         * Validates all parishioner information
         *
         * @retval true   All parishioner information is valid.
         * @retval errors (array) of strings that describes all errors.
         */
        function validate()
        {
            $valid = true;
            $errors = array();

            if ( !Parish::is_valid_id( $this->_id ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid parish id';
            }

            if ( !Parish::is_valid_name( $this->_name ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid parish name';
            }

            if ( !Parish::is_valid_email( $this->_email ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid parish email';
            }

            if ( !Parish::is_valid_website( $this->_website ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid parish website';
            }

            if ( !Parish::is_valid_phone( $this->_phone ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid parish phone number';
            }

            if ( !Parish::is_valid_phone2( $this->_phone2 ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid parish phone2 number';
            }

            if ( !Parish::is_valid_fax( $this->_fax ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid parish fax number';
            }

            if ( !Parish::is_valid_address_id( $this->_address_id ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid parish address id';
            }

            if ( !Parish::is_valid_postal_address_id( $this->_postal_address_id ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid parish postal address id';
            }


            return $valid ? true : $errors;
        }

        //
        // Private
        //

        var $_id;
        var $_name;
        var $_address_id;
        var $_postal_address_id;
        var $_phone;
        var $_phone2;
        var $_fax;
        var $_website;
        var $_email;
        var $_extra_info;
    }

    function parish_get_id_name_map( $p_extra_entries = array(), $p_show_accessible_only = true )
    {
        global $diocese_db;

        $t_core_parishes = table( 'core_parishes' );

        $query = "SELECT parish_id, name FROM $t_core_parishes";

        if ( $p_show_accessible_only )
        {
            if ( access_limited_to_one_parish() )
                $query .= ' WHERE parish_id = ' . access_get_parish_id();
        }

        $recordSet = &$diocese_db->execute( $query );

        $t_parishes = $p_extra_entries;

        while ( !$recordSet->EOF )
        {
            $t_parishes[$recordSet->fields['parish_id']] = $recordSet->fields['name'];
            $recordSet->MoveNext(); 
        }

        return $t_parishes;
    }

    function parish_get_id( $p_parish_name )
    {
        global $diocese_db;

        $t_core_parishes = table( 'core_parishes' );

        $sql_parish_name = $diocese_db->prepare_string( $p_parish_name );

        $query = "SELECT parish_id FROM $t_core_parishes WHERE name = $sql_parish_name";

        return $diocese_db->get_one( $query );
    }

    function parish_get_field( $p_parish_id, $p_field_name )
    {
        global $diocese_db;

        $t_core_parishes = table( 'core_parishes' );

        $sql_parish_id = $diocese_db->prepare_int( $p_parish_id );
        $sql_field_name = $p_field_name; // can't prepare this one, otherwise quotes will be added

        $query = "SELECT $sql_field_name FROM $t_core_parishes WHERE parish_id = $sql_parish_id";

        return $diocese_db->get_one( $query );
    }
?>
