<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003  e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: parishioner_inc.php,v 1.27 2004/04/15 14:44:39 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'ark_inc.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'validate_au.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'utils_api_inc.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'date_inc.php' );

    /**
     * Parishioner class stores/validates all the information about a
     * parishioner.  This class is NOT repsonsible for saving
     * parishioner info to or retrieving it from the database.
     *
     * :TODO: In the import code add checking for duplicate full names
     * :TODO: In the import code add checking for duplicate mobile numbers
     *
     * General Rules:
     *   - Set methods validate the data and returns true/false accordingly.
     *   - Set methods set the value even if the value is not valid.
     *   - Validate() method validates all attributes.
     *   - Data will only be saved to database if the validate() method returns
     *     true.
     *
     * @sa Family
     */
    class Parishioner extends Ark
    {
        /**
         * Constructor
         */
        function Parishioner()
        {
            $this->Ark();

            $this->_id = 0;  // id 0 means new parishioner that is not yet saved in the db
            $this->_title = '';
            $this->_first_name = '';
            $this->_middle_name = '';
            $this->_last_name = '';
            $this->_mobile = '';
            $this->_day_time_phone = '';
            $this->_email = '';
            $this->_occupation = '';
            $this->_date_of_annulment = Date::get_null_date();
            $this->_date_of_birth = Date::get_null_date();
            $this->_date_of_decease = Date::get_null_date();
            $this->_gender = '';
            $this->_primary_parish_id = 0;
            $this->_secondary_parish_id = 0;
            $this->_approved = 1;
            $this->_date_added = time();
            $this->_date_updated = time();
            $this->_extra_info = array();
        }

        function is_valid_id( $p_id )
        {
            return is_numeric( $p_id ) && ( $p_id >= 0 );
        }

        /**
         * Set the database id for the parishioner.
         *
         * If the parishioner id is zero, this means that this is a new parishioner
         * record, otherwise, the parishioner already exists in the database.
         *
         * @param $p_id    Parishioner database id.
         *
         * @retval true    Parishioner id set successfully.
         * @retval false   Invalid parishioner id.
         */
        function set_id( $p_id )
        {
            $this->_id = $p_id;
            return Parishioner::is_valid_id( $p_id );
        }

        /**
         * Get the database id of the parishioner.
         *
         * @return Parishioner database id.
         */
        function get_id()
        {
            return $this->_id;
        }

        function is_valid_title( $p_title )
        {
            // :TODO: implement parishioner::is_valid_title()
            return true;
        }

        /**
         * Set parishioner's title.
         *
         * @param $p_title Parishioners title (eg: Mr. Ms., Dr.)
         *
         * @retval true  Title set successfully
         * @retval false Invalid parishioner title.
         */
        function set_title( $p_title )
        {
            $this->_title = trim( $p_title );
            return Parishioner::is_valid_title( $p_title );
        }

        /**
         * Get parishioner's title
         *
         * @return Parishioner title (can be empty)
         */
        function get_title()
        {
            return $this->_title;
        }

        function is_valid_first_name( $p_first_name )
        {
            return is_valid_name( $p_first_name );
        }

        /**
         * Set first name of parishioner
         *
         * @param $p_first_name (string) Parishioner's first name (can't be empty)
         *
         * @retval true  Parishioner first name set successfully
         * @retval false Invalid parishioners first name.
         */
        function set_first_name( $p_first_name )
        {
            $p_first_name = trim($p_first_name);
            $this->_first_name = $p_first_name;

            return Parishioner::is_valid_first_name( $p_first_name );
        }

        /**
         * Get parishioner's first name
         *
         * @return (string) first name
         */
        function get_first_name()
        {
            return $this->_first_name;
        }

        function is_valid_middle_name( $p_middle_name )
        {
            $p_middle_name = trim( $p_middle_name );
            if ( $p_middle_name === '' )
                return true;

            return is_valid_name( $p_middle_name );
        }

        /**
         * Set the parishioner's middle name (can be empty)
         *
         * @param $p_middle_name  (string) Parishioner's middle name. (can be empty)
         *
         * @retval true  success
         * @retval false failure
         */
        function set_middle_name( $p_middle_name )
        {
            $p_middle_name = trim( $p_middle_name );
            $this->_middle_name = $p_middle_name;

            return Parishioner::is_valid_middle_name( $p_middle_name );
        }

        /**
         * Get parishioner's middle name
         *
         * @return (string) middle name
         */
        function get_middle_name()
        {
            return $this->_middle_name;
        }

        function is_valid_last_name( $p_last_name )
        {
           return is_valid_name( $p_last_name );
        }

        /**
         * Set parishioner's last name
         *
         * @param $p_last_name  Parishioner's last name (can't be empty)
         *
         * @retval true  success
         * @retval false failure
         */
        function set_last_name( $p_last_name )
        {
           $this->_last_name = trim( $p_last_name );
           return Parishioner::is_valid_last_name( $p_last_name );
        }

        /**
         * Get parishioner's last name
         *
         * @return (string) last name
         */
        function get_last_name()
        {
            return $this->_last_name;
        }

        function is_valid_date_of_birth( $p_date )
        {
            return ( $p_date === null ) || ( is_valid_date( $p_date ) );
        }

        /**
         * Set date of birth
         *
         * @param $p_date  (string) Date of birth in a format that can be
         *                 passed to date() PHP function.
         *
         * @retval true   Date of birth set successfully.
         * @retval false  Invalid date of birth.
         */
        function set_date_of_birth( $p_date )
        {
            $this->_date_of_birth = $p_date;
            return Parishioner::is_valid_date_of_birth( $p_date );
        }

        /**
         * Get parishioner's date of birth
         *
         * @return Date of birth in a format that can be passed to date()
         *         PHP function.  If date of birth is unknown, this method
         *         will return an empty string.
         */
        function get_date_of_birth()
        {
            return $this->_date_of_birth;
        }
        

        /**
         * Get parishioner's date of birth  as Day, Month or Year
         *
         * @return Date of birth in a format that can be passed to date()
         *         PHP function.  If date of birth is unknown, this method
         *         will return an empty string.
         */
        function get_date_of_birth_split( $p_split)
        {
            $p_dob=$this->_date_of_birth;
            
            list($p_year, $p_month, $p_day) = split("-", $this->_date_of_birth, 3);
   
            //$months = array( 'JAN'=>'01', 'FEB'=>'02', 'MAR'=>'03', 'APR'=>'04', 'MAY'=>'05', 'JUN'=>'06',
            //                 'JUL'=>'07', 'AUG'=>'08', 'SEP'=>'09', 'OCT'=>'10', 'NOV'=>'11', 'DEC'=>'12' );
            
            switch ($p_split)
            {
                case 'day':
                    $t_return=$p_day;
                break;
                
                case 'month':
                    $t_return=$p_month;
                break;
                
                case 'year':
                    $t_return=$p_year;
                break;
                
                default:
                    $t_return=-1;
                break;
            }
            
            return $t_return;
        }
        
                /**
         * Get parishioner's annulment date.
         *
         * @return Annulment date in the format that can be sent to date() PHP
         *         function or an empty string.
         */
        function get_date_of_annulment_split( $p_split)
        {
           list($p_year, $p_month, $p_day) = split("-", $this->_date_of_annulment, 3);
            
            switch ($p_split)
            {
                case 'day':
                    $t_return=$p_day;
                break;
                
                case 'month':
                    $t_return=$p_month;
                break;
                
                case 'year':
                    $t_return=$p_year;
                break;
                
                default:
                    $t_return=-1;
                break;
            }
            
            return $t_return;
        
        
        }
        
        
         /**
         * Get parishioner's date of decease
         *
         * @return Date of decease in a format that can be passed to date()
         *         PHP method.  If not known or not applicable, an empty string
         *         will be returned.
         */
        function get_date_of_decease_split( $p_split)
        {
         
            
            list($p_year, $p_month, $p_day) = split("-", $this->_date_of_decease, 3);
   
            //$months = array( 'JAN'=>'01', 'FEB'=>'02', 'MAR'=>'03', 'APR'=>'04', 'MAY'=>'05', 'JUN'=>'06',
            //                 'JUL'=>'07', 'AUG'=>'08', 'SEP'=>'09', 'OCT'=>'10', 'NOV'=>'11', 'DEC'=>'12' );
            
            switch ($p_split)
            {
                case 'day':
                    $t_return=$p_day;
                break;
                
                case 'month':
                    $t_return=$p_month;
                break;
                
                case 'year':
                    $t_return=$p_year;
                break;
                
                default:
                    $t_return=-1;
                break;
            }
            
            return $t_return;
           
        }

        
        
        


        function is_valid_date_of_decease( $p_date )
        {
            return ( $p_date === null ) || ( is_valid_date( $p_date ) );
        }

        /**
         * Set parishioner's date of decease
         *
         * @param $p_date (string) Date of birth in a format that can be
         *                passed to date() PHP function.  If not applicable
         *                or not know an empty string can be sent.
         *
         * @retval true  Date of decease set successfully.
         * @retval false Invalid date of decease.
         */
        function set_date_of_decease( $p_date )
        {
            $this->_date_of_decease = $p_date;
            return Parishioner::is_valid_date_of_decease( $p_date );
        }

        /**
         * Get parishioner's date of decease
         *
         * @return Date of decease in a format that can be passed to date()
         *         PHP method.  If not known or not applicable, an empty string
         *         will be returned.
         */
        function get_date_of_decease()
        {
            return $this->_date_of_decease;
        }

        function is_valid_mobile_number( $p_mobile )
        {
            if ( strlen( trim( $p_mobile ) ) == 0 )
                return true;

            // isValidMobileNumber returns normalised number or false.
            return Validate_AU::isValidMobileNumber( $p_mobile ) !== false;
        }

        /**
         * Set mobile number
         *
         * @param $p_mobile  (string) Parishioner mobile phone number
         *
         * @retval true  Mobile number set successfully
         * @retval false Invalid mobile number.
         */
        function set_mobile_number( $p_mobile )
        {
            $this->_mobile = Validate_AU::_normalisePhoneNumber( $p_mobile );
            if ( $this->_mobile == '' )
                return true;

            $normalised = Validate_AU::isValidMobileNumber( $this->_mobile );
            if ($normalised === false)
                return false;

            $this->_mobile = $normalised;

            return true;
        }

        /**
         * Get mobile phone number
         *
         * @return (string) mobile phone number
         */
        function get_mobile_number()
        {
           return $this->_mobile;
        }

        function is_valid_day_time_phone( $p_phone )
        {
            // :TODO: validate phone as landline/mobile if not empty.
            return true;
        }

        /**
         * Set daytime phone number.
         *
         * @param $p_phone  Phone number, must be a valid landline or mobile number.
         *
         * @retval true  Daytime phone set successfully.
         * @retval false Invalid daytime phone.
         */
        function set_day_time_phone( $p_phone )
        {
            $this->_day_time_phone = $p_phone;
            return Parishioner::is_valid_day_time_phone( $p_phone );
        }

        /**
         * Get daytime phone number.
         *
         * @return Daytime phone number, or empty string.
         */
        function get_day_time_phone()
        {
            return $this->_day_time_phone;
        }

        function is_valid_email( $p_email )
        {
            $p_email = trim( $p_email );
            return ( ( $p_email === '' ) || ( is_valid_email( $p_email ) ) );
        }

        /**
         * Set parishioner's email address.
         *
         * @param $p_email  Valid email address or empty string.
         *
         * @retval true  Email set successfully.f
         * @retval false Invalid email address.
         */
        function set_email( $p_email )
        {
            $this->_email = $p_email;
            return Parishioner::is_valid_email( $p_email );
        }

        /**
         * Get parishioner's email address.
         *
         * @return Email address or empty string.
         */
        function get_email()
        {
            return $this->_email;
        }

        function is_valid_occupation( $p_occupation )
        {
            return true;
        }

        function set_occupation( $p_occupation )
        {
            $this->_occupation = trim( $p_occupation );
            return Parishioner::is_valid_occupation( $p_occupation );
        }

        function get_occupation()
        {
            return $this->_occupation;
        }

        function is_valid_date_of_annulment( $p_date )
        {
            return ( $p_date == null ) || is_valid_date( $p_date );
        }

        /**
         * Set parishioner's annulment date if applicable.
         *
         * @param $p_date Annulment date in the format acceppted by the date()
         *                PHP function or an empty string.
         *
         * @retval true   Annulment date set successfully.
         * @retval false  Invalid annulment date.
         */
        function set_date_of_annulment( $p_date )
        {
            $this->_date_of_annulment = $p_date;
            return Parishioner::is_valid_date_of_annulment( $p_date );
        }

        /**
         * Get parishioner's annulment date.
         *
         * @return Annulment date in the format that can be sent to date() PHP
         *         function or an empty string.
         */
        function get_date_of_annulment()
        {
           return $this->_date_of_annulment;
        }

        function is_valid_parish_id ( $p_parish_id )
        {
            return ( is_numeric( $p_parish_id ) && ( $p_parish_id >= 0 ) );
        }

        /**
         * Set primary parish ID for the parishioner.
         *
         * @param $p_parish_id  The id of the main parish that the parishioners goes to.
         *
         * @retval true  Parish Id set successfully.
         * @retval false Invalid parish id.
         *
         * @sa set_secondary_parish_id()
         */
        function set_primary_parish_id( $p_parish_id )
        {
           $this->_primary_parish_id = $p_parish_id;
           return Parishioner::is_valid_parish_id( $p_parish_id );
        }

        /**
         * Get id of the main parish that the parishioner goes to.
         *
         * @return Primary parish id, can be 0,
         */
        function get_primary_parish_id()
        {
           return $this->_primary_parish_id;
        }

        /**
         * Set id of the secondary parish that the parishioner goes to.
         *
         * @param $p_parish_id  Parish id.
         *
         * @retval true  Parish id set successfully.
         * @retval false Invalid parish id.
         *
         * @sa set_primary_parish_id()
         */
        function set_secondary_parish_id( $p_parish_id )
        {
           $this->_secondary_parish_id = $p_parish_id;
           return Parishioner::is_valid_parish_id( $p_parish_id );
        }

        /**
         * Get id of the secondary parish that the parishioner goes to.
         *
         * @return Secondary parish id, will be 0 most of the time.
         */
        function get_secondary_parish_id()
        {
            return $this->_secondary_parish_id;
        }

        function is_valid_gender( $p_gender )
        {
            $p_gender = strtoupper( trim( $p_gender ) );
            switch ( $p_gender )
            {
            case 'M':
            case 'F':
            case '':
                return true;

            default:
                return false;
            }
        }

        /**
         * Set parishioner gender
         *
         * @param $p_gender (char) 'M', 'F', or ''
         *
         * @retval true  Gender set successfully
         * @retval false Invalid gender
         */
        function set_gender( $p_gender )
        {
            $p_gender = strtoupper( trim( $p_gender ) );
            $this->_gender = $p_gender;

            return Parishioner::is_valid_gender( $p_gender );
        }

        /**
         * Gets the parishioner's gender.
         *
         * @return (string) 'M', 'F', or ''
         */
        function get_gender()
        {
            return $this->_gender;
        }

        function set_approved( $p_approved )
        {
            $this->_approved = $p_approved ? 1 : 0;
        }

        function get_approved()
        {
            return $this->_approved;
        }

        function set_date_added( $p_timestamp = null )
        {
            if ( $p_timestamp === null )
                $p_timestamp = time();

            $this->_date_added = $p_timestamp;
        }

        function get_date_added()
        {
            return $this->_date_added;
        }

        function set_date_updated( $p_timestamp = null )
        {
            if ( $p_timestamp === null )
                $p_timestamp = time();

            $this->_date_updated = $p_timestamp;
        }

        function get_date_updated()
        {
            return $this->_date_updated;
        }

        /**
         * Set extra information about the parishioner that was
         * collected in the census but does not exist in the
         * parishioner core information.  The aim is to save this
         * information in a generic table and be able to import
         * later on when application specific tables are added.
         * eg: confession father, baptism date, occupation.
         *
         * @param $p_field (string) Description of the information (eg:
         *                          occupation)
         * @param $p_value (string) Value of the field
         *
         * @retval true    Extra field set successfully
         * @retval false   Invalid extra field
         */
        function set_extra_information( $p_field, $p_value )
        {
            $p_field = strtoupper( trim( $p_field ) );
            $p_value = trim( $p_value );

            if ( ( strlen( $p_field ) == 0 ) || ( strlen( $p_value ) == 0 ) )
                return false;

            $this->_extra_info[$p_field] = trim( $p_value );
            return true;
        }

        function get_extra_information( $p_field )
        {
            $p_field = strtoupper( trim( $p_field ) );
            if ( ( strlen( $p_field ) == 0 ) || ( !isset( $this->_extra_info[$p_field] ) ) )
                return false;

            return $this->_extra_info[$p_field];
        }

        /**
         * Return all parishioner information as a string.
         *
         * @return (string) Dump of all parishioner data
         */
        function dump()
        {
            global $cfg_timestamp_format;

            $dump  = '<table border="1" cellspacing="0" cellpadding="3" width="100%">';
            $dump .= get_dump_row( 'Parishioner Id', $this->_id );
            $dump .= get_dump_row( 'Title', $this->_title );
            $dump .= get_dump_row( 'First Name', $this->_first_name );
            $dump .= get_dump_row( 'Middle Name', $this->_middle_name );
            $dump .= get_dump_row( 'Surname', $this->_last_name );
            $dump .= get_dump_row( 'Date of birth', format_date( $this->_date_of_birth ) );
            $dump .= get_dump_row( 'Date of annulment', format_date( $this->_date_of_annulment ) );
            $dump .= get_dump_row( 'Date of decease', format_date( $this->_date_of_decease ) );
            $dump .= get_dump_row( 'Email', $this->_email );
            $dump .= get_dump_row( 'Occupation', $this->_occupation );
            $dump .= get_dump_row( 'Mobile', $this->_mobile );
            $dump .= get_dump_row( 'Day time phone', $this->_day_time_phone );
            $dump .= get_dump_row( 'Gender', $this->_gender );
            $dump .= get_dump_row( 'Primary Parish Id', $this->_primary_parish_id );
            $dump .= get_dump_row( 'Secondary Parish Id', $this->_secondary_parish_id );
            $dump .= get_dump_row( 'Approved', ( $this->_approved == 1 ) ? 'yes' : 'no'  );
            $dump .= get_dump_row( 'Date Added', date( $cfg_timestamp_format, $this->_date_added ) );
            $dump .= get_dump_row( 'Date Updated', date( $cfg_timestamp_format, $this->_date_updated ) );

            foreach ( $this->_extra_info as $field => $value )
                $dump .= get_dump_row( "$field (extra)", $value );

            $validation_result = $this->validate();
            if ( $validation_result !== true )
            {
                $errors = implode( '<br />', $validation_result );
                $dump .= get_dump_row( 'Validation', $errors );
            }
            else
            {
                $dump .= get_dump_row( 'Validation', '' );
            }

            $dump .= '</table>';

            return $dump;
        }

        /**
         * Validates all parishioner information
         *
         * @retval true   All parishioner information is valid.
         * @retval errors (array) of strings that describes all errors.
         */
        function validate()
        {
            $valid = true;
            $errors = array();

            if ( !Parishioner::is_valid_id( $this->_id ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner id '" . $this->_id . "'";
            }

            if ( !Parishioner::is_valid_title( $this->_title ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner title '" . $this->_title . "'";
            }

            if ( !Parishioner::is_valid_first_name( $this->_first_name ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner first name '" . $this->_first_name . "'";
            }

            if ( !Parishioner::is_valid_middle_name( $this->_middle_name ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner middle name '" . $this->_middle_name . "'";
            }

            if ( !Parishioner::is_valid_last_name( $this->_last_name ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner last name '" . $this->_last_name . "'";
            }

            if ( !Parishioner::is_valid_date_of_birth( $this->_date_of_birth ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner date of birth '" . $this->_date_of_birth . "'";
            }

            if ( !Parishioner::is_valid_date_of_decease( $this->_date_of_decease ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner date of decease '" . $this->_date_of_decease . "'";
            }

            if ( !Parishioner::is_valid_date_of_annulment( $this->_date_of_annulment ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner date of annulment '" . $this->_date_of_annulment . "'";
            }

            if ( !Parishioner::is_valid_email( $this->_email ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner email '" . $this->_email . "'";
            }

            if ( !Parishioner::is_valid_occupation( $this->_occupation ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner occupation '" . $this->_occupation . "'";
            }

            if ( !Parishioner::is_valid_mobile_number( $this->_mobile ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner mobile number '" . $this->_mobile . "'";
            }

            if ( !Parishioner::is_valid_day_time_phone( $this->_day_time_phone ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner day time phone number '" . $this->_day_time_phone . "'";
            }

            if ( !Parishioner::is_valid_gender( $this->_gender ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner gender '" . $this->_gender . "'";
            }

            if ( !Parishioner::is_valid_parish_id( $this->_primary_parish_id ) )
            {
                $valid = false;
                $errors[] = "Error: Invalid parishioner primary parishioner id '" . $this->_primary_parish_id . "'";
            }

            if ( !Parishioner::is_valid_parish_id( $this->_secondary_parish_id ) )
            {
                $valid = false;
                $errors[] = "Error:Invalid parishioner secondary parishioner id '" . $this->_secondary_parish_id . "'";
            }

            return $valid ? true : $errors;
        }

        //--------------------------------------------------
        // Private Member Attributes
        //--------------------------------------------------

        var $_id;             ///< Parishioner id in the database (integer)
        var $_title;          ///< Mr., Mrs., Ms., Dr., ...etc (string, optional)
        var $_first_name;     ///< First name (string, mandatory)
        var $_middle_name;    ///< Middle name (string, optional)
        var $_last_name;      ///< Last name (string, mandatory)
        var $_mobile;         ///< Mobile (string, optional)
        var $_day_time_phone; ///< Day time phone number (string, optional)
        var $_email;          ///< Email address (string, optional)
        var $_occupation;     ///< Parishioner's job
        var $_date_of_annulment; ///< Date of annulment (string, optional)
        var $_date_of_birth;  ///< Date of birth (string, optional)
        var $_date_of_decease; ///< Date of decease (string, optional)
        var $_gender;         ///< Gender (string, optional)
        var $_primary_parish_id; ///< Primary Church Id (integer)
        var $_secondary_parish_id; ///< Secondary Church Id (integer)
        var $_approved;       ///< 1 if trusted, 0 if entered anonymously through the web
        var $_date_added;
        var $_date_updated;
        var $_extra_info;     ///< Extra information about the parishioners ( array, attribute => value )
    };

    function gender_get_id_name_map()
    {
        $map = array( '' => 'Not specified', 'F' => 'Female', 'M' => 'Male' );
        return $map;
    }

    function title_get_all()
    {
        return array( '', 'Mr.', 'Master', 'Mrs.', 'Miss', 'Ms.', 'Dr.', 'Father' );
    }

    # approve parishioner and all its family members in the database.
    function parishioner_approve( $p_parishioner_id )
    {
        global $diocese_db;

        $parishioner = $diocese_db->parishioner_load( $p_parishioner_id );
        $parishioner->set_date_updated();
        $parishioner->set_approved(1);
        $diocese_db->parishioner_save( $parishioner );
    }

    function parishioner_delete( $p_parishioner_id )
    {
        global $diocese_db;

        $sql_parishioner_id = $diocese_db->prepare_int( $p_parishioner_id );

        # Delete Parishioner Record
	$t_core_parishioners = table( 'core_parishioners' );
        $query = "DELETE FROM $t_core_parishioners WHERE parishioner_id = $sql_parishioner_id";
        $rs = &$diocese_db->execute( $query );

        # Delete corresponding family member records
        $t_core_family_members = table( 'core_family_members' );
        $query = "DELETE FROM $t_core_family_members WHERE parishioner_id = $sql_parishioner_id";
        $rs = &$diocese_db->execute( $query );
    }

    # Get all accessible parishioner ids
    function parishioner_get_all_ids()
    {
        global $diocese_db;

        $t_core_parishioners = table( 'core_parishioners' );

        $query = "SELECT parishioner_id from $t_core_parishioners";

        if ( access_limited_to_one_parish() )
            $query .= " WHERE primary_parish_id = " . access_get_parish_id();

        $t_parishioner_ids = array();
        for ( $rs = &$diocese_db->execute( $query ); !$rs->EOF; $rs->MoveNext() )
            $t_parishioner_ids[] = $rs->fields['parishioner_id'];

        return $t_parishioner_ids;
    }

    function parishioner_get_family_ids( $p_parishioner_id )
    {
        global $diocese_db;

        $sql_parishioner_id = $diocese_db->prepare_int( $p_parishioner_id );

        $t_core_family_members = table( 'core_family_members' );

        $t_family_ids = array();

        $query = "SELECT family_id FROM $t_core_family_members WHERE parishioner_id = $sql_parishioner_id";

        for ( $rs = $diocese_db->execute( $query ); !$rs->EOF; $rs->MoveNext() )
            $t_family_ids[] = $rs->fields['family_id'];

        return $t_family_ids;
    }
?>