<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: priest_inc.php,v 1.7 2004/03/27 06:08:03 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'ark_inc.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'date_inc.php' );
    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'utils_api_inc.php' );

    class Priest extends Ark
    {
        /**
         * Constructor
         */
        function Priest()
        {
            $this->Ark();


            $this->_id = 0;
            $this->_parishioner_id = 0;
            $this->_date_of_ordainment = Date::get_null_date();
        }

        function is_valid_id( $p_id )
        {
            return $p_id >= 0;
        }

        function set_id( $p_id )
        {
            $this->_id = (integer)$p_id;
            Priest::is_valid_id( $p_id );
        }

        function get_id()
        {
            return $this->_id;
        }

        function is_valid_parishioner_id( $p_parishioner_id )
        {
            return $p_parishioner_id > 0;
        }

        function set_parishioner_id( $p_parishioner_id )
        {
            $this->_parishioner_id = (integer)$p_parishioner_id;
            return Priest::is_valid_parishioner_id( $p_parishioner_id );
        }

        function get_parishioner_id()
        {
            return $this->_parishioner_id;
        }

        function is_valid_date_of_ordainment( $p_date )
        {
            return ( $p_date === null ) || ( is_valid_date( $p_date ) );
        }

        function set_date_of_ordainment( $p_date )
        {
            $this->_date_of_ordainment = $p_date;
            return Parishioner::is_valid_date_of_ordainment( $p_date );
        }

        function get_date_of_ordainment()
        {
            return $this->_date_of_ordainment;
        }

        function validate()
        {
            $valid = true;
            $errors = array();

            if ( !Priest::is_valid_id( $this->_id ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid priest id "' . $this->_id . '"';
            }

            if ( !Priest::is_valid_id( $this->_parishioner_id ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid priest parishioner id "' . $this->_parishioner_id . '"';
            }

            if ( !Priest::is_valid_date_of_ordainment( $this->_date_of_ordainment ) )
            {
                $valid = false;
                $errors[] = 'Error: Invalid priest ordainment date "' . $this->_date_of_ordainment . '"';
            }

            return $valid ? true : $errors;            
        }

        function dump()
        {
            $dump  = '<table border="1" cellspacing="0" cellpadding="3" width="100%">';
            $dump .= get_dump_row( 'Priest Id', $this->_id );
            $dump .= get_dump_row( 'Parishioner Id', $this->_parishioner_id );
            $dump .= get_dump_row( 'Ordainment Date', format_date( $this->_date_of_ordainment ) );

            $validation_result = $this->validate();
            if ( $validation_result !== true )
            {
                $errors = implode( '<br />', $validation_result );
                $dump .= get_dump_row( 'Validation', $errors );
            }
            else
            {
                $dump .= get_dump_row( 'Validation', '' );
            }

            $dump .= '</table>';

            return $dump;
        }

        //--------------------------------------------------
        // Private Member Attributes
        //--------------------------------------------------

        var $_id;
        var $_parishioner_id;
        var $_date_of_ordainment;
    }
?>
