<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003  e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: utils_api_inc.php,v 1.20 2004/10/14 10:50:37 vboctor Exp $
    # -------------------------------------------------------------------------

    function is_blank( $value )
    {
       $value = trim( $value );
       return ( strlen( $value ) == 0 );
    }

    //this function ensures that the empty fields do not print ""
    function is_blank2( $str )
    {
        if ( is_blank( $str ) )
        {
            return true;
        }
		
        $str = trim( $str );
        if ( ( $str == '\'\'') || ( $str == '\'%%\'' ) )
        {
            return true;
        }

        return false;
    }
	
    function get_dump_row( $field, $value )
    {
        if ( is_blank( $value ) )
            $value = '&nbsp;';

        return "<tr valign=\"top\"><th align=\"left\">$field</th><td>$value</td></tr>\n";
    }

    /**
     * Validate a name, this can be first/middle/ or last name.
     * if the supplied name is empty.
     *
     * @retval true   valid name
     * @retval false  invalid name
     *
     * :TODO: move to Validate_XXXX
     */
    function is_valid_name( $p_name )
    {
        $t_name = trim( $p_name );
        return preg_match('/^[A-Za-z\-\'\(\) ]+$/', $t_name);
    }

    function is_valid_date ( $p_date )
    {
        $date = new Date();
        if ( $date->FromString( $p_date ) === false )
            return false;

        return true;
    }

    function is_valid_email ( $p_email )
    {
        return true;
    }

    function is_valid_phone( $p_phone )
    {
        return is_blank( $p_phone ) || Validate_AU::isValidPhoneNumber( $p_phone ) || Validate_AU::isValidNationalPhoneNumber( $p_phone ) || Validate_AU::isValidMobileNumber( $p_phone );
    }

    function is_windows_server()
    {
        return (substr(php_uname(), 0, 7) == 'Windows');
    }

    function format_date( $p_date )
    {
        $date = new Date();
        if ( $date->FromString( $p_date ) === false )
            return "Invalid Date ($p_date)";

        return $date->ToDDMMMYYYY();
    }

    /**
     * requires $diocese_db to be initialised
     */
    function db_prepare_string( $p_str )
    {
        global $diocese_db;
        return $diocese_db->prepare_string( $p_str );
    }

    # --------------------
    # Print the headers to cause the page to redirect to $p_url
    # If $p_die is true (default), terminate the execution of the script
    #  immediately
    # If we have handled any errors on this page and the 'stop_on_errors' config
    #  option is turned on, return false and don't redirect.
    function header_redirect( $p_url, $p_die=true ) {
        $t_use_iis = ( strstr( $_SERVER['SERVER_SOFTWARE'], 'IIS' ) !== false ) ? 1 : 0;

        if ( 0 == $t_use_iis ) {
            header( 'Status: 302' );
        }
        header( 'Content-Type: text/html' );

        if ( 1 == $t_use_iis ) {
            header( "Refresh: 0;url=$p_url" );
        } else {
            header( "Location: $p_url" );
        }

        if ( $p_die ) {
            die; # additional output can cause problems so let's just stop output here
        }

        return true;
    }

    # --------------------
    # Get a string with a page link
    function string_page_link( $p_page_url, $p_text='', $p_page_no=0, $p_page_cur=0 )
    {
        if ( is_blank( $p_text ) )
            $p_text = $p_page_no;

        if ( ( 0 < $p_page_no ) && ( $p_page_no != $p_page_cur ) )
        {
            $separator = ( strpos( $p_page_url, '?' ) === false ) ? '?' : '&';
            $output = "<a href=\"$p_page_url" . $separator . "page_number=$p_page_no\">$p_text</a>";
        }
        else
            $output = " $p_text ";

        return $output;
    }

    # --------------------
    # Get a string with a list of page number links (eg [1 2 3])
    function string_page_links( $p_page, $p_start, $p_end, $p_current ) {
        # Check if we have more than one page,
        # otherwise return without doing anything.

        if ( $p_end - $p_start < 1 )
            return '';

        $t_items = array();
        $t_link = '';

        $t_first = 'First';
        $t_last  = 'Last';
        $t_prev  = 'Prev';
        $t_next  = 'Next';

        $t_page_links = 10;

        # First and previous links
        array_push( $t_items, string_page_link( $p_page, $t_first, 1, $p_current ) );
        array_push( $t_items, string_page_link( $p_page, $t_prev, $p_current - 1, $p_current ) );
		
        # Page numbers ...

        $t_first_page = max( $p_start, $p_current - $t_page_links/2 );
        $t_first_page = min( $t_first_page, $p_end - $t_page_links );
        $t_first_page = max( $t_first_page, $p_start );

        if ( $t_first_page > 1 )
            array_push( $t_items, '...' );

        $t_last_page = $t_first_page + $t_page_links;
        $t_last_page = min( $t_last_page, $p_end );

        for ( $i = $t_first_page ; $i <= $t_last_page ; $i++ )
            array_push( $t_items, string_page_link( $p_page, "$i", $i, $p_current ) );

        if ( $t_last_page < $p_end )
            array_push( $t_items, '...' );

        # Next and Last links
        if ( $p_current < $p_end )
            array_push( $t_items, string_page_link( $p_page, $t_next, $p_current + 1, $p_current ) );
        else
            array_push( $t_items, string_page_link( $p_page, $t_next ) );

        array_push( $t_items, string_page_link( $p_page, $t_last, $p_end, $p_current ) );

        return '[ ' . implode( ' ', $t_items ) . ' ]';
    }

    # --------------------
    # Used with hard-coded strings, or strings retrieved from config to add magic quotes
    # to make such string consistent with strings retrieved by POST / GET.  This allows
    # consistent handling when using such strings in database queries.
    function string_add_magic_quotes( $p_string )
    {
        // simulate that string is coming from $_GET or $_POST so that
        // the database_inc.php assumptions about the escaping are not broken.
        if ( get_magic_quotes_gpc() )
            $p_string = addslashes( $p_string );

        return $p_string;
    }

    # --------------------
    # Disable the timeout for pages that perform long operations.  This will only work if PHP is
    # not running in safe mode.
    function disable_timeout()
    {
        if ( ini_get( 'safe_mode' ) == false )
            @set_time_limit( 0 );
    }
?>