<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: vcard_inc.php,v 1.5 2004/04/15 12:56:35 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( $cfg_vcard_path . 'class.vCard.inc.php' );

    /**
     * ParishionerVirtualCard is an application specific class that is used to generate
     * vCard for parishioners.  This class internally uses the vCard package.  This should
     * be the only place in the code that uses the external vCard class.  The rest of the code
     * should only use this application-specific class.
     */
    class ParishionerVirtualCard
    {
        /**
         * Constructor
         *
         * Creates an instance of the class used internally to generate vCards.
         */
        function ParishionerVirtualCard()
        {
            $this->_vcard = new vCard;
        }

        /**
         * Use the parishioner information to populate the vCard.
         *
         * Examples of fields extracted from parishioner are: first name, last name, mobile, email.
         *
         * @param $p_parishioner  Instance of parishioner class to use to populate the vCard.
         *
         * @sa set_family()
         */
        function set_parishioner( $p_parishioner )
        {
            $this->_vcard->setEducationTitle( $p_parishioner->get_title() );
            $this->_vcard->setFirstName( $p_parishioner->get_first_name() );
            $this->_vcard->setMiddleName( $p_parishioner->get_middle_name() );
            $this->_vcard->setLastName( $p_parishioner->get_last_name() );
            $this->_vcard->setTelephoneWork1( $p_parishioner->get_day_time_phone() );
            $this->_vcard->setCellphone( $p_parishioner->get_mobile_number() );
            $this->_vcard->setPreferredTelephone( $p_parishioner->get_mobile_number() );
            $this->_vcard->birthday = (int)str_replace( '-', '', $p_parishioner->get_date_of_birth() );
            $this->_vcard->setEMail( $p_parishioner->get_email() );

            // $occupation = $p_parishioner->get_extra_information( PARISHIONER_EXTRA_FIELD_OCCUPATION );
            // if ( $occupation !== false )
            //   $this->_vcard->setJobTitle( $occupation );

            $t_address = null;

            // $this->_vcard->setWorkCountry()
            // $this->_vcard->setPostalStreet();
            // $this->_vcard->setPostalZIP();
            // $this->_vcard->setPostalRegion();
            // $this->_vcard->setPostalCountry();
            // $this->_vcard->setNickname('Maxi');
            // $this->_vcard->setCompany('Microsoft');
            // $this->_vcard->setOrganisation('Linux');
            // $this->_vcard->setDepartment('Product Placement');
            // $this->_vcard->setNote('Additional Note go here');
            // $this->_vcard->setTelephoneWork2('+43 (05555) 000000');
            // $this->_vcard->setFaxWork('+43 (05555) 000000');
        }

        /**
         * Use the family information to populate the vCard.
         *
         * Examples of fields extracted from family are: address, postal address, phone number.
         *
         * @param $p_family  Instance of family class to use to populate the vCard.
         *
         * @sa set_parishioner()
         */
        function set_family( $p_family )
        {
            $this->_vcard->setTelephoneHome1( $p_family->get_home_phone() );
            $this->_vcard->setTelephoneHome2( $p_family->get_home_phone2() );
            $this->_vcard->setFaxHome( $p_family->get_home_fax() );
        }

        /**
         * Use the family address information to populate the parishioners home address
         * information.
         *
         * @param $p_address  Instance of Address class to use to populate the vCard.
         *
         * @sa set_postal_address()
         */
        function set_address( $p_address )
        {
            $this->_vcard->setHomeStreet( $p_address->get_street_details() );
            $this->_vcard->setHomeRegion( $p_address->get_state() );
            $this->_vcard->setHomeZIP( $p_address->get_post_code() );
            $this->_vcard->setHomeCountry( $p_address->get_country() );

            // $this->_vcard->setHomeCity('Testcity');
        }

        /**
         * Use the family postal address information to populate the parishioners postal 
         * address information.
         *
         * @param $p_postal_address  Instance of postal address class to use to populate the
         *                           vCard.
         *
         * @sa set_address()
         */
        function set_postal_address( $p_postal_address )
        {
            // :TODO: not yet implemented
            // $this->_vcard->setPostalStreet('123 Examplestreet');
            // $this->_vcard->setPostalZIP('11111');
            // $this->_vcard->setPostalCity('Testcity');
            // $this->_vcard->setPostalRegion('PA');
            // $this->_vcard->setPostalCountry('USA');
        }

        /**
         * Generate virtual card for parishioner.
         */
        function generate_file()
        {
            $this->_vcard->outputFile( 'vcf' );
        }

        //
        // PRIVATE
        //

        var $_vcard;
    }
?>