<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: suburbs_report_page.php,v 1.3 2004/10/14 10:50:36 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'src' .
                  DIRECTORY_SEPARATOR . 'common_inc.php' );
    require_once( $src_path . 'access_api_inc.php' );

    access_ensure_not_standalone();

    # Get GET Variables
    $f_format = gpc_get_string( 'format',  'html' );

    disable_timeout();

    $diocese_db->connect();

    #
    # Generic sort function to sort an array based on a field of its records.
    #

    define("ORDER_ASC", "asc");
    define("ORDER_DESC", "desc");

    function mu_sort( $array, $key_sort, $asc_desc )
    {
        // check input parameters
        if ( func_num_args() < 2 || func_num_args() > 3)
            die("Wrong number of parameters for the call of mu_sort()");

        $array = func_get_arg(0);
        $key_sort = func_get_arg(1);
        if (func_num_args()==3)
            $asc_desc = func_get_arg(2);
        else
            $asc_desc = ORDER_ASC;

        $key_sorta = explode(",", $key_sort);

        $keys = array_keys($array[0]);

        // sets the $key_sort vars to the first
        for ( $m = 0; $m < count($key_sorta); $m++)
        {
            $nkeys[$m] = trim($key_sorta[$m]);
        }

        $n = count($key_sorta);    // counter used inside loop

        // this loop is used for gathering the rest of the
        // key's up and putting them into the $nkeys array
        for ( $i = 0; $i < count( $keys ); $i++ )
        {
            // quick check to see if key is already used.
            if ( !in_array( $keys[$i], $key_sorta ) )
            {
                // set the key into $nkeys array
                $nkeys[$n] = $keys[$i];

                // add 1 to the internal counter
                $n += 1;
            } // end if check
        } // end loop

        // this loop is used to group the first array [$array]
        // into it's usual clumps
        for( $u = 0; $u < count( $array ); $u++ )
        {
            // set array into var, for easier access.
            $arr = $array[$u];

            // this loop is used for setting all the new keys
            // and values into the new order
            for ( $s = 0; $s < count( $nkeys ); $s++ )
            {
                // set key from $nkeys into $k to be passed into multidimensional array
                $k = $nkeys[$s];

                // sets up new multidimensional array with new key ordering
                $output[$u][$k] = $array[$u][$k];
            } // end loop #2
        } // end loop #1

        switch($asc_desc)
        {
            case ORDER_DESC:
                rsort($output);
                break;

            default:
                sort($output);
        }

        // return sorted array
        return $output;
    } // end function

    #
    # Check that all suburbs in the database are used and valid
    #

    $suburbs_with_errors[] = array();

    $array_suburb_state_postcode = file( $src_path . 'au_suburb_state_postcode.csv' );

    for ( $i = 0; $i < count( $array_suburb_state_postcode ); $i++ )
        $array_suburb_state_postcode[$i] = trim( $array_suburb_state_postcode[$i] );

    $t_states_map = states_get_id_name_map();

    $t_suburb_ids = suburb_get_all_ids();
    $t_suburb_errors = array();

    foreach ( $t_suburb_ids as $t_suburb_id )
    {
        if ( !suburb_is_used( $t_suburb_id ) )
        {
            $t_suburb_name = suburb_get_name( $t_suburb_id );
            $suburbs_with_errors[$t_suburb_id] = "Suburb '$t_suburb_name' is not used in any addresses.";
        }
        else
        {
            $t_state_id = suburb_get_field( $t_suburb_id, 'state_id' );
            $t_suburb_state = strtoupper( $t_states_map[ $t_state_id ] );
            $t_suburb_name = strtoupper( suburb_get_name( $t_suburb_id ) );
            $t_suburb_postcode = strtoupper( suburb_get_field( $t_suburb_id, 'post_code' ) );

            $t_key = "$t_suburb_name,$t_suburb_state,$t_suburb_postcode";
            if ( !in_array( $t_key, $array_suburb_state_postcode ) )
                $suburbs_with_errors[$t_suburb_id] = "Unknown suburb '$t_key'";
        }
    }

    unset( $array_suburb_state_postcode );
    unset( $t_state_map );
    unset( $t_suburb_ids );





    $suburbs = array();

    function suburb_get_family_ids( $p_suburb_id )
    {
        global $diocese_db;

        $t_core_families       = table( 'core_families' );
        $t_core_addresses      = table( 'core_addresses' );

        $sql_suburb_id = $diocese_db->prepare_int( $p_suburb_id );

        $query = "SELECT f.family_id as family_id
                         FROM $t_core_families as f, $t_core_addresses as a
                         WHERE a.suburb_id = $sql_suburb_id AND f.address_id = a.address_id";
 
        if ( access_limited_to_one_parish() )
        {
            $query .= " AND f.parish_id = " . access_get_parish_id();
        }

        $t_result = &$diocese_db->execute( $query );

        $family_ids = array();
        while ( !$t_result->EOF )
        {
            $family_ids[] = $t_result->fields['family_id'];
            $t_result->MoveNext();
        }

        return $family_ids;
    }

    function suburb_get_family_count( $p_suburb_id )
    {
        global $diocese_db;

        $t_core_families       = table( 'core_families' );
        $t_core_addresses      = table( 'core_addresses' );

        $sql_suburb_id = $diocese_db->prepare_int( $p_suburb_id );

        $query = "SELECT count(*)
                         FROM $t_core_families as f, $t_core_addresses as a
                         WHERE a.suburb_id = $sql_suburb_id AND f.address_id = a.address_id";
 
        if ( access_limited_to_one_parish() )
        {
            $query .= " AND f.parish_id = " . access_get_parish_id();
        }

        return $diocese_db->get_one( $query );
    }

    function suburb_get_parishioner_count( $p_suburb_id )
    {
        global $diocese_db;

        $t_core_families       = table( 'core_families' );
        $t_core_family_members = table( 'core_family_members' );
        $t_core_addresses      = table( 'core_addresses' );

        $sql_suburb_id = $diocese_db->prepare_int( $p_suburb_id );

        $query = "SELECT count(*)
                         FROM $t_core_families as f, $t_core_family_members as fm, $t_core_addresses as a
                         WHERE a.suburb_id = $sql_suburb_id AND f.address_id = a.address_id AND fm.family_id = f.family_id";
 
        if ( access_limited_to_one_parish() )
        {
            $query .= " AND f.parish_id = " . access_get_parish_id();
        }

        return $diocese_db->get_one( $query );
    }

    $t_core_suburbs      = table( 'core_suburbs' );

    $query = "SELECT * FROM $t_core_suburbs";
    $t_result = &$diocese_db->execute( $query );

    $suburbs = array();
    while ( !$t_result->EOF )
    {
        $row = $t_result->fields;

        $suburb = array();
        $suburb['suburb_id'] = $row['suburb_id'];
        $suburb['name'] = ucwords( strtolower( $row['name'] ) );
        $suburb['state'] = state_get_field( $row['state_id'], 'initials' );
        $suburb['post_code'] = $row['post_code'];
        $suburb['family_ids'] = suburb_get_family_ids( $row['suburb_id'] );
        $suburb['families'] = count( $suburb['family_ids'] );

        if ( $suburb['families'] > 0 )
        {
            $suburb['parishioners'] = suburb_get_parishioner_count( $row['suburb_id'] );

            if ( isset( $suburbs_with_errors[ $row['suburb_id'] ] ) )
            {
                $suburb['error'] = true;
                $suburb['error_msg'] = $suburbs_with_errors[$row['suburb_id']];
            }
            else
            {
                $suburb['error'] = false;
                $suburb['error_msg'] = '';
            }

            $suburbs[] = $suburb;
        }

        $t_result->MoveNext();  //  Moves to the next row
    }  // end while

    $suburbs = mu_sort( $suburbs, 'name,state,post_code', ORDER_ASC );

    # Execute the template
    $template->assign( 'suburbs', $suburbs );
    $template->assign( 'num_of_suburbs', count( $suburbs ) );

    if ( $f_format === 'csv' )
    {
        $t_filename = 'suburbs.csv';

        header( 'Content-Type: text/plain; name=' . $t_filename );
        header( 'Content-Transfer-Encoding: BASE64;');
        header( 'Content-Disposition: attachment; filename=' . $t_filename );
        $template->run( 'suburbs_report_csv' );
    }
    else
    {
        $template->run( 'suburbs_report_page' );
    }
?>