<?php
    ###########################################################################
    #
    # eArk
    #
    # Copyright (C) 2003-2004 e-Ark Team - Diocese of Sydney and Affiliated Regions
    #
    # This program is distributed under the terms and conditions of the GPL
    # See the README and LICENSE files for details
    #
    ###########################################################################

    # -------------------------------------------------------------------------
    # $Id: summary_page.php,v 1.12 2004/05/19 14:10:15 vboctor Exp $
    # -------------------------------------------------------------------------

    require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'src' .
                  DIRECTORY_SEPARATOR . 'common_inc.php' );
    require_once( $src_path . 'access_api_inc.php' );

    access_ensure_not_standalone();

    # Get GET Variables
    $f_format = gpc_get_string( 'format',  'html' );

    $diocese_db->connect();

    function sql_date_range( $p_field, $p_start_date, $p_end_date )
    {
        global $diocese_db;

        $sql_field = $p_field;	// can't prepare otherwise ' will be added

        $t_start_string = db_prepare_string( date( 'Y-m-d', $p_start_date ) . ' 00:00:00' );
        $t_end_string   = db_prepare_string( date( 'Y-m-d', $p_end_date ) . ' 23:59:59' ); 

        return "( $sql_field BETWEEN $t_start_string AND $t_end_string )";
    }

    function summary_get( $p_parish_id = null )
    {
        global $diocese_db;

        $sql_parish_id = $diocese_db->prepare_int( $p_parish_id );
        $t_summary = array();


        if ( $p_parish_id == null )
        {
           $t_summary['id'] = '';
           $t_summary['title'] = 'Diocese';
        }
        else
        {
           $t_summary['id'] = $p_parish_id;
           $t_summary['title'] = parish_get_field( $p_parish_id, 'name' );
        }


        // Number of parishes
        $t_core_parishes = table( 'core_parishes' );
        $parish_query = "SELECT COUNT(*) FROM $t_core_parishes";
        if ( $p_parish_id !== null  )
            $parish_query .= " WHERE parish_id = $sql_parish_id";
        $t_summary['num_of_parishes'] = $diocese_db->get_one( $parish_query );

        // Number of families
        $t_core_families = table( 'core_families' );
        $family_query = "SELECT COUNT(*) FROM $t_core_families as families, $t_core_parishes as parishes WHERE ( families.parish_id = parishes.parish_id )";
        if ( $p_parish_id !== null )
            $family_query .= " AND parishes.parish_id = $sql_parish_id";
        $t_summary['num_of_families'] = $diocese_db->get_one( $family_query );

        $family_approved_query = $family_query . " AND ( approved = 0 )";
        $t_summary['num_of_families_pending_approval'] = $diocese_db->get_one( $family_approved_query );

        $t_summary['num_of_families'] -= $t_summary['num_of_families_pending_approval'];

        // Number of parishioners
        $t_core_parishioners = table( 'core_parishioners' );
        $parishioner_query = "SELECT COUNT(*) 
                  FROM $t_core_parishioners as parishioners, 
                       $t_core_parishes as parishes 
                  WHERE ( parishioners.primary_parish_id = parishes.parish_id )";
        if ( $p_parish_id !== null  )
            $parishioner_query .= " AND parishes.parish_id = " . $sql_parish_id;
        $t_summary['num_of_parishioners'] = $diocese_db->get_one( $parishioner_query );

        $parishioner_approved_query = $parishioner_query . " AND ( approved = 0 )";
        $t_summary['num_of_parishioners_pending_approval'] = $diocese_db->get_one( $parishioner_approved_query );

        $t_summary['num_of_parishioners'] -= $t_summary['num_of_parishioners_pending_approval'];

        $t_one_month_time = strtotime( '-1 month' );
        $t_three_month_time = strtotime( '-3 month' );

	$family_modified_last_month_query = $family_query . ' AND ( ' . 
                                                 sql_date_range( 'date_added', $t_one_month_time, time() ) . ' OR ' . 
                                                 sql_date_range( 'date_updated', $t_one_month_time, time() ) . ')' ;

        $t_summary['families_modified_last_month'] = $diocese_db->get_one( $family_modified_last_month_query );

	$family_modified_last_three_month_query = $family_query . ' AND ( ' . 
                                                 sql_date_range( 'date_added', $t_three_month_time, time() ) . ' OR ' . 
                                                 sql_date_range( 'date_updated', $t_three_month_time, time() ) . ')' ;
        $t_summary['families_modified_last_three_month'] = $diocese_db->get_one( $family_modified_last_three_month_query );


	$parishioner_modified_last_month_query = $parishioner_query . ' AND ( ' . 
                                                 sql_date_range( 'date_added', $t_one_month_time, time() ) . ' OR ' . 
                                                 sql_date_range( 'date_updated', $t_one_month_time, time() ) . ')' ;
        $t_summary['parishioners_modified_last_month'] = $diocese_db->get_one( $parishioner_modified_last_month_query );

	$parishioner_modified_last_three_month_query = $parishioner_query . ' AND ( ' . 
                                                 sql_date_range( 'date_added', $t_three_month_time, time() ) . ' OR ' . 
                                                 sql_date_range( 'date_updated', $t_three_month_time, time() ) . ')' ;
        $t_summary['parishioners_modified_last_three_month'] = $diocese_db->get_one( $parishioner_modified_last_three_month_query );

        return $t_summary;
    }

    $t_summaries = array();
    if ( access_limited_to_one_parish() )
        $t_summaries[] = summary_get( access_get_parish_id() );
    else
    {
        $t_parish_ids = array_keys( parish_get_id_name_map() );

        $t_summaries[] = summary_get();
        foreach( $t_parish_ids as $t_parish_id )
            $t_summaries[] = summary_get( $t_parish_id );
    }

    # Execute the template
    $template->assign( 'summaries', $t_summaries );

    if ( $f_format === 'csv' )
    {
        $t_filename = 'summary.csv';

        header( 'Content-Type: text/plain; name=' . $t_filename );
        header( 'Content-Transfer-Encoding: BASE64;');
        header( 'Content-Disposition: attachment; filename=' . $t_filename );
        $template->run( 'summary_csv' );
    }
    else
    {
        $template->run( 'summary_page' );
    }
?>